<?php
/**
 * Customizer functionality
 *
 * @package Wen_Biz
 */

/**
 * Sets up the WordPress core custom header and custom background features.
 *
 * @since 1.0
 *
 * @see wen_biz_header_style()
 */
function wen_biz_custom_header_and_bg() {
	$color_scheme       = wen_biz_get_color_scheme();
	$default_text_color = trim( $color_scheme['header_textcolor'], '#' );

	/**
	 * Filter the arguments used when adding 'custom-background' support in Zubin.
	 *
	 * @since 1.0
	 *
	 * @param array $args {
	 *     An array of custom-background support arguments.
	 *
	 *     @type string $default-color Default color of the background.
	 * }
	 */

	// Adds a class of (full-width|box) to blogs.
	if ( 'boxed' === get_theme_mod( 'wen_biz_layout_type' ) ) {
		add_theme_support( 'custom-background', apply_filters( 'wen_biz_custom_bg_args', array(
			'default-color' => trim( $color_scheme['background_color'], '#' ),
		) ) );
	} else {
		add_theme_support( 'custom-background', apply_filters( 'wen_biz_custom_bg_args', array(
			'default-color' => '#ffffff',
		) ) );
	}


	add_theme_support( 'custom-background', apply_filters( 'wen_biz_custom_bg_args', array(
		'default-color' => trim( $color_scheme['background_color'], '#' ),
	) ) );

	/**
	 * Filter the arguments used when adding 'custom-header' support in Zubin.
	 *
	 * @since 1.0
	 *
	 * @param array $args {
	 *     An array of custom-header support arguments.
	 *
	 *     @type string $default-text-color Default color of the header text.
	 *     @type int      $width            Width in pixels of the custom header image. Default 1200.
	 *     @type int      $height           Height in pixels of the custom header image. Default 280.
	 *     @type bool     $flex-height      Whether to allow flexible-height header images. Default true.
	 *     @type callable $wp-head-callback Callback function used to style the header image and text
	 *                                      displayed on the blog.
	 * }
	 */
	add_theme_support( 'custom-header', apply_filters( 'wen_biz_custom_header_args', array(
		'default-image'      => get_parent_theme_file_uri( '/images/header-image.jpg' ),
		'default-text-color' => $default_text_color,
		'width'              => 1920,
		'height'             => 822,
		'flex-height'        => true,
		'flex-height'        => true,
		'wp-head-callback'   => 'wen_biz_header_style',
		'video'              => true,
	) ) );

	register_default_headers( array(
		'default-image' => array(
			'url'           => '%s/images/header-image.jpg',
			'thumbnail_url' => '%s/images/header-image-275x155.jpg',
			'description'   => esc_html__( 'Default Header Image', 'wen-biz-pro' ),
		)
	) );
}
add_action( 'after_setup_theme', 'wen_biz_custom_header_and_bg' );

function wen_biz_color_options() {
	// We do not add Background Color and Header Text Color here as if comes from WordPress Core.

	$color_options = array(
		'page_background_color'            => array(
			'label'   => 	esc_html__( 'Primary Background Color', 'wen-biz-pro' ),
			'css'     =>	'
							/* Primary Background Color */

							.site-header-main.scrollDown,
							.sidebar input[type="text"],
							.sidebar input[type="email"],
							.sidebar input[type="url"],
							.sidebar input[type="password"],
							.sidebar input[type="search"],
							.sidebar input[type="number"],
							.sidebar input[type="tel"],
							.sidebar input[type="range"],
							.sidebar input[type="date"],
							.sidebar input[type="month"],
							.sidebar input[type="week"],
							.sidebar input[type="time"],
							.sidebar input[type="datetime"],
							.sidebar input[type="datetime-local"],
							.sidebar input[type="color"],
							.sidebar textarea,
							.sidebar select,
							.comment-respond input[type="text"],
							.comment-respond input[type="email"],
							.comment-respond input[type="url"],
							.comment-respond input[type="password"],
							.comment-respond input[type="search"],
							.comment-respond input[type="number"],
							.comment-respond input[type="tel"],
							.comment-respond input[type="range"],
							.comment-respond input[type="date"],
							.comment-respond input[type="month"],
							.comment-respond input[type="week"],
							.comment-respond input[type="time"],
							.comment-respond input[type="datetime"],
							.comment-respond input[type="datetime-local"],
							.comment-respond input[type="color"],
							.comment-respond textarea,
							.comment-respond select,
							.footer-newsletter input[type="text"],
							.footer-newsletter input[type="email"],
							.footer-newsletter input[type="url"],
							.footer-newsletter input[type="password"],
							.footer-newsletter input[type="search"],
							.footer-newsletter input[type="number"],
							.footer-newsletter input[type="tel"],
							.footer-newsletter input[type="range"],
							.footer-newsletter input[type="date"],
							.footer-newsletter input[type="month"],
							.footer-newsletter input[type="week"],
							.footer-newsletter input[type="time"],
							.footer-newsletter input[type="datetime"],
							.footer-newsletter input[type="datetime-local"],
							.footer-newsletter input[type="color"],
							.footer-newsletter textarea,
							.footer-newsletter select,
							.menu-inside-wrapper input[type="search"],
							.select2-container--default .select2-selection--single,
							.screen-reader-text:focus,
							.boxed-layout .site,
							.ui-state-active,
							.ui-widget-content .ui-state-active,
							.ui-widget-header .ui-state-active,
							#gallery-section .gallery-item .gallery-icon:hover a:after,
							#gallery-section .gallery-item .gallery-icon:focus a:after,
							#gallery-section .tiled-gallery .tiled-gallery-item:hover a:after,
							#gallery-section .tiled-gallery .tiled-gallery-item:focus a:after,
							.wen-biz-mejs-container.mejs-container .mejs-controls .mejs-time-rail .mejs-time-current,
							.mejs-time-handle-content,
							.mejs-controls .mejs-horizontal-volume-slider .mejs-horizontal-volume-current,
							section.ew-tabbed-recent-popular .ui-tabs .ui-tabs-nav li.ui-tabs-active a,
							section.ew-tabbed-recent-popular .ui-tabs .ui-tabs-panel,
							.section:nth-child(2n)#featured-content-section .featured-content-wrapper .hentry-inner,
							.section:nth-child(2n)#team-content-section .team-content-wrapper .hentry-inner,
							.section:nth-child(2n).pricing-section .hentry-inner,
							.section:nth-child(2n).contact-form-section .contact-us-form input[type="text"],
							.section:nth-child(2n).contact-form-section .contact-us-form input[type="email"],
							.section:nth-child(2n).contact-form-section .contact-us-form input[type="url"],
							.section:nth-child(2n).contact-form-section .contact-us-form input[type="password"],
							.section:nth-child(2n).contact-form-section .contact-us-form input[type="search"],
							.section:nth-child(2n).contact-form-section .contact-us-form input[type="number"],
							.section:nth-child(2n).contact-form-section .contact-us-form input[type="tel"],
							.section:nth-child(2n).contact-form-section .contact-us-form input[type="range"],
							.section:nth-child(2n).contact-form-section .contact-us-form input[type="date"],
							.section:nth-child(2n).contact-form-section .contact-us-form input[type="month"],
							.section:nth-child(2n).contact-form-section .contact-us-form input[type="week"],
							.section:nth-child(2n).contact-form-section .contact-us-form input[type="time"],
							.section:nth-child(2n).contact-form-section .contact-us-form input[type="datetime"],
							.section:nth-child(2n).contact-form-section .contact-us-form input[type="datetime-local"],
							.section:nth-child(2n).contact-form-section .contact-us-form input[type="color"],
							.section:nth-child(2n).contact-form-section .contact-us-form textarea,
							.section:nth-child(2n) .archive-post-wrap .entry-container,
							.promotion-content-wrapper .post-thumbnail-stats-wrapper .promotion-stats,
							.promotional-video-content-wrapper .custom-video-button-play,
							.is-gradient-button .promotional-video-content-wrapper button.custom-video-button-play {
								background-color: %1$s;
							}

							@media screen and (min-width: 75em) {
								.section:nth-child(2n)#team-content-section .team-content-wrapper .artist-social-profile {
									background-color: %1$s;
								}
							}

							#primary-menu-wrapper .site-header-cart {
								border-color: %1$s;
							}',
		),
		'secondary_background_color'             => array(
			'label'   => 	esc_html__( 'Secondary Background Color', 'wen-biz-pro' ),
			'css'     => 	'
							/* Secondary Background Color */

							body.boxed-layout:before,
							.menu-inside-wrapper,
							input[type="text"],
							input[type="email"],
							input[type="url"],
							input[type="password"],
							input[type="search"],
							input[type="number"],
							input[type="tel"],
							input[type="range"],
							input[type="date"],
							input[type="month"],
							input[type="week"],
							input[type="time"],
							input[type="datetime"],
							input[type="datetime-local"],
							input[type="color"],
							textarea,
							select,
							.author-info,
							mark,
							.custom-header,
							ul.tabs.wc-tabs li.active a,
							.woocommerce-Tabs-panel,
							.shop_table thead th,
							ul.wc_payment_methods.payment_methods.methods li,
							.comment-respond,
							.widget_shopping_cart,
							pre,
							.widget .ui-tabs .ui-tabs-panel,
							#featured-content-section .featured-content-wrapper .hentry-inner,
							#sticky-playlist-section, #sticky-playlist-section .wp-playlist,
							section.ew-tabbed-recent-popular .ui-tabs .ui-tabs-nav li a,
							.section:nth-child(2n),
							.testimonial-content-section .hentry-inner,
							.pricing-section .hentry-inner,
							.archive-post-wrap .entry-container,
							.wp-block-quote,
							figure.wp-block-table.is-style-stripes tbody tr:nth-child(2n+1),
							.wp-block-pullquote.is-style-solid-color,
							.sidebar.widget-area section.widget,
							.contact-us-form input[type="text"],
							.contact-us-form input[type="email"],
							.contact-us-form input[type="url"],
							.contact-us-form input[type="password"],
							.contact-us-form input[type="search"],
							.contact-us-form input[type="number"],
							.contact-us-form input[type="tel"],
							.contact-us-form input[type="range"],
							.contact-us-form input[type="date"],
							.contact-us-form input[type="month"],
							.contact-us-form input[type="week"],
							.contact-us-form input[type="time"],
							.contact-us-form input[type="datetime"],
							.contact-us-form input[type="datetime-local"],
							.contact-us-form input[type="color"],
							.contact-us-form textarea {
								background-color: %1$s;
							}

							@media screen and (min-width: 75em) {
							    .navigation-classic .site-header .sub-menu,
								.navigation-classic .site-header .children,
								#team-content-section .team-content-wrapper .artist-social-profile {
									background-color: %1$s;
								}
							}',
		),
		'tertiary_background_color'             => array(
			'label'   => 	esc_html__( 'Tertiary Background Color', 'wen-biz-pro' ),
			'css'     => 	'
							/* Tertiary Background Color */

							#site-generator,
							ins,
							#colophon,
							.app-section .entry-container:after,
							#wen-biz-logo-slider-section .owl-dots .owl-dot.active,
							#site-header-top-menu,
							#footer-newsletter,
							.is-gradient-button .service-section .button:hover,
							.is-gradient-button .service-section .button:focus,
							.service-section .button:hover,
							.service-section .button:focus {
								background-color: %1$s;
							}',
		),
		'header_top_background_color'             => array(
			'label'   => 	esc_html__( 'Header Top Background Color', 'wen-biz-pro' ),
			'css'     => 	'
							/* Header Top Background Color */

							.header-top-bar,
							.service-section,
							.section:nth-child(2n).service-section,
							#promotional-headline-section .entry-content ul li:before,
							#promotional-headline-section .entry-summary ul li:before,
							.pricing-section .entry-header {
								background-color: %1$s;
							}

							@media screen and (min-width: 64em) {
								#site-header-top-menu {
									background-color: %1$s;
								}
							}',
		),
		'service_block_background_color'             => array(
			'label'   => 	esc_html__( 'Service Block Background Color', 'wen-biz-pro' ),
			'css'     => 	'
							/* Service Block Background Color */

							.service-section .hentry-inner,
							.section:nth-child(2n).service-section .hentry-inner {
								background-color: %1$s;
							}',
		),
		'main_text_color'          => array(
			'label'   => 	esc_html__( 'Main Text Color', 'wen-biz-pro' ),
			'css'     => 	'
							/* Main Text Color */

							body,
							input,
							select,
							optgroup,
							textarea,
							input[type="text"],
							input[type="email"],
							input[type="url"],
							input[type="password"],
							input[type="search"],
							input[type="number"],
							input[type="tel"],
							input[type="range"],
							input[type="date"],
							input[type="month"],
							input[type="week"],
							input[type="time"],
							input[type="datetime"],
							input[type="datetime-local"],
							input[type="color"],
							textarea,
							section.ew-tabbed-recent-popular .ui-widget-content,
							#portfolio-content-section .portfolio-content-wrapper .filter-button-group button,
							.menu-inside-wrapper .action-buttons > .is-ghost-button,
							form div.fes-form .fes-el .fes-fields input[type="text"],
							form div.fes-form .fes-el .fes-fields input[type="password"],
							form div.fes-form .fes-el .fes-fields input[type="email"],
							form div.fes-form .fes-el .fes-fields input[type="url"],
							form div.fes-form .fes-el .fes-fields input[type="number"],
							form div.fes-form .fes-el .fes-fields textarea,
							#tabs.ui-tabs .ui-tabs-nav li a,
							#footer-newsletter .tnp-widget input[type=email],
							.wp-block-code {
							    color: %1$s;
							}

							.section .owl-carousel .owl-dots button,
							#testimonial-content-section.style-two .owl-prev:before,
							#testimonial-content-section.style-two .owl-next:after {
							     background-color: %1$s;
							}',
		),
		'heading_text_color'         => array(
			'label'   => 	esc_html__( 'Heading Text Color', 'wen-biz-pro' ),
			'css'     => 	'
							/* Heading Text Color */

							h1,
							h2,
							h3,
							h4,
							h5,
							h6,
							blockquote,
							input:focus,
							select:focus,
							optgroup:focus,
							textarea:focus,
							.section-title,
							.drop-cap:first-letter,
							.portfolio-section-headline .section-title,
							.author-name,
							.comment-reply-link,
							.author-title,
							.comment-respond .comment-form p label,
							.has-background-image .entry-container .event-title .entry-title,
							.has-background-image .entry-container .event-title .entry-title a,
							section.ew-tabbed-recent-popular .ui-tabs .ui-tabs-nav li.ui-tabs-active a,
							.filter-select-group > span,
							.filters-select select,
							#tabs.ui-tabs .ui-tabs-nav li a:hover,
							#tabs.ui-tabs .ui-tabs-nav li a:focus,
							#tabs.ui-tabs .ui-tabs-nav li.ui-tabs-active a,
							.portfolio-content-wrapper .filter-select-group > span,
							.inner-contact .label,
							.page .site-main .entry-footer .entry-meta > span > span,
							.single .site-main .entry-footer .entry-meta > span > span,
							.promotion-content-wrapper .post-thumbnail-stats-wrapper .promotion-stats,
							.hero-content-wrapper .entry-content .block-one-title,
							.hero-content-wrapper .entry-content .block-two-title,
							span.contact-info-list {
							    color: %1$s;
							}

							.portfolio-content-wrapper .filters-select-wrap:after {
							    border-top-color: %1$s;
							}',
		),
		'link_color'         => array(
			'label'   => 	esc_html__( 'Link Color', 'wen-biz-pro' ),
			'css'     => 	'
							/* Link Color */

							a,
							.site-title a:hover,
							.site-title a:focus,
							.menu-toggle:hover,
							.menu-toggle:focus,
							.main-navigation a:hover,
							.main-navigation a:focus,
							.dropdown-toggle:hover,
							.dropdown-toggle:focus,
							.cart-contents:hover,
							.cart-contents:focus,
							.main-navigation .sub-menu a:hover,
							.main-navigation .sub-menu a:focus,
							.header-top-bar .contact-details li a:hover,
							.header-top-bar .contact-details li a:focus,
							.header-top-right .social-links-menu a:hover,
							.header-top-right .social-links-menu a:focus,
							.menu-social-container a:hover,
							.menu-social-container a:focus,
							.site-header-main .social-navigation a:hover,
							.site-header-main .social-navigation a:focus {
							    color: %1$s;
							}

							.main-navigation .current-menu-item a,
							.main-navigation .current-page-item a,
							#promotion-content-section .entry-content ul li:before,
							#promotion-content-section .entry-summary ul li:before,
							.is-gradient-button .featured-content-wrapper .more-button .more-link,
							.featured-content-wrapper .more-button .more-link,
							.contact .contact-info-link,
							.contact-tagline,
							table a {
								color: %1$s;
							}',
		),
		'secondary_link_color'           => array(
			'label'   => 	esc_html__( 'Secondary Link Color', 'wen-biz-pro' ),
			'is_rgba' => true,
			'css'     => 	'
							/* Secondary Link Color */

							.more-link,
							.menu-toggle,
							.cart-contents,
							.entry-title a,
							ins,
							.breadcrumb a,
							p.stars a,
							p.stars a:before,
							.controller:before,
							.select2-results__option,
							.testimonials-content-wrapper.section.testimonial-wrapper .cycle-prev:before,
							.testimonials-content-wrapper.section.testimonial-wrapper .cycle-prev:after,
							.testimonials-content-wrapper.section.testimonial-wrapper .cycle-next:before,
							.clients-content-wrapper .controller .cycle-pager span,
							.testimonials-content-wrapper .cycle-pager:after,
							.testimonials-content-wrapper .entry-title a,
							.testimonials-content-wrapper.section.testimonial-wrapper .hentry,
							.scrollup a:hover:before,
							.scrollup a:focus:before,
							.archive-content-wrap .section-content-wrapper.layout-one .entry-container>.entry-meta .posted-on a,
							.author-label,
							.section-heading-wrapper .entry-title span,
							.author-section-title,
							.nav-menu .menu-item-has-children>a:before,
							.nav-menu .menu_item_has_children>a:before,
							span.woocommerce-Price-amount,
							.events-content-wrapper .entry-meta a:hover,
							.events-content-wrapper .entry-meta a:focus,
							.sidebar .widget-wrap li a,
							.ui-state-active a,
							.ui-state-active a:link,
							.ui-state-active a:visited,
							.site-header-main .social-navigation a,
							.social-search-wrapper .menu-social-container li a,
							.menu-social-container a,
							.sidebar nav.social-navigation ul li a:hover,
							.sidebar nav.social-navigation ul li a:focus,
							.screen-reader-text:focus,
							td#today,
							.toggled-on.active:before,
							.comment-respond .comment-form p.is-focused label,
							.main-navigation a,
							.main-navigation .sub-menu a,
							.dropdown-toggle,
							.page-links a,
							.nav-title,
							.post-title,
							.post-navigation .nav-title,
							.widget_recent_entries li a,
							.wp-caption .wp-caption-text,
							.comments-title,
							.comment-reply-title,
							.author-name .url,
							.vcard,
							.position,
							.contact a {
								color: %1$s;
							}

							#feature-slider-section button.owl-dot,
							#testimonial-content-section button.owl-dot {
								background-color: %1$s;
							}
							
							.nav-subtitle,
							.has-background-image .event-list-description .entry-summary,
							.has-background-image .event-list-description .entry-summary p,
							.has-background-image .event-list-description .entry-content,
							.has-background-image .event-list-description .entry-content p,
							.playlist-content-wrapper .wp-playlist-tracks,
							.testimonial-content-section .position,
							blockquote.wp-block-quote cite,
							.wp-block-pullquote cite,
							[class^="wp-block-"]:not(.wp-block-gallery) figcaption,
							figure.wp-block-table figcaption,
							blockquote.wp-block-quote.is-style-large cite,
							.wp-block-table tfoot td,
							.wp-block-latest-comments__comment-date,
							[class^="wp-block-"]:not(.wp-block-gallery) figcaption,
							.pagination .page-numbers,
							.sidebar .widget ul li a,
							.entry-meta a,
							.comment-permalink,
							.comment-edit-link,
							.tagcloud a,
							input::placeholder,
							textarea::placeholder,
							.sidebar .widget input::placeholder,
							.custom-header-media .breadcrumb-area .breadcrumb-current,
							.custom-header-media .breadcrumb a:hover,
							.custom-header-media .breadcrumb a:focus,
							.widget_recent_entries .post-date {
								color: rgba(%2$s, %3$s, %4$s, 0.5);
							}',
		),
		'link_hover_color'         => array(
			'label'   => 	esc_html__( 'Link Hover Color', 'wen-biz-pro' ),
			'css'     => 	'
							/* Link Hover Color */

							a:hover,
							a:focus,
							.is-gradient-button .featured-content-wrapper .more-button .more-link:hover,
							.is-gradient-button .featured-content-wrapper .more-button .more-link:focus,
							.featured-content-wrapper .more-button .more-link:hover,
							.featured-content-wrapper .more-button .more-link:focus,
							.contact .contact-info-link:hover,
							.contact .contact-info-link:focus {
							    color: %1$s;
							}',
		),
		'secondary_link_hover_color'         => array(
			'label'   => 	esc_html__( 'Secondary Link Hover Color', 'wen-biz-pro' ),
			'css'     => 	'
							/* Secondary Link Hover Color */

							.more-link:hover,
							.more-link:focus,
							.entry-title a:hover,
							.entry-title a:focus,
							.entry-meta a:hover,
							.entry-meta a:focus,
							.comment-meta a:hover,
							.comment-meta a:focus,
							.play-button-text:hover,
							.play-button-text:focus,
							.has-background-image .woocommerce-loop-product__title:hover,
							.has-background-image .woocommerce-loop-product__title:focus,
							.has-background-image .entry-container .entry-meta a:hover,
							.has-background-image .entry-container .entry-meta a:focus,
							.has-background-image .entry-container .entry-title a:hover,
							.has-background-image .entry-container .entry-title a:focus,
							#site-footer-navigation li a:hover,
							#site-footer-navigation li a:focus,
							#social-footer-navigation li a:hover,
							#social-footer-navigation li a:focus,
							.has-background-image .entry-title a:hover,
							.has-background-image .entry-title a:focus,
							.has-background-image .entry-meta a:hover,
							.has-background-image .entry-meta a:focus,
							.archive-post-wrap .hentry:nth-child(2n) .entry-title a:hover,
							.archive-post-wrap .hentry:nth-child(2n) .entry-title a:focus,
							.archive-post-wrap .hentry:nth-child(2n) .entry-meta a:hover,
							.archive-post-wrap .hentry:nth-child(2n) .entry-meta a:focus,
							.wp-playlist-tracks .wp-playlist-caption:hover,
							.wp-playlist-tracks .wp-playlist-caption:focus,
							#service-section .entry-title a:hover,
							#service-section .entry-title a:focus,
							.woocommerce-loop-product__title:hover,
							.woocommerce-loop-product__title:focus,
							span.price span.woocommerce-Price-amount:hover,
							span.price span.woocommerce-Price-amount:focus,
							.widget_recent_entries li a:hover,
							.widget_recent_entries li a:focus,
							button#wp-custom-header-video-button:hover,
							button#wp-custom-header-video-button:focus,
							.widget .ui-state-default a:hover,
							.widget .ui-state-default a:focus,
							.widget .ui-widget-content .ui-state-default a:hover,
							.widget .ui-widget-content .ui-state-default a:focus,
							.widget .ui-widget-header .ui-state-default a:hover,
							.widget .ui-widget-header .ui-state-default a:focus,
							body .site-header .site-header-main .site-header-menu .menu-inside-wrapper .main-navigation .nav-menu ul .current_page_item > a:hover,
							body .site-header .site-header-main .site-header-menu .menu-inside-wrapper .main-navigation .nav-menu ul .current_page_item > a:focus,
							.tag-cloud-link:hover,
							.tag-cloud-link:focus,
							.nav-title:hover,
							.nav-title:focus,
							.menu-social-container a:hover,
							.menu-social-container a:focus,
							.portfolio-content-wrapper .hentry .entry-container a:hover,
							.portfolio-content-wrapper .hentry .entry-container a:focus,
							.social-search-wrapper .menu-social-container li a:hover,
							.social-search-wrapper .menu-social-container li a:focus,
							.author a:hover,
							.author a:focus,
							.entry-title a:hover,
							.entry-title a:focus,
							.site-footer td#prev a:hover,
							.site-footer td#prev a:focus,
							.site-footer td#next a:hover,
							.site-footer td#next a:focus,
							.comment-reply-link:hover,
							.comment-reply-link:focus,
							.author-section-title:hover,
							.author-section-title:focus,
							.comment-permalink:hover,
							.comment-permalink:focus,
							.comment-edit-link:hover,
							.comment-edit-link:focus,
							.nav-subtitle:hover,
							.nav-subtitle:focus,
							.scroll-down:hover,
							.scroll-down:focus,
							.testimonials-content-wrapper.section.testimonial-wrapper .entry-title a:hover,
							.testimonials-content-wrapper.section.testimonial-wrapper .entry-title a:focus,
							#site-generator .menu-social-container a:hover,
							#site-generator .menu-social-container a:focus,
							.widget-wrap li a:hover,
							.widget-wrap li a:focus,
							.archive-content-wrap .section-content-wrapper.layout-one .entry-container > .entry-meta .posted-on a:hover,
							.archive-content-wrap .section-content-wrapper.layout-one .entry-container > .entry-meta .posted-on a:focus,
							.entry-title a:hover,
							.entry-title a:focus,
							.single footer .entry-meta a:hover,
							.single footer .entry-meta a:focus,
							.wen-biz-logo-slider-content-wrapper .entry-title span:hover,
							.wen-biz-logo-slider-content-wrapper .entry-title span:focus,
							.wp-playlist .mejs-controls .mejs-button button:hover,
							.wp-playlist .mejs-controls .mejs-button button:focus,
							#sticky-playlist-section .mejs-container.wen-biz-mejs-container .mejs-toggle-playlist button:hover,
							#sticky-playlist-section .mejs-container.wen-biz-mejs-container .mejs-toggle-playlist button:focus,
							.breadcrumb a:hover,
							.breadcrumb a:focus,
							.site-info a:hover,
							.site-info a:focus,
							.sidebar .widget ul li a:hover,
							.sidebar .widget ul li a:focus,
							#portfolio-content-section .portfolio-content-wrapper .filter-button-group button:hover,
							#portfolio-content-section .portfolio-content-wrapper .filter-button-group button:focus,
							.contact a:hover,
							.contact a:focus,
							.service-section .entry-title a:hover,
							.service-section .entry-title a:focus,
							.pricing-content-wrapper .entry-header .entry-title a:hover,
							.pricing-content-wrapper .entry-header .entry-title a:focus,
							.pricing-section .hentry.highlight .more-button .more-link:hover,
							.pricing-section .hentry.highlight .more-button .more-link:focus,
							.pricing-section .section-content-wrapper .hentry.highlight .entry-content .wp-block-button .wp-block-button__link:hover,
							.pricing-section .section-content-wrapper .hentry.highlight .entry-content .wp-block-button .wp-block-button__link:focus,
							.pricing-section .section-content-wrapper .hentry.highlight .entry-summary .wp-block-button .wp-block-button__link:hover,
							.pricing-section .section-content-wrapper .hentry.highlight .entry-summary .wp-block-button .wp-block-button__link:focus {
								color: %1$s;
							}

							p.stars:hover a:before,
							p.stars:focus a:before,
							.star-rating span:before,
							p.stars.selected a.active:before,
							p.stars.selected a:not(.active):before,
							p.stars.selected a.active~a:before,
							p.stars a:hover~a:before,
							p.stars a:focus~a:before,
							#reviews .comment-respond .comment-form-rating .stars span a.active:before,
							#reviews .comment-respond .comment-form-rating .stars.selected span a:not(.active):before,
							#promotion-section .play-button,
							.section-tagline,
							#feature-slider-section .entry-meta a,
							.archive-post-wrap .hentry .entry-meta > span:hover::before,
							.archive-post-wrap .hentry .entry-meta > span:focus::before,
							.pagination .page-numbers:hover,
							.pagination .page-numbers:focus,
							ul > li::marker,
							.sidebar .social-navigation.ct-social-widget a,
							#team-content-section .social-navigation a,
							#portfolio-content-section .portfolio-content-wrapper .filter-button-group button.is-checked,
							.custom-header-media .breadcrumb-area .sep,
							.promotion-content-wrapper .post-thumbnail-stats-wrapper .promotion-stats .stat-count,
							.promotional-video-content-wrapper .custom-video-button-play,
							.is-gradient-button .promotional-video-content-wrapper .custom-video-button-play,
							.site-title a:hover,
							.site-title a:focus,
							.menu-toggle:hover,
							.menu-toggle:focus,
							.main-navigation a:hover,
							.main-navigation a:focus,
							.dropdown-toggle:hover,
							.dropdown-toggle:focus,
							.cart-contents:hover,
							.cart-contents:focus,
							.main-navigation .sub-menu a:hover,
							.main-navigation .sub-menu a:focus,
							.header-top-bar .contact-details li a:hover,
							.header-top-bar .contact-details li a:focus,
							.header-top-right .social-links-menu a:hover,
							.header-top-right .social-links-menu a:focus,
							.menu-social-container a:hover,
							.menu-social-container a:focus,
							.site-header-main .social-navigation a:hover,
							.site-header-main .social-navigation a:focus,
							.textwidget ul li .icon {
							    color: %1$s;
							}

							.portfolio-content-wrapper .filter-button-group button.is-checked:before,
							.portfolio-content-wrapper .inner-wrap:before,
							.ui-state-active a:after,
							body input[type="text"]:focus,
							body input[type="email"]:focus,
							body input[type="url"]:focus,
							body input[type="password"]:focus,
							body input[type="search"]:focus,
							body input[type="number"]:focus,
							body input[type="tel"]:focus,
							body input[type="range"]:focus,
							body input[type="date"]:focus,
							body input[type="month"]:focus,
							body input[type="week"]:focus,
							body input[type="time"]:focus,
							body input[type="datetime"]:focus,
							body input[type="datetime-local"]:focus,
							body input[type="color"]:focus,
							body textarea:focus,
							form div.fes-form .fes-el .fes-fields input[type="text"]:focus,
							form div.fes-form .fes-el .fes-fields input[type="password"]:focus,
							form div.fes-form .fes-el .fes-fields input[type="email"]:focus,
							form div.fes-form .fes-el .fes-fields input[type="url"]:focus,
							form div.fes-form .fes-el .fes-fields input[type="number"]:focus,
							form div.fes-form .fes-el .fes-fields textarea:focus,
							select:focus,
							#service-section .more-button .more-link,
							#promotion-content-section .entry-content ul li:before,
							#promotion-content-section .entry-summary ul li:before,
							.pricing-section .hentry .more-button .more-link,
							.is-gradient-button .pricing-section .hentry.highlight .more-button .more-link:hover,
							.is-gradient-button .pricing-section .hentry.highlight .more-button .more-link:focus,
							.pricing-section .section-content-wrapper .hentry.highlight .entry-content .wp-block-button .wp-block-button__link:hover,
							.pricing-section .section-content-wrapper .hentry.highlight .entry-content .wp-block-button .wp-block-button__link:focus,
							.pricing-section .section-content-wrapper .hentry.highlight .entry-summary .wp-block-button .wp-block-button__link:hover,
							.pricing-section .section-content-wrapper .hentry.highlight .entry-summary .wp-block-button .wp-block-button__link:focus {
								border-color: %1$s;
							}

							@media screen and (min-width: 75em) {
								.navigation-classic .main-navigation .current_page_item > a:before,
								.navigation-classic .main-navigation .current-menu-item > a:before {
								  border-color: %1$s;
								}
							}

							#feature-slider-section button.owl-dot.active,
							#feature-slider-section button.owl-dot:hover,
							#feature-slider-section button.owl-dot:focus,
							#testimonial-content-section button.owl-dot.active,
							#testimonial-content-section button.owl-dot:hover,
							#testimonial-content-section button.owl-dot:focus {
								background-color: %1$s;
							}',
		),
		'border_color'             => array(
			'label'   => 	esc_html__( 'Border Color', 'wen-biz-pro' ),
			'css'     => 	'
							/* Border Color */

							.woocommerce-tabs .panel,
							.woocommerce-tabs ul.tabs li.active a:after,
							.woocommerce-tabs ul.tabs:after,
							.calendar_wrap tbody tr:first-child,
							.calendar_wrap tbody tr:last-child,
							tfoot,
							tfoot tr td,
							.author-info,
							.wpcf7 div input,
							.wpcf7 div textarea,
							.navigation-classic .main-navigation ul ul,
							.woocommerce-shorting-wrapper,
							.woocommerce-tabs ul.tabs.wc-tabs li,
							.menu-wrapper .widget_shopping_cart ul.woocommerce-mini-cart li,
							.entry-summary form.cart,
							.widget_recent_entries li,
							table,
							caption,
							th,
							td,
							table thead,
							table thead tr,
							thead th,
							select,
							table.shop_table_responsive tr td,
							table tbody tr,
							table.shop_table_responsive tbody tr:last-child,
							.shop_table tfoot tr td,
							.shop_table tfoot tr th,
							table.shop_table.woocommerce-checkout-review-order-table .cart_item td,
							table.shop_table.woocommerce-checkout-review-order-table tr td,
							table.shop_table.woocommerce-checkout-review-order-table tr th,
							.rtl tbody td:last-child,
							.rtl table thead th:last-child,
							.select2-container--default .select2-selection--single,
							table.woocommerce-grouped-product-list.group_table,
							table.woocommerce-grouped-product-list.group_table td,
							table.variations,
							table.variations td,
							.woocommerce-pagination ul.page-numbers li .page-numbers,
							.archive-content-wrap .navigation.pagination .page-numbers,
							.woocommerce-posts-wrapper .summary.entry-summary .woocommerce-product-rating,
							.cart-collaterals .order-total,
							#payment .wc_payment_methods .payment_box,
							.products .product,
							abbr,
							acronym,
							.product-quantity input[type="number"],
							.coupon input[type="text"],
							.catch-instagram-feed-gallery-widget-wrapper .button,
							.site-header-cart .widget_shopping_cart,
							.woocommerce-grouped-product-list tr,
							.mobile-social-search,
							.widget .ui-tabs .ui-tabs-panel,
							.site-header-menu .menu-inside-wrapper .nav-menu button:focus,
							header .site-header-menu .menu-inside-wrapper .main-navigation .sub-menu li:last-child,
							header .site-header-menu .menu-inside-wrapper .main-navigation .children li:last-child,
							.comment-body,
							.section:nth-child(2n-1) + .site-content,
							.site-content + .section:nth-child(2n-1),
							.archive-content-wrap .section-content-wrapper.layout-one .hentry .hentry-inner .entry-container>.entry-meta,
							.comments-area,
							.playlist-content-wrapper .wp-playlist .wp-playlist-tracks,
							.archive-post-wrap .hentry .entry-footer,
							.portfolio-content-wrapper .filter-button-group,
							.portfolio-content-wrapper .filters-select-wrap select,
							form div.fes-form fieldset,
							input[type="text"],
							input[type="email"],
							input[type="url"],
							input[type="password"],
							input[type="search"],
							input[type="number"],
							input[type="tel"],
							input[type="range"],
							input[type="date"],
							input[type="month"],
							input[type="week"],
							input[type="time"],
							input[type="datetime"],
							input[type="datetime-local"],
							input[type="color"],
							textarea,
							.wp-block-search .wp-block-search__input,
							.post-navigation,
							.comment-list > li > .children > li article,
							.comment-list > li > article,
							.sidebar .social-navigation.ct-social-widget a,
							#team-content-section .social-navigation a,
							.tagcloud a,
							.page .site-main .entry-footer .entry-meta > span:not(.edit-link) a,
							.single .site-main .entry-footer .entry-meta > span:not(.edit-link) a,
							.widget .hentry,
							.wp-calendar-table tr,
							.wp-block-social-links li a,
							.featured-content-wrapper .more-link,
							.testimonial-content-wrapper .author-thumb,
							.navigation-default #primary-menu-wrapper .menu-inside-wrapper,
							.events-content-wrapper .events-article-wrapper .hentry,
							.events-content-wrapper .hentry,
							#sticky-playlist-section,
							.hero-content-wrapper .entry-content .block-one,
							.hero-content-wrapper .entry-content .block-two,
							#footer-newsletter .tnp-widget input[type=email],
							.wp-block-table,
							.wp-block-table caption,
							.wp-block-table th,
							.wp-block-table td,
							.wp-block-table tfoot,
							.featured-content-wrapper .more-button .more-link,
							.team-content-wrapper .artist-social-profile,
							.team-contact-details,
							.pricing-section .section-content-wrapper .entry-header-wrap.has-package-price + .entry-content:before,
							.pricing-section .section-content-wrapper .entry-header-wrap.has-package-price + .entry-summary:before,
							.pricing-section .section-content-wrapper .entry-content li,
							.pricing-section .section-content-wrapper .entry-summary li  {
							    border-color: %1$s;
							}

							.is-gradient-button #testimonial-content-section .owl-nav > button.disabled {
								background-color: %1$s;
							}',
		),
		'footer_border_color'             => array(
			'label'   => 	esc_html__( 'Footer Border Color', 'wen-biz-pro' ),
			'css'     => 	'
							/* Footer Border Color */

							.site-footer table,
							.site-footer caption,
							.site-footer th,
							.site-footer td,
							.site-footer table thead,
							.site-footer table thead tr,
							.site-footer thead th,
							.site-footer select,
							.site-footer input[type="text"],
							.site-footer input[type="email"],
							.site-footer input[type="url"],
							.site-footer input[type="password"],
							.site-footer input[type="search"],
							.site-footer input[type="number"],
							.site-footer input[type="tel"],
							.site-footer input[type="range"],
							.site-footer input[type="date"],
							.site-footer input[type="month"],
							.site-footer input[type="week"],
							.site-footer input[type="time"],
							.site-footer input[type="datetime"],
							.site-footer input[type="datetime-local"],
							.site-footer input[type="color"],
							.site-footer textarea,
							.site-footer .wrapper:before,
							.site-footer .wp-block-social-links li a,
							#footer-newsletter + #colophon:before {
							    border-color: %1$s;
							}',
		),
		'custom_header_slider_text_color'              => array(
			'label'   => 	esc_html__( 'Custom Header and Slider Text Color', 'wen-biz-pro' ),
			'css'     => 	'#feature-slider-section .entry-title a,
							#feature-slider-section .section-tagline,
							#feature-slider-section .entry-meta a,
							.feature-slider-wrapper .entry-container .entry-summary,
							.feature-slider-wrapper .entry-container .entry-content,
							.feature-slider-wrapper .entry-meta span,
							.custom-header-content .section-tagline,
							.custom-header-content .entry-title,
							.custom-header-content .site-header-text,
							.custom-header-content-wrapper .section-title span,
							.custom-header-media .breadcrumb a,
							.custom-header-media .catch-breadcrumb .breadcrumb,
							#feature-slider-section .entry-meta a:hover,
							#feature-slider-section .entry-meta a:focus,
							.custom-header-media .entry-meta a,
							#feature-slider-section .owl-prev,
							#feature-slider-section .owl-next,
							.gallery-caption {
								color: %1$s;
							}

							#feature-slider-section .owl-prev,
							#feature-slider-section .owl-next {
								border-color: %1$s;
							}',
		),
		'custom_header_slider_text_hover_color'              => array(
			'label'   => 	esc_html__( 'Custom Header and Slider Text Hover Color', 'wen-biz-pro' ),
			'css'     => 	'#feature-slider-section .entry-title a:hover, #feature-slider-section .entry-title a:focus,
							#feature-slider-section .entry-meta a:hover,
							#feature-slider-section .entry-meta a:focus,
							.custom-header-media .entry-meta a:hover,
							.custom-header-media .entry-meta a:focus {
								color: %1$s;
							}',
		),
		'gradient_button_background_color_first'        => array(
			'label'       => 	esc_html__( 'Gradient Button Background Color First', 'wen-biz-pro' ),
			'is_gradient' => 	true,
			'css'         => 	'
								/* Gradient Button Background Color */

								.is-gradient-button .author-link,
								.is-gradient-button .more-button .more-link,
								.is-gradient-button button:not(.dropdown-toggle):not(.menu-toggle):not(.custom-video-button-play):not(.owl-dot),
								.is-gradient-button button[disabled]:hover,
								.is-gradient-button button[disabled]:focus,
								.is-gradient-button .button,
								.is-gradient-button .entry-summary button,
								.is-gradient-button input[type="button"],
								.is-gradient-button input[type="button"][disabled]:hover,
								.is-gradient-button input[type="button"][disabled]:focus,
								.is-gradient-button input[type="reset"],
								.is-gradient-button input[type="reset"][disabled]:hover,
								.is-gradient-button input[type="reset"][disabled]:focus,
								.is-gradient-button input[type="submit"],
								.is-gradient-button input[type="submit"][disabled]:hover,
								.is-gradient-button input[type="submit"][disabled]:focus,
								.is-gradient-button #stats-section .view-more .more-link,
								.is-gradient-button #app-section .entry-summary .more-link,
								.is-gradient-button .posts-navigation a,
								.is-gradient-button #content #infinite-handle span button,
								.is-gradient-button #hero-section .more-button .more-link,
								.is-gradient-button #promotion-content-section .more-button .more-link,
								.is-gradient-button .promotion-section .more-link,
								.is-gradient-button .woocommerce .product-container .wc-forward,
								.is-gradient-button .header-media .more-link:not(.is-ghost-button),
								.is-gradient-button #feature-slider-section .more-link,
								.is-gradient-button #testimonial-content-section .owl-nav > button,
								.is-gradient-button .wp-block-file__button,
								.is-gradient-button .wp-block-button__link,
								.is-gradient-button .pagination .page-numbers.current,
								.is-gradient-button .sticky-post span,
								.is-gradient-button .ewnewsletter .hentry form input[type="submit"],
								.is-gradient-button #footer-newsletter .tnp-widget .tnp-field-button input[type="submit"],
								.is-gradient-button .pricing-section .hentry .more-button .more-link:hover,
								.is-gradient-button .pricing-section .hentry .more-button .more-link:focus,
								.is-gradient-button .pricing-section .hentry.highlight .more-button .more-link,
								.is-gradient-button .pricing-section .section-content-wrapper .hentry.highlight .entry-content .wp-block-button .wp-block-button__link,
								.is-gradient-button .pricing-section .section-content-wrapper .hentry.highlight .entry-summary .wp-block-button .wp-block-button__link,
								.is-gradient-button .pricing-section .section-content-wrapper .hentry .entry-content .wp-block-button .wp-block-button__link:hover,
								.is-gradient-button .pricing-section .section-content-wrapper .hentry .entry-summary .wp-block-button .wp-block-button__link:hover,
								.is-gradient-button .pricing-section .section-content-wrapper .hentry .entry-content .wp-block-button .wp-block-button__link:focus,
								.is-gradient-button .pricing-section .section-content-wrapper .hentry .entry-summary .wp-block-button .wp-block-button__link:focus {
								    background-image: linear-gradient(to left, %1$s, %2$s);
								}

								button[type="submit"].search-submit.search-focused,
								.demo_store {
								    background-color: %1$s;
								}',
		),
		'gradient_button_background_color_first_next'        => array(
			'label'       => esc_html__( 'Gradient Button Background Color Second', 'wen-biz-pro' ),
			'is_gradient' => true,
		),
		'button_background_color'        => array(
			'label'   => 	esc_html__( 'Button Background Color', 'wen-biz-pro' ),
			'css'     => 	'
							/* Button Background Color */

							.author-link,
							.asc-settings,
							.button,
							.entry-content button,
							.entry-summary button,
							button,
							#scrollup,
							.slider-content-wrapper .controllers .cycle-prev,
							.slider-content-wrapper .controllers .cycle-next,
							button[type="submit"],
							input[type="submit"],
							.scrollup a,
							.wp-block-button__link,
							#infinite-handle .ctis-load-more button,
							.menu-inside-wrapper #site-header-cart-wrappe li>a,
							.woocommerce-pagination ul.page-numbers li .page-numbers.current,
							.archive-content-wrap .pagination .page-numbers.current,
							.cart-collaterals .shop_table.shop_table_responsive .cart-subtotal,
							.catch-instagram-feed-gallery-widget-wrapper .button,
							.sticky-label,
							#wen-biz-logo-slider-section .owl-dots .owl-dot,
							#wen-biz-logo-slider-section .owl-prev,
							#wen-biz-logo-slider-section .owl-next,
							.post-page-numbers.current,
							.sticky-post span,
							#hero-section .more-button .more-link,
							#promotion-content-section .more-button .more-link,
							.promotion-section .more-link,
							.pricing-section .hentry.highlight .more-button .more-link,
							.pricing-section .popular-tag,
							.woocommerce .product-container .wc-forward,
							#feature-slider-section .more-link,
							.site-footer .ewnewsletter .hentry form input[type="submit"]:hover,
							.site-footer .ewnewsletter .hentry form input[type="submit"]:focus,
							form div.fes-form .fes-submit input[type="submit"],
							.demo_store,
							.tagcloud a:hover,
							.tagcloud a:focus,
							.single .site-main .entry-footer .entry-meta > span:not(.edit-link) a:hover,
							.single .site-main .entry-footer .entry-meta > span:not(.edit-link) a:focus,
							.sidebar .widget.social-navigation a:hover,
							.sidebar .widget.social-navigation a:focus,
							.site-footer .widget.social-navigation a:hover,
							.site-footer .widget.social-navigation a:focus,
							.more-button .more-link,
							#team-content-section .social-navigation a:hover,
							#team-content-section .social-navigation a:focus,
							#testimonial-content-section .owl-nav > button,
							.wp-block-file .wp-block-file__button,
							.wp-block-search .wp-block-search__button,
							.wp-block-button .wp-block-button__link,
							blockquote.wp-block-quote:before,
							.pagination .page-numbers.current,
							.posts-navigation a,
							.ewnewsletter .hentry form input[type="submit"],
							#feature-slider-section .owl-nav button:hover,
							#feature-slider-section .owl-nav button:focus,
							.testimonial-content-section .entry-container:before,
							#gallery-section .gallery-item .gallery-icon a:before,
							#gallery-section .tiled-gallery .tiled-gallery-item a:before,
							.gallery-caption,
							#footer-newsletter .tnp-widget .tnp-field-button input[type="submit"],
							.onsale,
							.pricing-section .hentry .more-button .more-link:hover,
							.pricing-section .hentry .more-button .more-link:focus,
							.pricing-section .section-content-wrapper .hentry.highlight .entry-content .wp-block-button .wp-block-button__link,
							.pricing-section .section-content-wrapper .hentry.highlight .entry-summary .wp-block-button .wp-block-button__link,
							.pricing-section .section-content-wrapper .entry-content .wp-block-button .wp-block-button__link:hover,
							.pricing-section .section-content-wrapper .entry-content .wp-block-button .wp-block-button__link:focus,
							.pricing-section .section-content-wrapper .entry-summary .wp-block-button .wp-block-button__link:hover,
							.pricing-section .section-content-wrapper .entry-summary .wp-block-button .wp-block-button__link:focus {
							    background-color: %1$s;
							}

							.contact-details .contact svg,
							.is-style-outline > .wp-block-button__link:not(.has-text-color),
							.wp-block-button__link.is-style-outline:not(.has-text-color),
							.is-style-outline .wp-block-button__link,
							.is-style-outline .more-link,
							.is-style-outline .button,
							.archive-posts-wrapper .post-thumbnail .icon-info,
							.team-contact-details li a svg.icon.icon-envelope,
							.pricing-section .hentry .more-button .more-link,
							.is-gradient-button .pricing-section .hentry .more-button .more-link,
							.is-gradient-button .pricing-section .hentry.highlight .more-button .more-link:hover,
							.is-gradient-button .pricing-section .hentry.highlight .more-button .more-link:focus {
								color: %1$s;
							}

							.post-wrapper .entry-meta svg.icon use,
							.team-contact-details li a svg.icon use {
								fill: %1$s;
							}',
		),
		'button_background_hover_color'        => array(
			'label'   => 	esc_html__( 'Button Background Hover Color', 'wen-biz-pro' ),
			'css'     => 	'
							/* Button Background Hover Color */

							.author-link:hover,
							.author-link:focus,
							.button:hover,
							.button:focus,
							#scrollup:hover,
							#scrollup:focus,
							button:hover,
							button:focus,
							.scrollup a:hover,
							.scrollup a:focus,
							#wen-biz-logo-slider-section .owl-prev:hover,
							#wen-biz-logo-slider-section .owl-prev:focus,
							#wen-biz-logo-slider-section .owl-next:hover,
							#wen-biz-logo-slider-section .owl-next:focus,
							button[type="submit"]:hover,
							button[type="submit"]:focus,
							input[type="submit"]:hover,
							input[type="submit"]:focus,
							.wp-block-button__link:hover,
							.wp-block-button__link:focus,
							.woocommerce .products .product-container .button:hover,
							.woocommerce .products .product-container .button:focus,
							#infinite-handle .ctis-load-more button:hover,
							#infinite-handle .ctis-load-more button:focus,
							.slider-content-wrapper .cycle-next:hover,
							.slider-content-wrapper .cycle-next:focus,
							.slider-content-wrapper .cycle-prev:hover,
							.slider-content-wrapper .cycle-prev:focus,
							.woocommerce-pagination ul.page-numbers li .page-numbers:hover,
							.woocommerce-pagination ul.page-numbers li .page-numbers:focus,
							.archive-content-wrap .pagination .page-numbers:hover,
							.archive-content-wrap .pagination .page-numbers:focus,
							.catch-instagram-feed-gallery-widget-wrapper .instagram-button .button:hover,
							.catch-instagram-feed-gallery-widget-wrapper .instagram-button .button:focus,
							#hero-section .more-button .more-link:hover,
							#hero-section .more-button .more-link:focus,
							#promotion-content-section .more-button .more-link:hover,
							#promotion-content-section .more-button .more-link:focus,
							.promotion-section .more-link:hover,
							.promotion-section .more-link:focus,
							.woocommerce .product-container .wc-forward:hover,
							.woocommerce .product-container .wc-forward:focus,
							#feature-slider-section .more-link:hover,
							#feature-slider-section .more-link:focus,
							.onsale:hover,
							.onsale:focus,
							.action-buttons .button.is-ghost-button:hover,
							.action-buttons .button.is-ghost-button:focus,
							#service-section .more-button .more-link:hover,
							#service-section .more-button .more-link:focus,
							#testimonial-content-section .owl-nav > button
							.more-button .more-link:hover,
							#testimonial-content-section .owl-nav > button
							.more-button .more-link:focus,
							.is-gradient-button .more-button .more-link:hover,
							.is-gradient-button .more-button .more-link:focus,
							.is-gradient-button button:not(.dropdown-toggle):not(.menu-toggle):hover,
							.is-gradient-button button:not(.dropdown-toggle):not(.menu-toggle):focus,
							.is-gradient-button .button:hover,
							.is-gradient-button .button:focus,
							.is-gradient-button .entry-summary button:hover,
							.is-gradient-button .entry-summary button:focus,
							.is-gradient-button input[type="button"]:hover,
							.is-gradient-button input[type="button"]:focus,
							.is-gradient-button input[type="reset"]:hover,
							.is-gradient-button input[type="reset"]:focus,
							.is-gradient-button input[type="submit"]:hover,
							.is-gradient-button input[type="submit"]:focus,
							.is-gradient-button #stats-section .view-more .more-link:hover,
							.is-gradient-button #stats-section .view-more .more-link:focus,
							.is-gradient-button #app-section .entry-summary .more-link:hover,
							.is-gradient-button #app-section .entry-summary .more-link:focus,
							.is-gradient-button .posts-navigation a:hover,
							.is-gradient-button .posts-navigation a:focus,
							.is-gradient-button #content #infinite-handle span button:hover,
							.is-gradient-button #content #infinite-handle span button:focus,
							.is-gradient-button #hero-section .more-button .more-link:hover,
							.is-gradient-button #hero-section .more-button .more-link:focus,
							.is-gradient-button #promotion-content-section .more-button .more-link:hover,
							.is-gradient-button #promotion-content-section .more-button .more-link:focus,
							.is-gradient-button .promotion-section .more-link:hover,
							.is-gradient-button .promotion-section .more-link:focus,
							.is-gradient-button .woocommerce .product-container .wc-forward:hover,
							.is-gradient-button .woocommerce .product-container .wc-forward:focus,
							.is-gradient-button .header-media .more-link:not(.is-ghost-button):hover,
							.is-gradient-button .header-media .more-link:not(.is-ghost-button):focus,
							.is-gradient-button #feature-slider-section .more-link:hover,
							.is-gradient-button #feature-slider-section .more-link:focus,
							.is-gradient-button #testimonial-content-section .owl-nav > button:hover,
							.is-gradient-button #testimonial-content-section .owl-nav > button:focus,
							.is-gradient-button .wp-block-file__button:hover,
							.is-gradient-button .wp-block-file__button:focus,
							.is-gradient-button .wp-block-button__link:hover,
							.is-gradient-button .wp-block-button__link:focus,
							.wp-block-file .wp-block-file__button:hover,
							.wp-block-file .wp-block-file__button:focus,
							.wp-block-button .wp-block-button__link:hover,
							.wp-block-button .wp-block-button__link:focus,
							.ewnewsletter .hentry form input[type="submit"]:hover,
							.ewnewsletter .hentry form input[type="submit"]:focus,
							#footer-newsletter .tnp-widget .tnp-field-button input[type="submit"]:hover,
							#footer-newsletter .tnp-widget .tnp-field-button input[type="submit"]:focus,
							.promotional-video-content-wrapper .custom-video-button-play:hover,
							.promotional-video-content-wrapper .custom-video-button-play:focus,
							.site-footer .ewnewsletter .hentry form input[type="submit"]:hover,
							.site-footer .ewnewsletter .hentry form input[type="submit"]:focus {
							    background-color: %1$s;
							}',
		),
		'custom_header_button_background_color'        => array(
			'label'   => 	esc_html__( 'Custom Header Button Background Color', 'wen-biz-pro' ),
			'css'     => 	'
							/* Custom Header Button Background Color */

							.custom-header-media .more-button .more-link {
							    background-color: %1$s;
							}',
		),
		'custom_header_button_hover_background_color'        => array(
			'label'   => 	esc_html__( 'Custom Header Button Hover Background Color', 'wen-biz-pro' ),
			'css'     => 	'
							/* Custom Header Button Hover Background Color */

							.is-gradient-button .custom-header-media .more-button .more-link:hover,
							.is-gradient-button .custom-header-media .more-button .more-link:focus,
							.custom-header-media .more-button .more-link:hover,
							.custom-header-media .more-button .more-link:focus {
							    background-color: %1$s;
							}',
		),
		'button_text_color'        => array(
			'label'   => 	esc_html__( 'Button Text Color', 'wen-biz-pro' ),
			'css'     => 	'
							/* Button Text Color */

							.author-link,
							.sidebar .widget.social-navigation a:hover,
							.sidebar .widget.social-navigation a:focus,
							.site-footer .widget.social-navigation a:hover,
							.site-footer .widget.social-navigation a:focus,
							.entry-content button,
							.entry-summary button,
							.slider-content-wrapper .controllers .cycle-prev,
							.slider-content-wrapper .controllers .cycle-next,
							button,
							#scrollup,
							#primary-search-wrapper .search-container button,
							.button,
							.scroll-down,
							.scrollup a:before,
							.page-numbers:hover,
							.page-numbers:focus,
							button[type="submit"],
							input[type="submit"],
							button#wp-custom-header-video-button,
							#infinite-handle .ctis-load-more button,
							.woocommerce-pagination ul.page-numbers li:hover,
							.archive-content-wrap .pagination .page-numbers:hover,
							.archive-content-wrap .pagination .page-numbers:focus,
							.woocommerce-pagination ul.page-numbers li:focus,
							.archive-content-wrap .pagination .page-numbers.current,
							.woocommerce-pagination ul.page-numbers li .page-numbers.current,
							#portfolio-content-section .entry-container,
							.slider-content-wrapper #featured-slider-prev:hover:before,
							.slider-content-wrapper #featured-slider-next:hover:before,
							.slider-content-wrapper #featured-slider-prev:focus:before,
							.slider-content-wrapper #featured-slider-next:focus:before,
							.nav-menu .menu-item-has-children>a:hover:before,
							.nav-menu .menu-item-has-children>a:focus:before,
							.nav-menu .menu_item_has_children>a:hover:before,
							.nav-menu .menu_item_has_children>a:focus:before,
							.cart-collaterals .shop_table.shop_table_responsive .cart-subtotal,
							.post-page-numbers.current,
							.sticky-post span,
							#hero-section .more-button .more-link,
							#promotion-content-section .more-button .more-link,
							.promotion-section .more-link,
							.pricing-section .hentry.highlight .more-button .more-link,
							.pricing-section .popular-tag,
							.woocommerce .product-container .wc-forward,
							#feature-slider-section .more-link,
							.ewnewsletter .hentry form input[type="submit"]:hover,
							.ewnewsletter .hentry form input[type="submit"]:focus,
							.site-footer .ewnewsletter .hentry form input[type="submit"]:hover,
							.site-footer .ewnewsletter .hentry form input[type="submit"]:focus,
							form div.fes-form .fes-submit input[type="submit"],
							.demo_store .woocommerce-store-notice__dismiss-link,
							.demo_store,
							.tagcloud a:hover,
							.tagcloud a:focus,
							.single .site-main .entry-footer .entry-meta > span:not(.edit-link) a:hover,
							.single .site-main .entry-footer .entry-meta > span:not(.edit-link) a:focus,
							.more-button .more-link,
							#team-content-section .social-navigation a:hover,
							#team-content-section .social-navigation a:focus,
							#testimonial-content-section .owl-nav > button,
							.wp-block-file .wp-block-file__button,
							.wp-block-search .wp-block-search__button,
							.wp-block-button .wp-block-button__link,
							blockquote.wp-block-quote:before,
							.pagination .page-numbers.current,
							.ewnewsletter .hentry form input[type="submit"],
							#footer-newsletter .tnp-widget .tnp-field-button input[type="submit"],
							.testimonial-content-section .entry-container:before,
							.onsale,
							.pricing-section .section-content-wrapper .hentry.highlight .entry-content .wp-block-button .wp-block-button__link,
							.pricing-section .section-content-wrapper .hentry.highlight .entry-summary .wp-block-button .wp-block-button__link {
							    color: %1$s;
							}

							.absolute-header .bars {
							    background-color: %1$s;
							}',
		),
		'gradient_button_text_color'        => array(
			'label'   => 	esc_html__( 'Gradient Button Text Color', 'wen-biz-pro' ),
			'css'     => 	'
							/* Gradient Button Text Color */

							.is-gradient-button .author-link,
							.is-gradient-button .more-button .more-link,
							.is-gradient-button button:not(.dropdown-toggle):not(.menu-toggle):not(.custom-video-button-play),
							.is-gradient-button button[disabled]:hover,
							.is-gradient-button button[disabled]:focus,
							.is-gradient-button .button,
							.is-gradient-button .entry-summary button,
							.is-gradient-button input[type="button"],
							.is-gradient-button input[type="button"][disabled]:hover,
							.is-gradient-button input[type="button"][disabled]:focus,
							.is-gradient-button input[type="reset"],
							.is-gradient-button input[type="reset"][disabled]:hover,
							.is-gradient-button input[type="reset"][disabled]:focus,
							.is-gradient-button input[type="submit"],
							.is-gradient-button input[type="submit"][disabled]:hover,
							.is-gradient-button input[type="submit"][disabled]:focus,
							.is-gradient-button #stats-section .view-more .more-link,
							.is-gradient-button #app-section .entry-summary .more-link,
							.is-gradient-button .posts-navigation a,
							.is-gradient-button #content #infinite-handle span button,
							.is-gradient-button #hero-section .more-button .more-link,
							.is-gradient-button #promotion-content-section .more-button .more-link,
							.is-gradient-button .promotion-section .more-link,
							.is-gradient-button .woocommerce .product-container .wc-forward,
							.is-gradient-button .header-media .more-link:not(.is-ghost-button),
							.is-gradient-button #feature-slider-section .more-link,
							.is-gradient-button #testimonial-content-section .owl-nav > button,
							.is-gradient-button .wp-block-file__button,
							.is-gradient-button .wp-block-button__link {
							    color: %1$s;
							}',
		),
		'button_hover_text_color'        => array(
			'label'   => 	esc_html__( 'Button Hover Text Color', 'wen-biz-pro' ),
			'css'     => 	'
							/* Button Hover Text Color */

							.author-link:hover,
							.author-link:focus,
							button:hover,
							button:focus,
							.button:hover,
							.button:focus,
							.entry-content button:hover,
							.entry-content button:focus,
							.entry-summary button:hover,
							.entry-summary button:focus,
							input[type="submit"]:hover,
							input[type="submit"]:focus,
							button[type="submit"]:hover,
							button[type="submit"]:focus,
							#primary-search-wrapper .search-container button:hover,
							#primary-search-wrapper .search-container button:focus,
							#infinite-handle .ctis-load-more button:hover,
							#infinite-handle .ctis-load-more button:focus,
							.catch-instagram-feed-gallery-widget-wrapper .instagram-button .button:hover,
							.catch-instagram-feed-gallery-widget-wrapper .instagram-button .button:focus,
							.catch-instagram-feed-gallery-widget-wrapper .instagram-button .button:hover,
							.catch-instagram-feed-gallery-widget-wrapper .instagram-button .button:focus,
							#wen-biz-logo-slider-section .owl-prev:hover,
							#wen-biz-logo-slider-section .owl-prev:focus,
							#wen-biz-logo-slider-section .owl-next:hover,
							#wen-biz-logo-slider-section .owl-next:focus,
							#scrollup:hover,
							#scrollup:focus,
							#hero-section .more-button .more-link:hover,
							#hero-section .more-button .more-link:focus,
							#promotion-content-section .more-button .more-link:hover,
							#promotion-content-section .more-button .more-link:focus,
							.promotion-section .more-link:hover,
							.promotion-section .more-link:focus,
							.woocommerce .product-container .wc-forward:hover,
							.woocommerce .product-container .wc-forward:focus,
							#feature-slider-section .more-link:hover,
							#feature-slider-section .more-link:focus,
							.onsale:hover,
							.onsale:focus,
							.action-buttons .button.is-ghost-button:hover,
							.action-buttons .button.is-ghost-button:focus,
							form div.fes-form .fes-submit input[type="submit"]:hover,
							form div.fes-form .fes-submit input[type="submit"]:focus,
							#service-section .more-button .more-link:hover,
							#service-section .more-button .more-link:focus,
							#testimonial-content-section .owl-nav > button
							.more-button .more-link:hover,
							#testimonial-content-section .owl-nav > button
							.more-button .more-link:focus,
							.is-gradient-button .more-button .more-link:hover,
							.is-gradient-button .more-button .more-link:focus,
							.is-gradient-button button:not(.dropdown-toggle):not(.menu-toggle):hover,
							.is-gradient-button button:not(.dropdown-toggle):not(.menu-toggle):focus,
							.is-gradient-button .button:hover,
							.is-gradient-button .button:focus,
							.is-gradient-button .entry-summary button:hover,
							.is-gradient-button .entry-summary button:focus,
							.is-gradient-button input[type="button"]:hover,
							.is-gradient-button input[type="button"]:focus,
							.is-gradient-button input[type="reset"]:hover,
							.is-gradient-button input[type="reset"]:focus,
							.is-gradient-button input[type="submit"]:hover,
							.is-gradient-button input[type="submit"]:focus,
							.is-gradient-button #stats-section .view-more .more-link:hover,
							.is-gradient-button #stats-section .view-more .more-link:focus,
							.is-gradient-button #app-section .entry-summary .more-link:hover,
							.is-gradient-button #app-section .entry-summary .more-link:focus,
							.is-gradient-button .posts-navigation a:hover,
							.is-gradient-button .posts-navigation a:focus,
							.is-gradient-button #content #infinite-handle span button:hover,
							.is-gradient-button #content #infinite-handle span button:focus,
							.is-gradient-button #hero-section .more-button .more-link:hover,
							.is-gradient-button #hero-section .more-button .more-link:focus,
							.is-gradient-button #promotion-content-section .more-button .more-link:hover,
							.is-gradient-button #promotion-content-section .more-button .more-link:focus,
							.is-gradient-button .promotion-section .more-link:hover,
							.is-gradient-button .promotion-section .more-link:focus,
							.is-gradient-button .woocommerce .product-container .wc-forward:hover,
							.is-gradient-button .woocommerce .product-container .wc-forward:focus,
							.is-gradient-button .header-media .more-link:not(.is-ghost-button):hover,
							.is-gradient-button .header-media .more-link:not(.is-ghost-button):focus,
							.is-gradient-button #feature-slider-section .more-link:hover,
							.is-gradient-button #feature-slider-section .more-link:focus,
							.is-gradient-button #testimonial-content-section .owl-nav > button:hover,
							.is-gradient-button #testimonial-content-section .owl-nav > button:focus,
							.is-gradient-button .wp-block-file__button:hover,
							.is-gradient-button .wp-block-file__button:focus,
							.is-gradient-button .wp-block-button__link:hover,
							.is-gradient-button .wp-block-button__link:focus,
							.is-gradient-button .wp-block-button__link:hover,
							.is-gradient-button .wp-block-button__link:focus,
							.wp-block-file .wp-block-file__button:hover,
							.wp-block-file .wp-block-file__button:focus,
							.wp-block-button .wp-block-button__link:hover,
							.wp-block-button .wp-block-button__link:focus,
							.promotional-video-content-wrapper .custom-video-button-play:hover,
							.promotional-video-content-wrapper .custom-video-button-play:focus,
							.pricing-section .hentry .more-button .more-link:hover,
							.pricing-section .hentry .more-button .more-link:focus {
							    color: %1$s;
							}',
		),
		'custom_header_button_text_color'        => array(
			'label'   => 	esc_html__( 'Custom Header Button Text Color', 'wen-biz-pro' ),
			'css'     => 	'
							/* Custom Header Button Text Color */

							.is-gradient-button .custom-header-media .more-button .more-link,
							.custom-header-media .more-button .more-link {
							    color: %1$s;
							}',
		),
		'custom_header_button_hover_text_color'        => array(
			'label'   => 	esc_html__( 'Custom Header Button Hover Text Color', 'wen-biz-pro' ),
			'css'     => 	'
							/* Custom Header Button Hover Text Color */

							.is-gradient-button .custom-header-media .more-button .more-link:hover,
							.is-gradient-button .custom-header-media .more-button .more-link:focus,
							.custom-header-media .more-button .more-link:hover,
							.custom-header-media .more-button .more-link:focus {
							    color: %1$s;
							}',
		),
		'footer_text_color'        => array(
			'label'       => 	esc_html__( 'Footer Text Color', 'wen-biz-pro' ),
			'is_rgba' 	  => true,
			'css'         => 	'
								/* Footer Text Color */

								.site-footer h1,
								.site-footer h2,
								.site-footer h3,
								.site-footer h4,
								.site-footer h5,
								.site-footer h6,
								.footer-widget-area a,
							   .footer-widget-area .widget-title,
							   .site-footer .widget .wp-block-group h2,
							   #social-footer-navigation li a,
							   .site-info a,
							   .footer-newsletter .section-title,
							   #footer-newsletter .ew-newsletter,
							   #footer-newsletter .tnp-widget label {
								    color: %1$s;
								}

								.site-footer input[type="text"]:focus,
								.site-footer input[type="email"]:focus,
								.site-footer input[type="url"]:focus,
								.site-footer input[type="password"]:focus,
								.site-footer input[type="search"]:focus,
								.site-footer input[type="number"]:focus,
								.site-footer input[type="tel"]:focus,
								.site-footer input[type="range"]:focus,
								.site-footer input[type="date"]:focus,
								.site-footer input[type="month"]:focus,
								.site-footer input[type="week"]:focus,
								.site-footer input[type="time"]:focus,
								.site-footer input[type="datetime"]:focus,
								.site-footer input[type="datetime-local"]:focus,
								.site-footer input[type="color"]:focus,
								.site-footer textarea:focus,
								.site-footer td#today {
									border-color: rgba(%2$s, %3$s, %4$s, 0.6);
								}

								.site-info,
								#site-footer-navigation li a,
								.footer-widget-area .widget,
								.footer-widget-area ul li a,
								.site-footer input::placeholder,
								#footer-newsletter input::placeholder,
								.site-footer input[type="text"],
								.site-footer input[type="email"],
								.site-footer input[type="url"],
								.site-footer input[type="password"],
								.site-footer input[type="search"],
								.site-footer input[type="number"],
								.site-footer input[type="tel"],
								.site-footer input[type="range"],
								.site-footer input[type="date"],
								.site-footer input[type="month"],
								.site-footer input[type="week"],
								.site-footer input[type="time"],
								.site-footer input[type="datetime"],
								.site-footer input[type="datetime-local"],
								.site-footer input[type="color"],
								.site-footer textarea {
									color: rgba(%2$s, %3$s, %4$s, 0.6);
								}',
		),
		'white_text_color'        => array(
			'label'       => 	esc_html__( 'White Text Color', 'wen-biz-pro' ),
			'css'         => 	'
								/* White Text Color */

								ins,
								.scroll-down,
								.has-background-image .entry-container,
								.portfolio-content-wrapper .hentry .entry-container a,
								.portfolio-content-wrapper .hentry .entry-container .entry-summary,
								.ewnewsletter.has-background-image .section-title,
								.testimonials-content-wrapper.section.testimonial-wrapper.has-background-image .hentry,
								.testimonials-content-wrapper.section.testimonial-wrapper.has-background-image .position,
								.playlist-content-wrapper .wen-biz-mejs-container.mejs-container button,
								.playlist-content-wrapper .wp-playlist-current-item,
								.has-background-image .section-title,
								.has-background-image .section-tagline,
								.has-background-image .section-description,
								.has-background-image .entry-container .entry-meta a,
								.has-background-image .entry-container .entry-title a,
								.has-background-image .entry-container .entry-title,
								.has-background-image .entry-container .entry-title span,
								.has-background-image .entry-container .entry-summary,
								.has-background-image .entry-container .entry-content,
								.has-background-image .woocommerce-loop-product__title,
								.content-color-white .entry-container .entry-title a,
								.content-color-white .entry-container .entry-title,
								.content-color-white .entry-container .section-title,
								.content-color-white .entry-container .entry-content,
								.content-color-white .entry-container .entry-summary,
								.content-color-white .section-description,
								.has-background-image .products .button,
								#feature-slider-section .owl-nav button:hover:before,
								#feature-slider-section .owl-nav button:focus:before,
								.playlist-content-wrapper .wp-playlist-caption:hover,
								.playlist-content-wrapper .wp-playlist-caption:focus,
								.play-button-text,
								#feature-slider-section .owl-dot,
								#app-section.content-color-white .entry-container .entry-content,
								.events-content-wrapper .entry-meta a,
								#playlist-section .playlist-content-wrapper .mejs-time,
								.header-top-bar,
								.header-top-bar .contact-details li a,
								.header-top-bar .menu-toggle,
								.header-top-right .social-links-menu a,
								.service-section,
								.service-section .section-tagline,
								.service-section .section-title,
								.service-section .entry-title a,
								#promotional-headline-section .entry-content ul li:before,
								#promotional-headline-section .entry-summary ul li:before,
								ins,
								ins span.woocommerce-Price-amount,
								.pricing-content-wrapper .entry-header .entry-title a {
								    color: %1$s;
								}',
		),
	);

	return apply_filters( 'wen_biz_color_options', $color_options );
}

/**
 * Registers color schemes for Zubin.
 *
 * Can be filtered with {@see 'wen_biz_color_schemes'}.
 *
 * The order of colors in a colors array:
 * 1. Background Color
 * 2. Header Text Color
 * 3. Page Background Color
 * 4. Secondary Background Color
 * 5. Absolute Header Background Color
 * 6. Main Text Color
 * 7. Headline Text Color
 * 8. Tertiary Background
 * 9. Link Color
 * 10. Link Hover Color
 * 11. Secondary Link Color
 * 12. Button Background Color
 * 13. Button Text Color
 * 14. Header and Tertiary Color
 * 15. Button Hover Text Color
 * 16. Button Hover Background Color
 * 17. Blog Background Odd
 * 18. Blog Background Even
 * 19. Blog Background Even Color
 * 20. Border Color
 * 21. Text Color With Background

 *
 * @since 1.0
 *
 * @return array An associative array of color scheme options.
 */
function wen_biz_get_color_schemes() {
	/**
	 * Filter the color schemes registered for use with Zubin.
	 *
	 * The default schemes include 'default', 'dark', 'gray', 'red', and 'yellow'.
	 *
	 * @since 1.0
	 *
	 * @param array $schemes {
	 *     Associative array of color schemes data.
	 *
	 *     @type array $slug {
	 *         Associative array of information for setting up the color scheme.
	 *
	 *         @type string $label  Color scheme label.
	 *         @type array  $colors HEX codes for default colors prepended with a hash symbol ('#').
	 *                              Colors are defined in the following order: Main background, page
	 *                              background, link, main text, secondary text.
	 *     }
	 * }
	 */
	return apply_filters( 'wen_biz_color_schemes', array(
		'default' => array(
			'label'  => esc_html__( 'Default', 'wen-biz-pro' ),
			'colors' => array(
				'header_textcolor' 										=> '#202020', /* Header Text Color */
				'background_color'         								=> '#ffffff', /* Body Background Color */
				'page_background_color'         						=> '#ffffff', /* Page Background Color */
				'secondary_background_color'            				=> '#f8f8f8', /* Secondary Background Color */
				'tertiary_background_color'            				    => '#1c202d', /* Tertiary Background Color */
				'header_top_background_color'            				=> '#2d3242', /* Header Top Background Color */
				'service_block_background_color'            			=> '#3b3e52', /* Service Block Background Color */
				'main_text_color'             							=> '#333333', /* Main Text Color */
				'heading_text_color'      								=> '#202020', /* Heading Text Color */
				'link_color'  											=> '#e75f41', /* Link Color  */
				'secondary_link_color'              					=> '#202020', /* Secondary Link Color */
				'link_hover_color'    									=> '#000000', /* Link Hover Color */
				'secondary_link_hover_color'    						=> '#e75f41', /* Secondary Link Hover Color */
				'border_color'             								=> '#ebebeb', /* Border Color */
				'footer_border_color'             						=> '#4A4E5A', /* Footer Border Color */
				'custom_header_slider_text_color'        				=> '#ffffff', /* Custom Header and Slider Color */
				'custom_header_slider_text_hover_color'        			=> '#e75f41', /* Custom Header and Slider Text Hover Color */
				'gradient_button_background_color_first'       			=> '#e86a3d', /* Gradient Button Background Color First */
				'gradient_button_background_color_first_next'   		=> '#e75743', /* Gradient Button Background Color Second */
				'button_background_color'        						=> '#e75743', /* Button Background Text Color */
				'button_background_hover_color'        					=> '#333333', /* Button Background Hover Color */
				'custom_header_button_background_color'        			=> '#e75743', /* Custom Header Button Background Text Color */
				'custom_header_button_hover_background_color'        	=> '#333333', /* Custom Header Button Hover Background Text Color */
				'button_text_color'        								=> '#ffffff', /* Button Text Color */
				'gradient_button_text_color'        					=> '#ffffff', /* Gradient Button Text Color */
				'custom_header_button_text_color'        				=> '#ffffff', /* Custom Header Button Text Color */
				'custom_header_button_hover_text_color'        			=> '#ffffff', /* Custom Header Button Hover Text Color */
				'button_hover_text_color'        						=> '#ffffff', /* Button Hover Text Color */
				'footer_text_color'        								=> '#ffffff', /* Footer Text Color */
				'white_text_color'        								=> '#ffffff', /* White Text Color */
			),
		),
		'dark' => array(/* Dark */
			'label'  => esc_html__( 'Dark', 'wen-biz-pro' ),
			'colors' => array(
				'header_textcolor' 										=> '#ffffff', /* Header Text Color */
				'background_color'         								=> '#000000', /* Body Background Color */
				'page_background_color'         						=> '#000000', /* Page Background Color */
				'secondary_background_color'            				=> '#1e1e1e', /* Secondary Background Color */
				'tertiary_background_color'            				    => '#222222', /* Tertiary Background Color */
				'header_top_background_color'            				=> '#181818', /* Header Top Background Color */
				'service_block_background_color'            			=> '#000000', /* Service Block Background Color */
				'main_text_color'             							=> '#999999', /* Main Text Color */
				'heading_text_color'      								=> '#ffffff', /* Heading Text Color */
				'link_color'  											=> '#e75f41', /* Link Color  */
				'secondary_link_color'              					=> '#ffffff', /* Secondary Link Color */
				'link_hover_color'    									=> '#ffffff', /* Link Hover Color */
				'secondary_link_hover_color'    						=> '#e75f41', /* Secondary Link Hover Color */
				'border_color'             								=> '#282828', /* Border Color */
				'footer_border_color'             						=> '#4A4E5A', /* Footer Border Color */
				'custom_header_slider_text_color'        				=> '#ffffff', /* Custom Header and Slider Color */
				'custom_header_slider_text_hover_color'        			=> '#e75f41', /* Custom Header and Slider Text Hover Color */
				'gradient_button_background_color_first'       			=> '#e86a3d', /* Gradient Button Background Color First */
				'gradient_button_background_color_first_next'   		=> '#e75743', /* Gradient Button Background Color Second */
				'button_background_color'        						=> '#e75743', /* Button Background Text Color */
				'button_background_hover_color'        					=> '#333333', /* Button Background Hover Color */
				'custom_header_button_background_color'        			=> '#e75743', /* Custom Header Button Background Text Color */
				'custom_header_button_hover_background_color'        	=> '#333333', /* Custom Header Button Hover Background Text Color */
				'button_text_color'        								=> '#ffffff', /* Button Text Color */
				'gradient_button_text_color'        					=> '#ffffff', /* Gradient Button Text Color */
				'custom_header_button_text_color'        				=> '#ffffff', /* Custom Header Button Text Color */
				'custom_header_button_hover_text_color'        			=> '#ffffff', /* Custom Header Button Hover Text Color */
				'button_hover_text_color'        						=> '#ffffff', /* Button Hover Text Color */
				'footer_text_color'        								=> '#ffffff', /* Footer Text Color */
				'white_text_color'        								=> '#ffffff', /* White Text Color */
			),
		),
		'red' => array(
			'label'  => esc_html__( 'Red', 'wen-biz-pro' ),
			'colors' => array(
				'header_textcolor' 										=> '#ffffff', /* Header Text Color */
				'background_color'         								=> '#b32134', /* Body Background Color */
				'page_background_color'         						=> '#b32134', /* Page Background Color */
				'secondary_background_color'            				=> '#a71628', /* Secondary Background Color */
				'tertiary_background_color'            				    => '#222222', /* Tertiary Background Color */
				'header_top_background_color'            				=> '930518', /* Header Top Background Color */
				'service_block_background_color'            			=> '#b32134', /* Service Block Background Color */
				'main_text_color'             							=> '#cecece', /* Main Text Color */
				'heading_text_color'      								=> '#ffffff', /* Heading Text Color */
				'link_color'  											=> '#e75f41', /* Link Color  */
				'secondary_link_color'              					=> '#cccccc', /* Secondary Link Color */
				'link_hover_color'    									=> '#ffffff', /* Link Hover Color */
				'secondary_link_hover_color'    						=> '#e75f41', /* Secondary Link Hover Color */
				'border_color'             								=> '#c9374a', /* Border Color */
				'footer_border_color'             						=> '#4A4E5A', /* Footer Border Color */
				'custom_header_slider_text_color'        				=> '#ffffff', /* Custom Header and Slider Color */
				'custom_header_slider_text_hover_color'        			=> '#e75f41', /* Custom Header and Slider Text Hover Color */
				'gradient_button_background_color_first'       			=> '#e86a3d', /* Gradient Button Background Color First */
				'gradient_button_background_color_first_next'   		=> '#e75743', /* Gradient Button Background Color Second */
				'button_background_color'        						=> '#e75743', /* Button Background Text Color */
				'button_background_hover_color'        					=> '#333333', /* Button Background Hover Color */
				'custom_header_button_background_color'        			=> '#e75743', /* Custom Header Button Background Text Color */
				'custom_header_button_hover_background_color'        	=> '#333333', /* Custom Header Button Hover Background Text Color */
				'button_text_color'        								=> '#ffffff', /* Button Text Color */
				'gradient_button_text_color'        					=> '#ffffff', /* Gradient Button Text Color */
				'custom_header_button_text_color'        				=> '#ffffff', /* Custom Header Button Text Color */
				'custom_header_button_hover_text_color'        			=> '#ffffff', /* Custom Header Button Hover Text Color */
				'button_hover_text_color'        						=> '#ffffff', /* Button Hover Text Color */
				'footer_text_color'        								=> '#ffffff', /* Footer Text Color */
				'white_text_color'        								=> '#ffffff', /* White Text Color */
			),
		),
		'blue' => array(
			'label'  => esc_html__( 'Blue', 'wen-biz-pro' ),
			'colors' => array(
				'header_textcolor' 										=> '#ffffff', /* Header Text Color */
				'background_color'         								=> '#176b99', /* Body Background Color */
				'page_background_color'         						=> '#176b99', /* Page Background Color */
				'secondary_background_color'            				=> '#085c8a', /* Secondary Background Color */
				'tertiary_background_color'            				    => '#222222', /* Tertiary Background Color */
				'header_top_background_color'            				=> '#063b58', /* Header Top Background Color */
				'service_block_background_color'            			=> '#176b99', /* Service Block Background Color */
				'main_text_color'             							=> '#cccccc', /* Main Text Color */
				'heading_text_color'      								=> '#ffffff', /* Heading Text Color */
				'link_color'  											=> '#fd8271', /* Link Color  */
				'secondary_link_color'              					=> '#dddddd', /* Secondary Link Color */
				'link_hover_color'    									=> '#ffffff', /* Link Hover Color */
				'secondary_link_hover_color'    						=> '#fd8271', /* Secondary Link Hover Color */
				'border_color'             								=> '#3185b3', /* Border Color */
				'footer_border_color'             						=> '#4A4E5A', /* Footer Border Color */
				'custom_header_slider_text_color'        				=> '#ffffff', /* Custom Header and Slider Color */
				'custom_header_slider_text_hover_color'        			=> '#e75f41', /* Custom Header and Slider Text Hover Color */
				'gradient_button_background_color_first'       			=> '#e86a3d', /* Gradient Button Background Color First */
				'gradient_button_background_color_first_next'   		=> '#e75743', /* Gradient Button Background Color Second */
				'button_background_color'        						=> '#e75743', /* Button Background Text Color */
				'button_background_hover_color'        					=> '#333333', /* Button Background Hover Color */
				'custom_header_button_background_color'        			=> '#e75743', /* Custom Header Button Background Text Color */
				'custom_header_button_hover_background_color'        	=> '#333333', /* Custom Header Button Hover Background Text Color */
				'button_text_color'        								=> '#ffffff', /* Button Text Color */
				'gradient_button_text_color'        					=> '#ffffff', /* Gradient Button Text Color */
				'custom_header_button_text_color'        				=> '#ffffff', /* Custom Header Button Text Color */
				'custom_header_button_hover_text_color'        			=> '#ffffff', /* Custom Header Button Hover Text Color */
				'button_hover_text_color'        						=> '#ffffff', /* Button Hover Text Color */
				'footer_text_color'        								=> '#ffffff', /* Footer Text Color */
				'white_text_color'        								=> '#ffffff', /* White Text Color */
			),
		),
	) );
}

if ( ! function_exists( 'wen_biz_get_color_scheme' ) ) :
/**
 * Retrieves the current Zubin color scheme.
 *
 * Create your own wen_biz_get_color_scheme() function to override in a child theme.
 *
 * @since 1.0
 *
 * @return array An associative array of either the current or default color scheme HEX values.
 */
function wen_biz_get_color_scheme() {
	$color_scheme_option = get_theme_mod( 'color_scheme', 'default' );
	$color_schemes       = wen_biz_get_color_schemes();

	if ( array_key_exists( $color_scheme_option, $color_schemes ) ) {
		return $color_schemes[ $color_scheme_option ]['colors'];
	}

	return $color_schemes['default']['colors'];
}
endif; // wen_biz_get_color_scheme

if ( ! function_exists( 'wen_biz_get_color_scheme_choices' ) ) :
	/**
	 * Retrieves an array of color scheme choices registered for Zubin.
	 *
	 * Create your own wen_biz_get_color_scheme_choices() function to override
	 * in a child theme.
	 *
	 * @since 1.0
	 *
	 * @return array Array of color schemes.
	 */
	function wen_biz_get_color_scheme_choices() {
		$color_schemes                = wen_biz_get_color_schemes();
		$color_scheme_control_options = array();

		foreach ( $color_schemes as $color_scheme => $value ) {
			$color_scheme_control_options[ $color_scheme ] = $value['label'];
		}

		return $color_scheme_control_options;
	}
endif; // wen_biz_get_color_scheme_choices

/**
 * Binds the JS listener to make Customizer color_scheme control.
 *
 * Passes color scheme data as colorScheme global.
 *
 * @since 1.0
 */
function wen_biz_customize_control_js() {
	$min  = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

	wp_enqueue_script( 'wen-biz-color-scheme-control', trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'js/color-scheme-control' . $min . '.js', array( 'customize-controls', 'iris', 'underscore', 'wp-util' ), '20170816', true );

	$colors['colorScheme'] = wen_biz_get_color_schemes();

	$color_options = wen_biz_color_options();

    $color_options = array_merge( array( 'background_color', 'header_textcolor' ), array_keys( $color_options ) );

	$colors['colorOptions'] = $color_options;

	wp_localize_script( 'wen-biz-color-scheme-control', 'wenBizColorMain', $colors );

	wp_enqueue_script( 'wen-biz-custom-controls', trailingslashit( esc_url( get_template_directory_uri() ) ) . 'js/customize-custom-controls' . $min . '.js', array( 'jquery-ui-sortable' ), '20180802', true );

	wp_enqueue_style( 'wen-biz-custom-controls-css', trailingslashit( esc_url( get_template_directory_uri() ) ) . 'css/customizer.css' );
}
add_action( 'customize_controls_enqueue_scripts', 'wen_biz_customize_control_js' );

/**
 * Enqueues front-end CSS for custom colors.
 *
 * @since 1.0
 *
 * @see wp_add_inline_style()
 */
function wen_biz_all_color_css() {
	$color_schemes  = wen_biz_get_color_schemes();
	$color_scheme  = $color_schemes['default']['colors'];

	$css = '';

	$colors = wen_biz_color_options();

	$next = '';

	foreach ( $colors as $key => $color ) {
		if ( $next === $key ) {
			// Bail the loop if $next is encountered as its value is next value for gradient and it has already been used.
			continue;
		}

		$default_color = $color_scheme[ $key ];

		$value = get_theme_mod( $key, $default_color );

		if ( isset( $color['is_rgba'] ) && $color['is_rgba'] ) {
			if ( $value === $default_color ) {
				continue;
			}

			$value_rgba = wen_biz_hex2rgb( $value );

			$css .= sprintf( $color['css'], esc_attr( $value ), $value_rgba['red'], $value_rgba['green'], $value_rgba['blue'] );
		} elseif ( isset( $color['is_gradient'] ) && $color['is_gradient'] ) {
			$next = $key . '_next';

			$default_color2 = $color_scheme[ $next  ];

			$value2 = get_theme_mod( $next, $default_color2 );

			if ( $value === $default_color && $value2 === $default_color2 ) {
				continue;
			}

			$css .= sprintf( $color['css'], esc_attr( $value ), esc_attr( $value2 ) );
		} else {
			if ( $value === $default_color ) {
				continue;
			}

			$css .= sprintf( $color['css'], esc_attr( $value ) );
		}
	}

	if ( $css ) {
		wp_add_inline_style( 'wen-biz-block-style', $css );
	}
}
add_action( 'wp_enqueue_scripts', 'wen_biz_all_color_css', 11 );

/**
 * Enqueues front-end CSS for the Contact and Newsletter background color
 *
 * @since 1.0
 *
 * @see wp_add_inline_style()
 */

/**
 * Converts a HEX value to RGB.
 *
 * @since 1.0
 *
 * @param string $color The original color, in 3- or 6-digit hexadecimal form.
 * @return array Array containing RGB (red, green, and blue) values for the given
 *               HEX code, empty array otherwise.
 */
function wen_biz_hex2rgb( $color ) {
	$color = trim( $color, '#' );

	if ( strlen( $color ) === 3 ) {
		$r = hexdec( substr( $color, 0, 1 ).substr( $color, 0, 1 ) );
		$g = hexdec( substr( $color, 1, 1 ).substr( $color, 1, 1 ) );
		$b = hexdec( substr( $color, 2, 1 ).substr( $color, 2, 1 ) );
	} else if ( strlen( $color ) === 6 ) {
		$r = hexdec( substr( $color, 0, 2 ) );
		$g = hexdec( substr( $color, 2, 2 ) );
		$b = hexdec( substr( $color, 4, 2 ) );
	} else {
		return array();
	}

	return array( 'red' => $r, 'green' => $g, 'blue' => $b );
}
