<?php
/**
 * Theme Customizer
 *
 * @package Wen_Biz
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function wen_biz_color_scheme_register( $wp_customize ) {
	global $wp_customize;
	//Color Scheme
	$color_scheme = wen_biz_get_color_scheme();

	// Add color scheme setting and control.
	wen_biz_register_option( $wp_customize, array(
			'name'              => 'color_scheme',
			'default'           => 'default',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'transport'         => 'postMessage',
			'label'             => esc_html__( 'Color Scheme', 'wen-biz-pro' ),
			'section'           => 'colors',
			'type'              => 'select',
			'choices'           => wen_biz_get_color_scheme_choices(),
			'priority'          => 2,
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_gradient_button',
			'default'			=> 1,
			'sanitize_callback' => 'wen_biz_sanitize_checkbox',
			'label'             => esc_html__('Gradient Button', 'wen-biz-pro'),
			'section'           => 'colors',
			'custom_control'    => 'Wen_Biz_Toggle_Control',
			'priority'          => 14,
		)
	);

	$color_options = wen_biz_color_options();

	foreach ( $color_options as $key => $value ) {
		wen_biz_register_option( $wp_customize, array(
				'name'              => $key,
				'default'           => $color_scheme[ $key ],
				'sanitize_callback' => 'sanitize_hex_color',
				'transport'         => 'postMessage',
				'custom_control'    => 'WP_Customize_Color_Control',
				'label'             => $value['label'],
				'section'           => 'colors',
			)
		);
	}

	// Rename default Colors section
	$wp_customize->get_control( 'background_color' )->description = esc_html__( '(This option changes body background color only when Fluid Layout is enabled. )', 'wen-biz-pro' );

	$wp_customize->get_control( 'page_background_color' )->description = esc_html__( '(This option changes background color of input fields, fullscreen menu toggle, #page when boxed layout enabled, search background, etc...  )', 'wen-biz-pro' );

	$wp_customize->get_control( 'secondary_background_color' )->description = esc_html__( '(This option changes background color of sidebar widget, custom header, some sections, footer inputs, etc...)', 'wen-biz-pro' );

	$wp_customize->get_control( 'main_text_color' )->description = esc_html__( '(This option changes whole body text color.)', 'wen-biz-pro' );
	$wp_customize->get_control('gradient_button_background_color_first')->active_callback = 'wen_biz_is_gradient_button_enabled';
	$wp_customize->get_control('gradient_button_background_color_first_next')->active_callback = 'wen_biz_is_gradient_button_enabled';
	$wp_customize->get_control('gradient_button_background_color_first')->priority = 15;
	$wp_customize->get_control('gradient_button_background_color_first_next')->priority = 15;
}
add_action( 'customize_register', 'wen_biz_color_scheme_register' );

/** Active Callback Functions */

if ( ! function_exists('wen_biz_is_gradient_button_enabled') ) :
	/**
	 * Return true if gradient button is enabled
	 *
	 * @since Wen Travel Pro 5.0
	 */
	function wen_biz_is_gradient_button_enabled( $control )
	{
		return ($control->manager->get_setting( 'wen_biz_gradient_button' )->value() ? true : false);
	}
endif;
