<?php
/**
 * Reservation options
 *
 * @package Wen_Biz
 */

/**
 * Add Contact options to theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function wen_biz_contact_options( $wp_customize ) {
    $wp_customize->add_section( 'wen_biz_contact', array(
			'title' => esc_html__( 'Contact Form', 'wen-biz-pro' ),
			'panel' => 'wen_biz_theme_options',
		)
	);

	// Contact Form Start.
	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_contact_form_option',
			'default'           => 'disabled',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'choices'           => wen_biz_section_visibility_options(),
			'label'             => esc_html__( 'Enable on', 'wen-biz-pro' ),
			'section'           => 'wen_biz_contact',
			'type'              => 'select',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_contact_map',
			'sanitize_callback' => 'wen_biz_sanitize_image',
			'custom_control'    => 'WP_Customize_Image_Control',
			'active_callback'   => 'wen_biz_is_contact_form_active',
			'label'             => esc_html__( 'Map Image', 'wen-biz-pro' ),
			'section'           => 'wen_biz_contact',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_contact_map_link',
			'sanitize_callback' => 'esc_url_raw',
			'active_callback'   => 'wen_biz_is_contact_form_active',
			'label'             => esc_html__( 'Link', 'wen-biz-pro' ),
			'section'           => 'wen_biz_contact',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_contact_map_target',
			'sanitize_callback' => 'wen_biz_sanitize_checkbox',
			'active_callback'   => 'wen_biz_is_contact_form_active',
			'label'             => esc_html__( 'Open Link in New Window/Tab', 'wen-biz-pro' ),
			'section'           => 'wen_biz_contact',
			'custom_control'    => 'Wen_Biz_Toggle_Control',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_contact_tagline',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'wen_biz_is_contact_form_active',
			'label'             => esc_html__( 'Section Tagline', 'wen-biz-pro' ),
			'section'           => 'wen_biz_contact',
			'type'              => 'text',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_contact_title',
			'default'           => esc_html__( 'Contact', 'wen-biz-pro' ),
			'sanitize_callback' => 'sanitize_text_field',
			'active_callback'   => 'wen_biz_is_contact_form_active',
			'label'             => esc_html__( 'Headline', 'wen-biz-pro' ),
			'section'           => 'wen_biz_contact',
			'type'              => 'text',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_contact_description',
			'sanitize_callback' => 'sanitize_text_field',
			'active_callback'   => 'wen_biz_is_contact_form_active',
			'label'             => esc_html__( 'Content', 'wen-biz-pro' ),
			'section'           => 'wen_biz_contact',
			'type'              => 'textarea',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_contact_image',
			'sanitize_callback' => 'wen_biz_sanitize_image',
			'custom_control'    => 'WP_Customize_Image_Control',
			'active_callback'   => 'wen_biz_is_contact_form_active',
			'label'             => esc_html__( 'Contact Image', 'wen-biz-pro' ),
			'section'           => 'wen_biz_contact',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_contact_number_tagline',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'wen_biz_is_contact_form_active',
			'label'             => esc_html__( 'Contact Tagline', 'wen-biz-pro' ),
			'section'           => 'wen_biz_contact',
			'type'              => 'text',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_contact_phone',
			'sanitize_callback' => 'sanitize_text_field',
			'active_callback'   => 'wen_biz_is_contact_form_active',
			'label'             => esc_html__( 'Phone', 'wen-biz-pro' ),
			'section'           => 'wen_biz_contact',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_contact_info_list',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'wen_biz_is_contact_form_active',
			'label'             => esc_html__( 'Contact Info List', 'wen-biz-pro' ),
			'section'           => 'wen_biz_contact',
			'type'              => 'textarea',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_contact_text',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'wen_biz_is_contact_form_active',
			'label'             => esc_html__( 'Contact Link Text', 'wen-biz-pro' ),
			'section'           => 'wen_biz_contact',
			'type'              => 'text',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_contact_text_link',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'wen_biz_is_contact_form_active',
			'label'             => esc_html__( 'Contact Link', 'wen-biz-pro' ),
			'section'           => 'wen_biz_contact',
			'type'              => 'text',
		)
	);

	$type = wen_biz_section_type_options();

	unset( $type['category'] );

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_contact_type',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'active_callback'   => 'wen_biz_is_contact_form_active',
            'choices'           => $type,
            'default'			=> 'custom',
			'label'             => esc_html__( 'Type', 'wen-biz-pro' ),
			'section'           => 'wen_biz_contact',
			'type'              => 'select',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_contact_post',
			'sanitize_callback' => 'wen_biz_sanitize_post',
			'default'           => 0,
			'active_callback'   => 'wen_biz_is_contact_form_post_active',
			'input_attrs'       => array(
				'style' => 'width: 40px;'
			),
			'label'             => esc_html__( 'Post', 'wen-biz-pro' ),
			'section'           => 'wen_biz_contact',
			'choices'           => wen_biz_generate_post_array(),
			'type'              => 'select'
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_contact_page',
			'sanitize_callback' => 'wen_biz_sanitize_post',
			'active_callback'   => 'wen_biz_is_contact_form_page_active',
			'label'             => esc_html__( 'Page', 'wen-biz-pro' ),
			'section'           => 'wen_biz_contact',
			'type'              => 'dropdown-pages',
			'allow_addition'    => true,
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_contact_custom',
			'sanitize_callback' => 'wp_kses_post',
			'description'       => esc_html__( 'Add custom shortcodes from Contact Form 7 or Jetpack Contact Form or WPForms', 'wen-biz-pro' ),
			'active_callback'   => 'wen_biz_is_contact_form_custom_active',
			'label'             => esc_html__( 'Custom Content', 'wen-biz-pro' ),
			'section'           => 'wen_biz_contact',
			'type'              => 'textarea',
		)
	);
	// Contact Form End.
}
add_action( 'customize_register', 'wen_biz_contact_options', 10 );

/** Active Callback Functions **/
if ( ! function_exists( 'wen_biz_is_contact_form_active' ) ) :
	/**
	* Return true if reservation is active
	*
	* @since Darcie Pro 1.0
	*/
	function wen_biz_is_contact_form_active( $control ) {
		$enable = $control->manager->get_setting( 'wen_biz_contact_form_option' )->value();

		//return true only if previewed page on customizer matches the type of content option selected
		return ( wen_biz_check_section( $enable ) );
	}
endif;

if ( ! function_exists( 'wen_biz_is_contact_form_post_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Darcie Pro 1.0
	*/
	function wen_biz_is_contact_form_post_active( $control ) {
		$type = $control->manager->get_setting( 'wen_biz_contact_type' )->value();

		//return true only if previewed page on customizer matches the type of content option selected and is or is not selected type
		return ( wen_biz_is_contact_form_active( $control ) && 'post' === $type );
	}
endif;

if ( ! function_exists( 'wen_biz_is_contact_form_page_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Darcie Pro 1.0
	*/
	function wen_biz_is_contact_form_page_active( $control ) {
		$type = $control->manager->get_setting( 'wen_biz_contact_type' )->value();

		//return true only if previewed page on customizer matches the type of content option selected and is or is not selected type
		return ( wen_biz_is_contact_form_active( $control ) && 'page' === $type );
	}
endif;

if ( ! function_exists( 'wen_biz_is_contact_form_custom_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Darcie Pro 1.0
	*/
	function wen_biz_is_contact_form_custom_active( $control ) {
		$type = $control->manager->get_setting( 'wen_biz_contact_type' )->value();

		//return true only if previewed page on customizer matches the type of content option selected and is or is not selected type
		return ( wen_biz_is_contact_form_active( $control ) && 'custom' === $type );
	}
endif;

