<?php
/**
 * Featured Slider Options
 *
 * @package Wen_Biz
 */

/**
 * Add hero content options to theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function wen_biz_slider_options( $wp_customize ) {
	$wp_customize->add_section( 'wen_biz_featured_slider', array(
			'panel' => 'wen_biz_theme_options',
			'title' => esc_html__( 'Featured Slider', 'wen-biz-pro' ),
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_slider_option',
			'default'           => 'disabled',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'choices'           => wen_biz_section_visibility_options(),
			'label'             => esc_html__( 'Enable on', 'wen-biz-pro' ),
			'section'           => 'wen_biz_featured_slider',
			'type'              => 'select',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_slider_transition_in',
			'default'           => 'default',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'active_callback'   => 'wen_biz_is_slider_active',
			'choices'           => wen_biz_transition_effects(),
			'label'             => esc_html__( 'Transition In', 'wen-biz-pro' ),
			'section'           => 'wen_biz_featured_slider',
			'type'              => 'select',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_slider_transition_out',
			'default'           => 'default',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'active_callback'   => 'wen_biz_is_slider_active',
			'choices'           => wen_biz_transition_effects(),
			'label'             => esc_html__( 'Transition Out', 'wen-biz-pro' ),
			'section'           => 'wen_biz_featured_slider',
			'type'              => 'select',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_slider_nav',
			'default'           => 1,
			'sanitize_callback' => 'wen_biz_sanitize_checkbox',
			'active_callback'   => 'wen_biz_is_slider_active',
			'label'             => esc_html__( 'Display nav arrows', 'wen-biz-pro' ),
			'section'           => 'wen_biz_featured_slider',
			'custom_control'    => 'Wen_Biz_Toggle_Control',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_slider_dots',
			'sanitize_callback' => 'wen_biz_sanitize_checkbox',
			'active_callback'   => 'wen_biz_is_slider_active',
			'label'             => esc_html__( 'Display nav dots', 'wen-biz-pro' ),
			'section'           => 'wen_biz_featured_slider',
			'custom_control'    => 'Wen_Biz_Toggle_Control',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_slider_autoplay',
			'default'           => 1,
			'sanitize_callback' => 'wen_biz_sanitize_checkbox',
			'active_callback'   => 'wen_biz_is_slider_active',
			'label'             => esc_html__( 'Autoplay', 'wen-biz-pro' ),
			'section'           => 'wen_biz_featured_slider',
			'custom_control'    => 'Wen_Biz_Toggle_Control',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_slider_loop',
			'default'           => 1,
			'sanitize_callback' => 'wen_biz_sanitize_checkbox',
			'active_callback'   => 'wen_biz_is_slider_active',
			'label'             => esc_html__( 'Loop (Last to first)', 'wen-biz-pro' ),
			'section'           => 'wen_biz_featured_slider',
			'custom_control'    => 'Wen_Biz_Toggle_Control',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_slider_text_alignment',
			'default'           => 'text-align-left',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'active_callback'   => 'wen_biz_is_slider_active',
			'choices'           => array(
				'text-align-center' => esc_html__( 'Center', 'wen-biz-pro' ),
				'text-align-right'  => esc_html__( 'Right', 'wen-biz-pro' ),
				'text-align-left'   => esc_html__( 'Left', 'wen-biz-pro' ),
			),
			'label'             => esc_html__( 'Text Alignment', 'wen-biz-pro' ),
			'section'           => 'wen_biz_featured_slider',
			'type'              => 'select',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_slider_content_alignment',
			'default'           => 'content-align-left',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'active_callback'   => 'wen_biz_is_slider_active',
			'choices'           => array(
				'content-align-center' => esc_html__( 'Center', 'wen-biz-pro' ),
				'content-align-right'  => esc_html__( 'Right', 'wen-biz-pro' ),
				'content-align-left'   => esc_html__( 'Left', 'wen-biz-pro' ),
			),
			'label'             => esc_html__( 'Content Alignment', 'wen-biz-pro' ),
			'section'           => 'wen_biz_featured_slider',
			'type'              => 'select',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_slider_transition_timeout',
			'default'           => 4,
			'sanitize_callback' => 'wen_biz_sanitize_number_range',
			'active_callback'   => 'wen_biz_is_slider_active',
			'input_attrs'       => array(
				'style'       => 'width: 100px;',
				'min'         => 0,
			),
			'label'             => esc_html__( 'Transition timeout', 'wen-biz-pro' ),
			'section'           => 'wen_biz_featured_slider',
			'type'              => 'number',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_slider_opacity',
			'default'           => 33,
			'sanitize_callback' => 'wen_biz_sanitize_number_range',
			'active_callback'   => 'wen_biz_is_slider_active',
			'label'             => esc_html__( 'Image Overlay', 'wen-biz-pro' ),
			'section'           => 'wen_biz_featured_slider',
			'type'              => 'number',
			'input_attrs'       => array(
				'style' => 'width: 80px;',
				'min'   => 0,
				'max'   => 100,
			),
		)
	);

	$type = wen_biz_section_type_options();

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_slider_type',
			'default'           => 'category',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'active_callback'   => 'wen_biz_is_slider_active',
			'choices'           => $type,
			'label'             => esc_html__( 'Select Slider Type', 'wen-biz-pro' ),
			'section'           => 'wen_biz_featured_slider',
			'type'              => 'select',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_slider_number',
			'default'           => '4',
			'sanitize_callback' => 'wen_biz_sanitize_number_range',

			'active_callback'   => 'wen_biz_is_slider_active',
			'description'       => esc_html__( 'Save and refresh the page if No. of Slides is changed (Max no of slides is 20)', 'wen-biz-pro' ),
			'input_attrs'       => array(
				'style' => 'width: 100px;',
				'min'   => 0,
				'max'   => 20,
				'step'  => 1,
			),
			'label'             => esc_html__( 'No of Slides', 'wen-biz-pro' ),
			'section'           => 'wen_biz_featured_slider',
			'type'              => 'number',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_slider_content_show',
			'default'           => 'excerpt',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'active_callback'   => 'wen_biz_is_image_slider_inactive',
			'choices'           => wen_biz_content_show(),
			'label'             => esc_html__( 'Display Content', 'wen-biz-pro' ),
			'section'           => 'wen_biz_featured_slider',
			'type'              => 'select',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_slider_meta_show',
			'default'           => 'show-meta',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'active_callback'   => 'wen_biz_is_image_slider_inactive',
			'choices'           => wen_biz_meta_show(),
			'label'             => esc_html__( 'Display Meta', 'wen-biz-pro' ),
			'section'           => 'wen_biz_featured_slider',
			'type'              => 'select',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_exclude_slider_post',
			'sanitize_callback' => 'wen_biz_sanitize_checkbox',
			'active_callback'   => 'wen_biz_is_post_slider_active',
			'label'             => esc_html__( 'Exclude Slider post from Homepage posts', 'wen-biz-pro' ),
			'section'           => 'wen_biz_featured_slider',
			'custom_control'    => 'Wen_Biz_Toggle_Control',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_slider_select_category',
			'sanitize_callback' => 'wen_biz_sanitize_category_list',
			'custom_control'    => 'Wen_Biz_Multi_Cat',
			'active_callback'   => 'wen_biz_is_category_slider_active',
			'label'             => esc_html__( 'Select Categories', 'wen-biz-pro' ),
			'section'           => 'wen_biz_featured_slider',
			'type'              => 'dropdown-categories',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_slider_image_position_desktop',
			'default'           => 'center center',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'active_callback'   => 'wen_biz_is_slider_active',
			'label'             => esc_html__( 'Image Position (Desktop View)', 'wen-biz-pro' ),
			'section'           => 'wen_biz_featured_slider',
			'type'              => 'select',
			'choices'           => array(
				'left top'      => esc_html__( 'Left Top', 'wen-biz-pro' ),
				'left center'   => esc_html__( 'Left Center', 'wen-biz-pro' ),
				'left bottom'   => esc_html__( 'Left Bottom', 'wen-biz-pro' ),
				'right top'     => esc_html__( 'Right Top', 'wen-biz-pro' ),
				'right center'  => esc_html__( 'Right Center', 'wen-biz-pro' ),
				'right bottom'  => esc_html__( 'Right Bottom', 'wen-biz-pro' ),
				'center top'    => esc_html__( 'Center Top', 'wen-biz-pro' ),
				'center center' => esc_html__( 'Center Center', 'wen-biz-pro' ),
				'center bottom' => esc_html__( 'Center Bottom', 'wen-biz-pro' ),
			),
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_slider_image_position_mobile',
			'default'           => 'center center',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'active_callback'   => 'wen_biz_is_slider_active',
			'label'             => esc_html__( 'Image Position (Mobile View)', 'wen-biz-pro' ),
			'section'           => 'wen_biz_featured_slider',
			'type'              => 'select',
			'choices'           => array(
				'left top'      => esc_html__( 'Left Top', 'wen-biz-pro' ),
				'left center'   => esc_html__( 'Left Center', 'wen-biz-pro' ),
				'left bottom'   => esc_html__( 'Left Bottom', 'wen-biz-pro' ),
				'right top'     => esc_html__( 'Right Top', 'wen-biz-pro' ),
				'right center'  => esc_html__( 'Right Center', 'wen-biz-pro' ),
				'right bottom'  => esc_html__( 'Right Bottom', 'wen-biz-pro' ),
				'center top'    => esc_html__( 'Center Top', 'wen-biz-pro' ),
				'center center' => esc_html__( 'Center Center', 'wen-biz-pro' ),
				'center bottom' => esc_html__( 'Center Bottom', 'wen-biz-pro' ),
			),
		)
	);

	$slider_number = get_theme_mod( 'wen_biz_slider_number', 4 );

	for ( $i = 1; $i <= $slider_number ; $i++ ) {
		// Post Sliders
		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_slider_post_' . $i,
				'sanitize_callback' => 'wen_biz_sanitize_post',
				'active_callback'   => 'wen_biz_is_post_slider_active',
				'input_attrs'       => array(
					'style' => 'width: 80px;',
				),
				'label'             => esc_html__( 'Post', 'wen-biz-pro' ) . ' # ' . $i,
				'section'           => 'wen_biz_featured_slider',
				'choices'           => wen_biz_generate_post_array(),
				'type'              => 'select',
			)
		);

		// Page Sliders
		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_slider_page_' . $i,
				'sanitize_callback' => 'wen_biz_sanitize_post',
				'active_callback'   => 'wen_biz_is_page_slider_active',
				'label'             => esc_html__( 'Page', 'wen-biz-pro' ) . ' # ' . $i,
				'section'           => 'wen_biz_featured_slider',
				'type'              => 'dropdown-pages',
			)
		);

		// Image Sliders
		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_slider_note_' . $i,
				'sanitize_callback' => 'sanitize_text_field',
				'custom_control'    => 'Wen_Biz_Note_Control',
				'active_callback'   => 'wen_biz_is_image_slider_active',
				'label'             => esc_html__( 'Slide #', 'wen-biz-pro' ) . $i,
				'section'           => 'wen_biz_featured_slider',
				'type'              => 'description',
			)
		);

		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_slider_image_' . $i,
				'sanitize_callback' => 'wen_biz_sanitize_image',
				'custom_control'    => 'WP_Customize_Image_Control',
				'active_callback'   => 'wen_biz_is_image_slider_active',
				'label'             => esc_html__( 'Image', 'wen-biz-pro' ),
				'section'           => 'wen_biz_featured_slider',
			)
		);

		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_slider_link_' . $i,
				'sanitize_callback' => 'esc_url_raw',
				'active_callback'   => 'wen_biz_is_image_slider_active',
				'label'             => esc_html__( 'Link', 'wen-biz-pro' ),
				'section'           => 'wen_biz_featured_slider',
			)
		);

		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_slider_target_' . $i,
				'sanitize_callback' => 'wen_biz_sanitize_checkbox',
				'active_callback'   => 'wen_biz_is_image_slider_active',
				'label'             => esc_html__( 'Open Link in New Window/Tab', 'wen-biz-pro' ),
				'section'           => 'wen_biz_featured_slider',
				'custom_control'    => 'Wen_Biz_Toggle_Control',
			)
		);

		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_slider_subtitle_' . $i,
				'sanitize_callback' => 'wp_kses_post',
				'active_callback'   => 'wen_biz_is_image_slider_active',
				'label'             => esc_html__( 'Tagline', 'wen-biz-pro' ),
				'section'           => 'wen_biz_featured_slider',
				'type'              => 'text',
			)
		);

		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_slider_title_' . $i,
				'sanitize_callback' => 'wp_kses_post',
				'active_callback'   => 'wen_biz_is_image_slider_active',
				'label'             => esc_html__( 'Title', 'wen-biz-pro' ),
				'section'           => 'wen_biz_featured_slider',
				'type'              => 'text',
			)
		);

		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_slider_content_' . $i,
				'sanitize_callback' => 'wp_kses_post',
				'active_callback'   => 'wen_biz_is_image_slider_active',
				'label'             => esc_html__( 'Content', 'wen-biz-pro' ),
				'section'           => 'wen_biz_featured_slider',
				'type'              => 'textarea',
			)
		);

		wen_biz_register_option( $wp_customize, array(
	            'name'              => 'wen_biz_slider_button_text_' . $i,
	            'sanitize_callback' => 'sanitize_text_field',
	            'active_callback'   => 'wen_biz_is_image_slider_active',
	            'label'             => esc_html__( 'Button Text', 'wen-biz-pro' ),
	            'section'           => 'wen_biz_featured_slider',
	        )
	    );
	} // End for().
}
add_action( 'customize_register', 'wen_biz_slider_options' );

/** Active Callback Functions */

if ( ! function_exists( 'wen_biz_is_slider_active' ) ) :
	/**
	* Return true if slider is active
	*
	* @since 1.0.0
	*/
	function wen_biz_is_slider_active( $control ) {
		$enable = $control->manager->get_setting( 'wen_biz_slider_option' )->value();

		//return true only if previwed page on customizer matches the type option selected
		return wen_biz_check_section( $enable );
	}
endif;

if ( ! function_exists( 'wen_biz_is_post_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since 1.0.0
	*/
	function wen_biz_is_post_slider_active( $control ) {
		$type = $control->manager->get_setting( 'wen_biz_slider_type' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is or is not selected type
		return ( wen_biz_is_slider_active( $control ) && 'post' === $type );
	}
endif;

if ( ! function_exists( 'wen_biz_is_page_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since 1.0.0
	*/
	function wen_biz_is_page_slider_active( $control ) {
		$type = $control->manager->get_setting( 'wen_biz_slider_type' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is or is not selected type
		return ( wen_biz_is_slider_active( $control ) && 'page' === $type );
	}
endif;

if ( ! function_exists( 'wen_biz_is_category_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since 1.0.0
	*/
	function wen_biz_is_category_slider_active( $control ) {
		$type = $control->manager->get_setting( 'wen_biz_slider_type' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is or is not selected type
		return ( wen_biz_is_slider_active( $control ) && 'category' === $type );
	}
endif;

if ( ! function_exists( 'wen_biz_is_image_slider_active' ) ) :
	/**
	* Return true if image slider is active
	*
	* @since 1.0.0
	*/
	function wen_biz_is_image_slider_active( $control ) {
		$type = $control->manager->get_setting( 'wen_biz_slider_type' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is or is not selected type
		return ( wen_biz_is_slider_active( $control ) && 'custom' === $type );
	}
endif;

if ( ! function_exists( 'wen_biz_is_image_slider_inactive' ) ) :
	/**
	* Return true if image slider is inactive
	*
	* @since 1.0.0
	*/
	function wen_biz_is_image_slider_inactive( $control ) {
		$type = $control->manager->get_setting( 'wen_biz_slider_type' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is or is not selected type
		return ( wen_biz_is_slider_active( $control ) && 'custom' !== $type );
	}
endif;
