<?php
/**
 * Header Top Options
 *
 * @package Wen_Biz
 */

/**
 * Add header top options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function wen_biz_header_top( $wp_customize ) {
	$wp_customize->add_section( 'wen_biz_header_top', array(
		'panel'       => 'wen_biz_theme_options',
		'title'       => esc_html__( 'Header Top Options', 'wen-biz-pro' ),
	) );

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_disable_header_top',
			'sanitize_callback' => 'wen_biz_sanitize_checkbox',
			'label'             => esc_html__( 'Header Top', 'wen-biz-pro' ),
			'section'           => 'wen_biz_header_top',
			'custom_control'    => 'Wen_Biz_Toggle_Control',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_social_menu_left',
			'default'			=> 0,
			'sanitize_callback' => 'wen_biz_sanitize_checkbox',
			'active_callback'   => 'wen_biz_is_header_top_enabled',
			'label'             => esc_html__( 'Social Menu on Left', 'wen-biz-pro' ),
			'section'           => 'wen_biz_header_top',
			'custom_control'    => 'Wen_Biz_Toggle_Control',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_header_top_menu_note',
			'sanitize_callback' => 'sanitize_text_field',
			'custom_control'    => 'Wen_Biz_Note_Control',
			'active_callback'   => 'wen_biz_is_header_top_enabled',
			'label'             => sprintf( esc_html__( 'For Top Social Menu, go %1$shere%2$s', 'wen-biz-pro' ),
				 '<a href="javascript:wp.customize.control( \'nav_menu_locations[social-top]\' ).focus();">',
				 '</a>'
			),
			'section'           => 'wen_biz_header_top',
			'type'              => 'description',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_header_top_menu_label',
			'default'           => esc_html__( 'Top Bar', 'wen-biz-pro' ),
			'sanitize_callback' => 'sanitize_text_field',
			'active_callback'   => 'wen_biz_is_header_top_enabled',
			'label'             => esc_html__( 'Mobile Menu Label', 'wen-biz-pro' ),
			'section'           => 'wen_biz_header_top',
			'type'              => 'text',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_display_date',
			'sanitize_callback' => 'wen_biz_sanitize_checkbox',
			'active_callback'   => 'wen_biz_is_header_top_enabled',
			'label'             => esc_html__( 'Display Date', 'wen-biz-pro' ),
			'section'           => 'wen_biz_header_top',
			'custom_control'    => 'Wen_Biz_Toggle_Control',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_header_top_link_text',
			'sanitize_callback' => 'sanitize_text_field',
			'active_callback'   => 'wen_biz_is_header_top_enabled',
			'label'             => esc_html__( 'Link Text', 'wen-biz-pro' ),
			'section'           => 'wen_biz_header_top',
			'type'              => 'text',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_header_top_link',
			'sanitize_callback' => 'esc_url_raw',
			'active_callback'   => 'wen_biz_is_header_top_enabled',
			'label'             => esc_html__( 'Link url', 'wen-biz-pro' ),
			'section'           => 'wen_biz_header_top',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_header_top_link_target',
			'sanitize_callback' => 'wen_biz_sanitize_checkbox',
			'active_callback'   => 'wen_biz_is_header_top_enabled',
			'label'             => esc_html__( 'Open Link in New Window/Tab', 'wen-biz-pro' ),
			'section'           => 'wen_biz_header_top',
			'custom_control'    => 'Wen_Biz_Toggle_Control',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_address',
			'sanitize_callback' => 'wp_kses_post',
			'default'			=> esc_html__(' Boston, MA, USA ', 'wen-biz-pro' ),
			'active_callback'   => 'wen_biz_is_header_top_enabled',
			'label'             => esc_html__('Address', 'wen-biz-pro'),
			'section'           => 'wen_biz_header_top',
			'type'              => 'text',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_phone',
			'sanitize_callback' => 'sanitize_text_field',
			'default'			=> esc_html__('123-456-7890', 'wen-biz-pro'),
			'active_callback'   => 'wen_biz_is_header_top_enabled',
			'label'             => esc_html__( 'Phone', 'wen-biz-pro' ),
			'section'           => 'wen_biz_header_top',
			'type'              => 'text',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_email',
			'sanitize_callback' => 'sanitize_email',
			'default'			=> esc_html__('someone@somewhere.com', 'wen-biz-pro'),
			'active_callback'   => 'wen_biz_is_header_top_enabled',
			'label'             => esc_html__( 'Email', 'wen-biz-pro' ),
			'section'           => 'wen_biz_header_top',
			'type'              => 'text',
		)
	);
}
add_action( 'customize_register', 'wen_biz_header_top' );

if( ! function_exists( 'wen_biz_is_header_top_enabled' ) ) :
    /**
    * Return true if header top is enabled
    */
    function wen_biz_is_header_top_enabled( $control ) {
        return ( $control->manager->get_setting( 'wen_biz_disable_header_top' )->value() ? true : false );
    }
endif;
