<?php
/**
 * Add Portfolio Settings in Customizer
 *
 * @package Wen_Biz
 */

/**
 * Add portfolio options to theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function wen_biz_portfolio_options( $wp_customize ) {
	// Add note to Jetpack Portfolio Section
	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_jetpack_portfolio_cpt_note',
			'sanitize_callback' => 'sanitize_text_field',
			'custom_control'    => 'Wen_Biz_Note_Control',
			'label'             => sprintf( esc_html__( 'For Portfolio Options for WEN Biz Theme, go %1$shere%2$s', 'wen-biz-pro' ),
				 '<a href="javascript:wp.customize.section( \'wen_biz_portfolio\' ).focus();">',
				 '</a>'
			),
			'section'           => 'jetpack_portfolio',
			'type'              => 'description',
			'priority'          => 1,
		)
	);

	$wp_customize->add_section( 'wen_biz_portfolio', array(
			'panel'    => 'wen_biz_theme_options',
			'title'    => esc_html__( 'Portfolio', 'wen-biz-pro' ),
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_portfolio_option',
			'default'           => 'disabled',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'choices'           => wen_biz_section_visibility_options(),
			'label'             => esc_html__( 'Enable on', 'wen-biz-pro' ),
			'section'           => 'wen_biz_portfolio',
			'type'              => 'select',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_portfolio_layout',
			'default'           => 'layout-four',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'active_callback'   => 'wen_biz_is_portfolio_active',
			'choices'           => wen_biz_sections_layout_options(),
			'label'             => esc_html__( 'Select Layout', 'wen-biz-pro' ),
			'section'           => 'wen_biz_portfolio',
			'type'              => 'select',
		)
	);

	$type = wen_biz_section_type_options();

	$type['jetpack-portfolio'] = esc_html__( 'Custom Post Type', 'wen-biz-pro' );
	$type['jetpack-portfolio-type'] = esc_html__( 'CPT - Project Types', 'wen-biz-pro' );

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_portfolio_type',
			'default'           => 'category',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'active_callback'   => 'wen_biz_is_portfolio_active',
			'choices'           => $type,
			'description'       => sprintf( esc_html__( 'For Custom Post Type Content, install %1$sEssential Content Types%2$s Plugin with Portfolio Content Type Enabled', 'wen-biz-pro' ),
				'<a target="_blank" href="https://wordpress.org/plugins/essential-content-types/">',
				'</a>'
			),
			'label'             => esc_html__( 'Select Type', 'wen-biz-pro' ),
			'section'           => 'wen_biz_portfolio',
			'type'              => 'select',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_portfolio_cpt_note',
			'sanitize_callback' => 'sanitize_text_field',
			'custom_control'    => 'Wen_Biz_Note_Control',
			'active_callback'   => 'wen_biz_is_jetpack_portfolio_active',
			'label'             => sprintf( esc_html__( 'For CPT heading and sub-heading, go %1$shere%2$s', 'wen-biz-pro' ),
				 '<a href="javascript:wp.customize.control( \'jetpack_portfolio_title\' ).focus();">',
				 '</a>'
			),
			'section'           => 'wen_biz_portfolio',
			'type'              => 'description',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_portfolio_tagline',
			'sanitize_callback' => 'wp_kses_post',
			'label'             => esc_html__( 'Section Tagline', 'wen-biz-pro' ),
			'active_callback'   => 'wen_biz_is_cpt_portfolio_inactive',
			'section'           => 'wen_biz_portfolio',
			'type'              => 'text',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_portfolio_title',
			'default'           => esc_html__( 'My Works', 'wen-biz-pro' ),
			'sanitize_callback' => 'wp_kses_post',
			'label'             => esc_html__( 'Section Title', 'wen-biz-pro' ),
			'active_callback'   => 'wen_biz_is_cpt_portfolio_inactive',
			'section'           => 'wen_biz_portfolio',
			'type'              => 'text',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_portfolio_number',
			'default'           => 6,
			'sanitize_callback' => 'wen_biz_sanitize_number_range',
			'active_callback'   => 'wen_biz_is_portfolio_active',
			'label'             => esc_html__( 'Number of items to show', 'wen-biz-pro' ),
			'section'           => 'wen_biz_portfolio',
			'type'              => 'number',
			'input_attrs'       => array(
				'style'             => 'width: 100px;',
				'min'               => 0,
			),
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_portfolio_select_category',
			'sanitize_callback' => 'wen_biz_sanitize_category_list',
			'active_callback'   => 'wen_biz_is_category_portfolio_active',
			'custom_control'    => 'Wen_Biz_Multi_Cat',
			'label'             => esc_html__( 'Select Categories', 'wen-biz-pro' ),
			'section'           => 'wen_biz_portfolio',
			'type'              => 'dropdown-categories',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_portfolio_select_project_type',
			'sanitize_callback' => 'wen_biz_sanitize_project_type',
			'active_callback'   => 'wen_biz_is_project_type_portfolio_active',
			'custom_control'    => 'Wen_Biz_Multi_Cat_Project_Type',
			'label'             => esc_html__( 'Select Project Type', 'wen-biz-pro' ),
			'section'           => 'wen_biz_portfolio',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_filter_type',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'default'           => 'filter-type-classic',
			'active_callback'   => 'wen_biz_is_cat_project_type_active',
			'label'             => esc_html__( 'Filter Type', 'wen-biz-pro' ),
			'section'           => 'wen_biz_portfolio',
			'type'              => 'select',
			'choices'           => array(
				'filter-type-classic'  =>esc_html__( 'Serial (Classic)', 'wen-biz-pro' ),
				'filter-type-dropdown' => esc_html__( 'Dropdown', 'wen-biz-pro' ),
			),
		)
	);

	$number = get_theme_mod( 'wen_biz_portfolio_number', 6 );

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_portfolio_display_title',
			'default'           => 1,
			'sanitize_callback' => 'wen_biz_sanitize_checkbox',
			'active_callback'   => 'wen_biz_is_image_portfolio_inactive',
			'label'             => esc_html__( 'Display Title', 'wen-biz-pro' ),
			'section'           => 'wen_biz_portfolio',
			'custom_control'    => 'Wen_Biz_Toggle_Control',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_portfolio_meta_show',
			'default'           => 1,
			'active_callback'   => 'wen_biz_is_post_category_post_cpt_portfolio_active',
			'sanitize_callback' => 'wen_biz_sanitize_checkbox',
			'label'             => esc_html__( 'Display Meta', 'wen-biz-pro' ),
			'section'           => 'wen_biz_portfolio',
			'custom_control'    => 'Wen_Biz_Toggle_Control',
		)
	);

	for ( $i = 1; $i <= $number ; $i++ ) {
		//for featured post content
		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_portfolio_post_' . $i,
				'sanitize_callback' => 'wen_biz_sanitize_post',
				'active_callback'   => 'wen_biz_is_post_portfolio_active',
				'input_attrs'       => array(
				'style'             => 'width: 100px;'
				),
				'label'             => esc_html__( 'Post', 'wen-biz-pro' ) . ' ' . $i ,
				'section'           => 'wen_biz_portfolio',
				'choices'           => wen_biz_generate_post_array(),
				'type'              => 'select',
			)
		);

		//for CPT
		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_portfolio_cpt_' . $i,
				'sanitize_callback' => 'wen_biz_sanitize_post',
				'active_callback'   => 'wen_biz_is_jetpack_portfolio_active',
				'label'             => esc_html__( 'Portfolio', 'wen-biz-pro' ) . ' ' . $i ,
				'section'           => 'wen_biz_portfolio',
				'type'              => 'select',
				'choices'           => wen_biz_generate_post_array( 'jetpack-portfolio' ),
			)
		);

		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_portfolio_page_' . $i,
				'sanitize_callback' => 'wen_biz_sanitize_post',
				'active_callback'   => 'wen_biz_is_page_portfolio_active',
				'label'             => esc_html__( 'Page', 'wen-biz-pro' ) . ' ' . $i ,
				'section'           => 'wen_biz_portfolio',
				'type'              => 'dropdown-pages',
			)
		);

		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_portfolio_note_' . $i,
				'sanitize_callback' => 'sanitize_text_field',
				'custom_control'    => 'Wen_Biz_Note_Control',
				'active_callback'   => 'wen_biz_is_image_portfolio_active',
				'label'             => esc_html__( 'Portfolio #', 'wen-biz-pro' ) .  $i,
				'section'           => 'wen_biz_portfolio',
				'type'              => 'description',
			)
		);

		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_portfolio_image_' . $i,
				'custom_control'      => 'WP_Customize_Image_Control',
				'sanitize_callback' => 'wen_biz_sanitize_image',
				'active_callback'   => 'wen_biz_is_image_portfolio_active',
				'label'             => esc_html__( 'Image', 'wen-biz-pro' ),
				'section'           => 'wen_biz_portfolio',
			)
		);

		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_portfolio_title_' . $i,
				'sanitize_callback' => 'sanitize_text_field',
				'active_callback'   => 'wen_biz_is_image_portfolio_active',
				'label'             => esc_html__( 'Name', 'wen-biz-pro' ),
				'section'           => 'wen_biz_portfolio',
				'type'              => 'text',
			)
		);

		 wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_portfolio_link_' . $i,
				'sanitize_callback' => 'esc_url_raw',
				'active_callback'   => 'wen_biz_is_image_portfolio_active',
				'label'             => esc_html__( 'Link', 'wen-biz-pro' ),
				'section'           => 'wen_biz_portfolio',
			)
		);

		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_portfolio_target_' . $i,
				'sanitize_callback' => 'wen_biz_sanitize_checkbox',
				'active_callback'   => 'wen_biz_is_image_portfolio_active',
				'label'             => esc_html__( 'Open Link in New Window/Tab', 'wen-biz-pro' ),
				'section'           => 'wen_biz_portfolio',
				'custom_control'    => 'Wen_Biz_Toggle_Control',
			)
		);
	} // End for().

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_portfolio_text',
			'default'           => esc_html__( 'View More', 'wen-biz-pro' ),
			'sanitize_callback' => 'sanitize_text_field',
			'active_callback'   => 'wen_biz_is_portfolio_active',
			'label'             => esc_html__( 'Button Text', 'wen-biz-pro' ),
			'section'           => 'wen_biz_portfolio',
			'type'              => 'text',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_portfolio_link',
			'sanitize_callback' => 'esc_url_raw',
			'active_callback'   => 'wen_biz_is_portfolio_active',
			'label'             => esc_html__( 'Button Link', 'wen-biz-pro' ),
			'section'           => 'wen_biz_portfolio',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_portfolio_target',
			'sanitize_callback' => 'wen_biz_sanitize_checkbox',
			'active_callback'   => 'wen_biz_is_portfolio_active',
			'label'             => esc_html__( 'Open Link in New Window/Tab', 'wen-biz-pro' ),
			'section'           => 'wen_biz_portfolio',
			'custom_control'    => 'Wen_Biz_Toggle_Control',
		)
	);
}
add_action( 'customize_register', 'wen_biz_portfolio_options' );

/**
 * Active Callback Functions
 */
if ( ! function_exists( 'wen_biz_is_portfolio_active' ) ) :
	/**
	* Return true if portfolio is active
	*
	* @since 1.0.0
	*/
	function wen_biz_is_portfolio_active( $control ) {
		$enable = $control->manager->get_setting( 'wen_biz_portfolio_option' )->value();

		//return true only if previwed page on customizer matches the type of content option selected
		return wen_biz_check_section( $enable );
	}
endif;

if ( ! function_exists( 'wen_biz_is_post_portfolio_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since 1.0.0
	*/
	function wen_biz_is_post_portfolio_active( $control ) {
		$type = $control->manager->get_setting( 'wen_biz_portfolio_type' )->value();

		return ( wen_biz_is_portfolio_active( $control ) && 'post' === $type );
	}
endif;

if ( ! function_exists( 'wen_biz_is_jetpack_portfolio_active' ) ) :
	/**
	* Return true if jetpack portfolio is active
	*
	* @since 1.0.0
	*/
	function wen_biz_is_jetpack_portfolio_active( $control ) {
		$type = $control->manager->get_setting( 'wen_biz_portfolio_type' )->value();

		return ( wen_biz_is_portfolio_active( $control ) && 'jetpack-portfolio' === $type );
	}
endif;

if ( ! function_exists( 'wen_biz_is_page_portfolio_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since 1.0.0
	*/
	function wen_biz_is_page_portfolio_active( $control ) {
		$type = $control->manager->get_setting( 'wen_biz_portfolio_type' )->value();

		return ( wen_biz_is_portfolio_active( $control ) && 'page' === $type );
	}
endif;

if ( ! function_exists( 'wen_biz_is_category_portfolio_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since 1.0.0
	*/
	function wen_biz_is_category_portfolio_active( $control ) {
		$type = $control->manager->get_setting( 'wen_biz_portfolio_type' )->value();

		return ( wen_biz_is_portfolio_active( $control ) && 'category' === $type );
	}
endif;

if ( ! function_exists( 'wen_biz_is_project_type_portfolio_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since 1.0.0
	*/
	function wen_biz_is_project_type_portfolio_active( $control ) {
		$type = $control->manager->get_setting( 'wen_biz_portfolio_type' )->value();

		return ( wen_biz_is_portfolio_active( $control ) && 'jetpack-portfolio-type' === $type );
	}
endif;


if ( ! function_exists( 'wen_biz_is_post_category_post_cpt_portfolio_active' ) ) :
	/**
	* Return true if page and image is not active
	*
	* @since 1.0.0
	*/
	function wen_biz_is_post_category_post_cpt_portfolio_active( $control ) {
		$type = $control->manager->get_setting( 'wen_biz_portfolio_type' )->value();

		return ( wen_biz_is_portfolio_active( $control ) && 'page' !== $type && 'custom' !== $type );
	}
endif;

if ( ! function_exists( 'wen_biz_is_cpt_portfolio_inactive' ) ) :
	/**
	* Return true if cpt is not active
	*
	* @since 1.0.0
	*/
	function wen_biz_is_cpt_portfolio_inactive( $control ) {
		$type = $control->manager->get_setting( 'wen_biz_portfolio_type' )->value();

		return ( wen_biz_is_portfolio_active( $control ) && 'jetpack-portfolio' !== $type );
	}
endif;

if ( ! function_exists( 'wen_biz_is_image_portfolio_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since 1.0.0
	*/
	function wen_biz_is_image_portfolio_active( $control ) {
		$type = $control->manager->get_setting( 'wen_biz_portfolio_type' )->value();

		return ( wen_biz_is_portfolio_active( $control ) && 'custom' === $type );
	}
endif;

if ( ! function_exists( 'wen_biz_is_image_portfolio_inactive' ) ) :
	/**
	* Return true if custom content is inactive
	*
	* @since 1.0.0
	*/
	function wen_biz_is_image_portfolio_inactive( $control ) {
		$type = $control->manager->get_setting( 'wen_biz_portfolio_type' )->value();

		return ( wen_biz_is_portfolio_active( $control ) && 'custom' !== $type );
	}
endif;

if ( ! function_exists( 'wen_biz_is_cat_project_type_active' ) ) :
	/**
	* Return true if cat/project type content is inactive
	*
	* @since 1.0.0
	*/
	function wen_biz_is_cat_project_type_active( $control ) {
		$type = $control->manager->get_setting( 'wen_biz_portfolio_type' )->value();

		return ( wen_biz_is_portfolio_active( $control ) && ( 'category' === $type || 'jetpack-portfolio-type' === $type ) );
	}
endif;


