<?php
/**
 * Pricing options
 *
 * @package Wen_Biz
 */

/**
 * Add pricing content options to theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function wen_biz_pricing_options( $wp_customize ) {
    $wp_customize->add_section( 'wen_biz_pricing', array(
			'title' => esc_html__( 'Pricing', 'wen-biz-pro' ),
			'panel' => 'wen_biz_theme_options',
		)
	);

	// Add color scheme setting and control.
	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_pricing_option',
			'default'           => 'disabled',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'choices'           => wen_biz_section_visibility_options(),
			'label'             => esc_html__( 'Enable on', 'wen-biz-pro' ),
			'section'           => 'wen_biz_pricing',
			'type'              => 'select',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_pricing_layout',
			'default'           => 'layout-three',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'active_callback'   => 'wen_biz_is_pricing_active',
			'choices'           => wen_biz_sections_layout_options(),
			'label'             => esc_html__( 'Select Layout', 'wen-biz-pro' ),
			'section'           => 'wen_biz_pricing',
			'type'              => 'select',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_pricing_section_tagline',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'wen_biz_is_pricing_active',
			'label'             => esc_html__( 'Section Tagline', 'wen-biz-pro' ),
			'section'           => 'wen_biz_pricing',
			'type'              => 'text',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_pricing_section_title',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'wen_biz_is_pricing_active',
			'label'             => esc_html__( 'Section Title', 'wen-biz-pro' ),
			'section'           => 'wen_biz_pricing',
			'type'              => 'text',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_pricing_type',
			'default'           => 'category',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'active_callback'   => 'wen_biz_is_pricing_active',
            'choices'           => wen_biz_section_type_options(),
			'label'             => esc_html__( 'Type', 'wen-biz-pro' ),
			'section'           => 'wen_biz_pricing',
			'type'              => 'select',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_pricing_number',
			'default'           => 3,
			'sanitize_callback' => 'wen_biz_sanitize_number_range',
			'active_callback'   => 'wen_biz_is_pricing_active',
			'description'       => esc_html__( 'Save and refresh the page if No. of Pricing is changed (Max no of Pricing is 20)', 'wen-biz-pro' ),
			'input_attrs'       => array(
				'style' => 'width: 100px;',
				'min'   => 0,
			),
			'label'             => esc_html__( 'No of items', 'wen-biz-pro' ),
			'section'           => 'wen_biz_pricing',
			'type'              => 'number',
			'transport'         => 'postMessage',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_pricing_show',
			'default'           => 'full-content',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'active_callback'   => 'wen_biz_is_pricing_post_page_category_content_active',
			'choices'           => wen_biz_content_show(),
			'label'             => esc_html__( 'Display Content', 'wen-biz-pro' ),
			'section'           => 'wen_biz_pricing',
			'type'              => 'select',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_pricing_select_category',
			'sanitize_callback' => 'wen_biz_sanitize_category_list',
			'custom_control'    => 'Wen_Biz_Multi_Cat',
			'active_callback'   => 'wen_biz_is_pricing_category_content_active',
			'label'             => esc_html__( 'Select Categories', 'wen-biz-pro' ),
			'name'              => 'wen_biz_pricing_select_category',
			'section'           => 'wen_biz_pricing',
			'type'              => 'dropdown-categories',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_pricing_currency',
			'sanitize_callback' => 'sanitize_text_field',
			'active_callback'   => 'wen_biz_is_pricing_active',
			'label'             => esc_html__( 'Currency', 'wen-biz-pro' ),
			'section'           => 'wen_biz_pricing',
			'type'              => 'text',
		)
	);

	$number = get_theme_mod( 'wen_biz_pricing_number', 3 );

	//loop for pricing post content
	for ( $i = 1; $i <= $number ; $i++ ) {
		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_pricing_note_' . $i,
				'sanitize_callback' => 'sanitize_text_field',
				'custom_control'    => 'Wen_Biz_Note_Control',
				'active_callback'   => 'wen_biz_is_pricing_active',
				'label'             => esc_html__( 'Pricing #', 'wen-biz-pro' ) .  $i,
				'section'           => 'wen_biz_pricing',
				'type'              => 'description',
			)
		);

		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_pricing_highlight_' . $i,
				'sanitize_callback' => 'wen_biz_sanitize_checkbox',
				'active_callback'   => 'wen_biz_is_pricing_active',
				'label'             => esc_html__( 'Highlight this item', 'wen-biz-pro' ),
				'section'           => 'wen_biz_pricing',
				'custom_control'    => 'Wen_Biz_Toggle_Control',
			)
		);

		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_pricing_highlight_text_' . $i,
				'sanitize_callback' => 'sanitize_text_field',
				'active_callback'   => 'wen_biz_is_pricing_active',
				'label'             => esc_html__( 'Highlight text', 'wen-biz-pro' ),
				'default'           => esc_html__( 'Popular Choice', 'wen-biz-pro' ),
				'section'           => 'wen_biz_pricing',
			)
		);

		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_pricing_amount_' . $i,
				'sanitize_callback' => 'sanitize_text_field',
				'active_callback'   => 'wen_biz_is_pricing_active',
				'label'             => esc_html__( 'Amount', 'wen-biz-pro' ),
				'section'           => 'wen_biz_pricing',
				'type'              => 'text',
			)
		);

		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_pricing_amount_remarks_' . $i,
				'sanitize_callback' => 'sanitize_text_field',
				'active_callback'   => 'wen_biz_is_pricing_active',
				'label'             => esc_html__( 'Amount Remarks (per month)', 'wen-biz-pro' ),
				'section'           => 'wen_biz_pricing',
				'type'              => 'text',
			)
		);
		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_pricing_post_' . $i,
				'sanitize_callback' => 'wen_biz_sanitize_post',
				'default'           => 0,
				'active_callback'   => 'wen_biz_is_pricing_post_content_active',
				'input_attrs'       => array(
					'style'             => 'width: 40px;'
				),
				'label'             => esc_html__( 'Post', 'wen-biz-pro' ) . ' ' . $i ,
				'section'           => 'wen_biz_pricing',
				'choices'           => wen_biz_generate_post_array(),
				'type'              => 'select'
			)
		);

		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_pricing_page_' . $i,
				'sanitize_callback' => 'wen_biz_sanitize_post',
				'active_callback'   => 'wen_biz_is_pricing_page_content_active',
				'label'             => esc_html__( 'Pricing Page', 'wen-biz-pro' ) . ' ' . $i ,
				'section'           => 'wen_biz_pricing',
				'type'              => 'dropdown-pages',
				'allow_addition'    => true,
			)
		);

		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_pricing_image_' . $i,
				'sanitize_callback' => 'wen_biz_sanitize_image',
				'custom_control'    => 'WP_Customize_Image_Control',
				'active_callback'   => 'wen_biz_is_pricing_image_content_active',
				'label'             => esc_html__( 'Image', 'wen-biz-pro' ),
				'section'           => 'wen_biz_pricing',
			)
		);

		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_pricing_link_' . $i,
				'sanitize_callback' => 'esc_url_raw',
				'active_callback'   => 'wen_biz_is_pricing_image_content_active',
				'label'             => esc_html__( 'Link', 'wen-biz-pro' ),
				'section'           => 'wen_biz_pricing',
			)
		);

		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_pricing_target_' . $i,
				'sanitize_callback' => 'wen_biz_sanitize_checkbox',
				'active_callback'   => 'wen_biz_is_pricing_image_content_active',
				'label'             => esc_html__( 'Open Link in New Window/Tab', 'wen-biz-pro' ),
				'section'           => 'wen_biz_pricing',
				'custom_control'    => 'Wen_Biz_Toggle_Control',
			)
		);

		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_pricing_title_' . $i,
				'sanitize_callback' => 'wp_kses_post',
				'active_callback'   => 'wen_biz_is_pricing_image_content_active',
				'label'             => esc_html__( 'Title', 'wen-biz-pro' ),
				'section'           => 'wen_biz_pricing',
				'type'              => 'text',
			)
		);

		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_pricing_content_' . $i,
				'sanitize_callback' => 'wp_kses_post',
				'active_callback'   => 'wen_biz_is_pricing_image_content_active',
				'label'             => esc_html__( 'Content', 'wen-biz-pro' ),
				'section'           => 'wen_biz_pricing',
				'type'              => 'textarea',
			)
		);

		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_pricing_more_button_text_' . $i,
				'sanitize_callback' => 'sanitize_text_field',
				'active_callback'   => 'wen_biz_is_pricing_image_content_active',
				'label'             => esc_html__( 'More Button Text', 'wen-biz-pro' ),
				'section'           => 'wen_biz_pricing',
				'type'              => 'text',
			)
		);
	} // End for().
}
add_action( 'customize_register', 'wen_biz_pricing_options', 10 );

/** Active Callback Functions **/
if ( ! function_exists( 'wen_biz_is_pricing_active' ) ) :
	/**
	* Return true if pricing content is active
	*
	* @since 1.0.0
	*/
	function wen_biz_is_pricing_active( $control ) {
		$enable = $control->manager->get_setting( 'wen_biz_pricing_option' )->value();

		//return true only if previewed page on customizer matches the type of content option selected
		return ( wen_biz_check_section( $enable ) );
	}
endif;

if ( ! function_exists( 'wen_biz_is_pricing_post_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since 1.0.0
	*/
	function wen_biz_is_pricing_post_content_active( $control ) {
		$type = $control->manager->get_setting( 'wen_biz_pricing_type' )->value();

		//return true only if previewed page on customizer matches the type of content option selected and is or is not selected type
		return ( wen_biz_is_pricing_active( $control ) && ( 'post' === $type ) );
	}
endif;

if ( ! function_exists( 'wen_biz_is_pricing_page_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since 1.0.0
	*/
	function wen_biz_is_pricing_page_content_active( $control ) {
		$type = $control->manager->get_setting( 'wen_biz_pricing_type' )->value();

		//return true only if previewed page on customizer matches the type of content option selected and is or is not selected type
		return ( wen_biz_is_pricing_active( $control ) && ( 'page' === $type ) );
	}
endif;

if ( ! function_exists( 'wen_biz_is_pricing_category_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since 1.0.0
	*/
	function wen_biz_is_pricing_category_content_active( $control ) {
		$type = $control->manager->get_setting( 'wen_biz_pricing_type' )->value();

		//return true only if previewed page on customizer matches the type of content option selected and is or is not selected type
		return ( wen_biz_is_pricing_active( $control ) && ( 'category' === $type ) );
	}
endif;

if ( ! function_exists( 'wen_biz_is_pricing_post_page_category_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since 1.0.0
	*/
	function wen_biz_is_pricing_post_page_category_content_active( $control ) {
		$type = $control->manager->get_setting( 'wen_biz_pricing_type' )->value();

		//return true only if previewed page on customizer matches the type of content option selected and is or is not selected type
		return ( wen_biz_is_pricing_active( $control ) && ( 'category' === $type || 'page' === $type || 'post' === $type ) );
	}
endif;

if ( ! function_exists( 'wen_biz_is_pricing_image_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since 1.0.0
	*/
	function wen_biz_is_pricing_image_content_active( $control ) {
		$type = $control->manager->get_setting( 'wen_biz_pricing_type' )->value();

		//return true only if previewed page on customizer matches the type of content option selected and is or is not selected type
		return ( wen_biz_is_pricing_active( $control ) && ( 'custom' === $type ) );
	}
endif;
