<?php
/**
 * Featured Content options
 *
 * @package Wen_Biz
 */

/**
 * Add Promotional Video options to theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function wen_biz_promotional_video_options( $wp_customize ) {
    $wp_customize->add_section( 'wen_biz_promotional_video', array(
			'title' => esc_html__( 'Promotional Video', 'wen-biz-pro' ),
			'panel' => 'wen_biz_theme_options',
		)
	);

	// Add color scheme setting and control.
	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_promotional_video_option',
			'default'           => 'disabled',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'choices'           => wen_biz_section_visibility_options(),
			'label'             => esc_html__( 'Enable on', 'wen-biz-pro' ),
			'section'           => 'wen_biz_promotional_video',
			'type'              => 'select',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_promotional_video_bg_image',
			'sanitize_callback' => 'wen_biz_sanitize_image',
			'active_callback'   => 'wen_biz_is_promotional_video_active',
			'custom_control'    => 'WP_Customize_Image_Control',
			'label'             => esc_html__( 'Background Image', 'wen-biz-pro' ),
			'section'           => 'wen_biz_promotional_video',
		)
	);

	/*Overlay Option for Promotion Headline Background Image */
	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_promotional_video_background_image_opacity',
			'default'           => '50',
			'sanitize_callback' => 'wen_biz_sanitize_number_range',
			'active_callback'   => 'wen_biz_is_promotional_video_active',
			'label'             => esc_html__( 'Background Image Overlay', 'wen-biz-pro' ),
			'section'           => 'wen_biz_promotional_video',
			'type'              => 'number',
			'input_attrs'       => array(
				'style' => 'width: 60px;',
				'min'   => 0,
				'max'   => 100,
			),
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_promotional_video_tagline',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'wen_biz_is_promotional_video_active',
			'label'             => esc_html__( 'Tagline', 'wen-biz-pro' ),
			'section'           => 'wen_biz_promotional_video',
			'type'              => 'text',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_promotional_video_title',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'wen_biz_is_promotional_video_active',
			'label'             => esc_html__( 'Title', 'wen-biz-pro' ),
			'section'           => 'wen_biz_promotional_video',
			'type'              => 'text',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_promotional_video_description',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'wen_biz_is_promotional_video_active',
			'label'             => esc_html__( 'Description', 'wen-biz-pro' ),
			'section'           => 'wen_biz_promotional_video',
			'type'              => 'textarea',
		)
	);

	wen_biz_register_option( $wp_customize, array(
	        'name'              => 'wen_biz_promotional_video_url',
	        'sanitize_callback' => 'esc_url_raw',
	        'active_callback'   => 'wen_biz_is_promotional_video_active',
	        'label'             => esc_html__( 'Video Url', 'wen-biz-pro' ),
	        'section'           => 'wen_biz_promotional_video',
	    )
	);
}
add_action( 'customize_register', 'wen_biz_promotional_video_options', 10 );

/** Active Callback Functions **/
if ( ! function_exists( 'wen_biz_is_promotional_video_active' ) ) :
	/**
	* Return true if featured content is active
	*
	* @since 1.0
	*/
	function wen_biz_is_promotional_video_active( $control ) {
		$enable = $control->manager->get_setting( 'wen_biz_promotional_video_option' )->value();

		return wen_biz_check_section( $enable );
	}
endif;
