<?php
/**
 * Team options
 *
 * @package Wen_Biz
 */

/**
 * Add team content options to theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function wen_biz_team_options( $wp_customize ) {

	$wp_customize->add_section( 'wen_biz_team', array(
			'title' => esc_html__( 'Team', 'wen-biz-pro' ),
			'panel' => 'wen_biz_theme_options',
		)
	);

	// Add color scheme setting and control.
	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_team_option',
			'default'           => 'disabled',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'choices'           => wen_biz_section_visibility_options(),
			'label'             => esc_html__( 'Enable on', 'wen-biz-pro' ),
			'section'           => 'wen_biz_team',
			'type'              => 'select',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_team_layout',
			'default'           => 'layout-three',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'active_callback'   => 'wen_biz_is_team_active',
			'choices'           => wen_biz_sections_layout_options(),
			'label'             => esc_html__( 'Select Layout', 'wen-biz-pro' ),
			'section'           => 'wen_biz_team',
			'type'              => 'select',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_team_tagline',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'wen_biz_is_team_active',
			'label'             => esc_html__( 'Section Tagline', 'wen-biz-pro' ),
			'section'           => 'wen_biz_team',
			'type'              => 'text',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_team_title',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'wen_biz_is_team_active',
			'label'             => esc_html__( 'Section Title', 'wen-biz-pro' ),
			'section'           => 'wen_biz_team',
			'type'              => 'text',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_team_type',
			'default'           => 'category',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'active_callback'   => 'wen_biz_is_team_active',
			'choices'           => wen_biz_section_type_options(),
			'label'             => esc_html__( 'Type', 'wen-biz-pro' ),
			'section'           => 'wen_biz_team',
			'type'              => 'select',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_team_number',
			'default'           => 3,
			'sanitize_callback' => 'wen_biz_sanitize_number_range',
			'active_callback'   => 'wen_biz_is_team_active',
			'description'       => esc_html__( 'Save and refresh the page if No. of Items is changed', 'wen-biz-pro' ),
			'input_attrs'       => array(
				'style' => 'width: 100px;',
				'min'   => 0,
			),
			'label'             => esc_html__( 'No of Items', 'wen-biz-pro' ),
			'section'           => 'wen_biz_team',
			'type'              => 'number',
			'transport'         => 'postMessage',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_team_show',
			'default'           => 'hide-content',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'active_callback'   => 'wen_biz_is_team_post_page_category_content_active',
			'choices'           => wen_biz_content_show(),
			'label'             => esc_html__( 'Display Content', 'wen-biz-pro' ),
			'section'           => 'wen_biz_team',
			'type'              => 'select',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_team_select_category',
			'sanitize_callback' => 'wen_biz_sanitize_category_list',
			'custom_control'    => 'Wen_Biz_Multi_Cat',
			'active_callback'   => 'wen_biz_is_team_category_content_active',
			'label'             => esc_html__( 'Select Categories', 'wen-biz-pro' ),
			'name'              => 'wen_biz_team_select_category',
			'section'           => 'wen_biz_team',
			'type'              => 'dropdown-categories',
		)
	);

	$number = get_theme_mod( 'wen_biz_team_number', 3 );

	//loop for team post content
	for ( $i = 1; $i <= $number ; $i++ ) {
		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_team_post_' . $i,
				'sanitize_callback' => 'wen_biz_sanitize_post',
				'default'           => 0,
				'active_callback'   => 'wen_biz_is_team_post_content_active',
				'input_attrs'       => array(
					'style'             => 'width: 40px;'
				),
				'label'             => esc_html__( 'Team #', 'wen-biz-pro' ) . $i ,
				'section'           => 'wen_biz_team',
				'choices'           => wen_biz_generate_post_array(),
				'type'              => 'select'
			)
		);

		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_team_page_' . $i,
				'sanitize_callback' => 'wen_biz_sanitize_post',
				'active_callback'   => 'wen_biz_is_team_page_content_active',
				'label'             => esc_html__( 'Team #', 'wen-biz-pro' ) . $i ,
				'section'           => 'wen_biz_team',
				'type'              => 'dropdown-pages',
			)
		);

		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_team_note_' . $i,
				'sanitize_callback' => 'sanitize_text_field',
				'custom_control'    => 'Wen_Biz_Note_Control',
				'active_callback'   => 'wen_biz_is_team_image_content_active',
				'label'             => esc_html__( 'Team #', 'wen-biz-pro' ) .  $i,
				'section'           => 'wen_biz_team',
				'type'              => 'description',
			)
		);

		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_team_image_' . $i,
				'sanitize_callback' => 'wen_biz_sanitize_image',
				'custom_control'    => 'WP_Customize_Image_Control',
				'active_callback'   => 'wen_biz_is_team_image_content_active',
				'label'             => esc_html__( 'Image', 'wen-biz-pro' ),
				'section'           => 'wen_biz_team',
			)
		);

		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_team_link_' . $i,
				'sanitize_callback' => 'esc_url_raw',
				'active_callback'   => 'wen_biz_is_team_image_content_active',
				'label'             => esc_html__( 'Link', 'wen-biz-pro' ),
				'section'           => 'wen_biz_team',
			)
		);

		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_team_target_' . $i,
				'sanitize_callback' => 'wen_biz_sanitize_checkbox',
				'active_callback'   => 'wen_biz_is_team_image_content_active',
				'label'             => esc_html__( 'Open Link in New Window/Tab', 'wen-biz-pro' ),
				'section'           => 'wen_biz_team',
				'custom_control'    => 'Wen_Biz_Toggle_Control',
			)
		);

		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_team_title_' . $i,
				'sanitize_callback' => 'sanitize_text_field',
				'active_callback'   => 'wen_biz_is_team_image_content_active',
				'label'             => esc_html__( 'Title', 'wen-biz-pro' ),
				'section'           => 'wen_biz_team',
				'type'              => 'text',
			)
		);

		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_team_position_' . $i,
				'sanitize_callback' => 'sanitize_text_field',
				'active_callback'   => 'wen_biz_is_team_active',
				'label'             => esc_html__( 'Position', 'wen-biz-pro' ),
				'section'           => 'wen_biz_team',
				'type'              => 'text',
			)
		);

		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_team_phone_' . $i,
				'sanitize_callback' => 'sanitize_text_field',
				'active_callback'   => 'wen_biz_is_team_active',
				'label'             => esc_html__( 'Phone', 'wen-biz-pro' ),
				'section'           => 'wen_biz_team',
				'type'              => 'text',
			)
		);

		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_team_email_' . $i,
				'sanitize_callback' => 'sanitize_email',
				'active_callback'   => 'wen_biz_is_team_active',
				'label'             => esc_html__( 'Email', 'wen-biz-pro' ),
				'section'           => 'wen_biz_team',
				'type'              => 'text',
			)
		);

		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_team_content_' . $i,
				'sanitize_callback' => 'wp_kses_post',
				'active_callback'   => 'wen_biz_is_team_image_content_active',
				'label'             => esc_html__( 'Content', 'wen-biz-pro' ),
				'section'           => 'wen_biz_team',
				'type'              => 'textarea',
			)
		);

		for ( $j = 1; $j < 5; $j++ ) {
			wen_biz_register_option( $wp_customize, array(
					'name'              => 'wen_biz_team_social_link_' . $j . '_' . $i,
					'sanitize_callback' => 'esc_url_raw',
					'active_callback'   => 'wen_biz_is_team_active',
					'label'             => esc_html__( 'Team #', 'wen-biz-pro' ) .  $i . esc_html__( ': Social Link #', 'wen-biz-pro' ) . $j,
					'section'           => 'wen_biz_team',
				)
			);
		}
	} // End for().

}
add_action( 'customize_register', 'wen_biz_team_options', 10 );

/** Active Callback Functions **/
if ( ! function_exists( 'wen_biz_is_team_active' ) ) :
	/**
	* Return true if team content is active
	*
	* @since 1.0.0
	*/
	function wen_biz_is_team_active( $control ) {
		$enable = $control->manager->get_setting( 'wen_biz_team_option' )->value();

		//return true only if previewed page on customizer matches the type of content option selected
		return wen_biz_check_section( $enable );
	}
endif;

if ( ! function_exists( 'wen_biz_is_team_post_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since 1.0.0
	*/
	function wen_biz_is_team_post_content_active( $control ) {
		$type = $control->manager->get_setting( 'wen_biz_team_type' )->value();

		//return true only if previewed page on customizer matches the type of content option selected and is or is not selected type
		return ( wen_biz_is_team_active( $control ) && ( 'post' === $type ) );
	}
endif;

if ( ! function_exists( 'wen_biz_is_team_page_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since 1.0.0
	*/
	function wen_biz_is_team_page_content_active( $control ) {
		$type = $control->manager->get_setting( 'wen_biz_team_type' )->value();

		//return true only if previewed page on customizer matches the type of content option selected and is or is not selected type
		return ( wen_biz_is_team_active( $control ) && ( 'page' === $type ) );
	}
endif;

if ( ! function_exists( 'wen_biz_is_team_category_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since 1.0.0
	*/
	function wen_biz_is_team_category_content_active( $control ) {
		$type = $control->manager->get_setting( 'wen_biz_team_type' )->value();

		//return true only if previewed page on customizer matches the type of content option selected and is or is not selected type
		return ( wen_biz_is_team_active( $control ) && ( 'category' === $type ) );
	}
endif;

if ( ! function_exists( 'wen_biz_is_team_post_page_category_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since 1.0.0
	*/
	function wen_biz_is_team_post_page_category_content_active( $control ) {
		$type = $control->manager->get_setting( 'wen_biz_team_type' )->value();

		//return true only if previewed page on customizer matches the type of content option selected and is or is not selected type
		return ( wen_biz_is_team_active( $control ) && ( 'category' === $type || 'page' === $type || 'post' === $type ) );
	}
endif;

if ( ! function_exists( 'wen_biz_is_team_image_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since 1.0.0
	*/
	function wen_biz_is_team_image_content_active( $control ) {
		$type = $control->manager->get_setting( 'wen_biz_team_type' )->value();

		//return true only if previewed page on customizer matches the type of content option selected and is or is not selected type
		return ( wen_biz_is_team_active( $control ) && ( 'custom' === $type ) );
	}
endif;
