<?php
/**
 * Add Testimonial Settings in Customizer
 *
 * @package Wen_Biz
*/

/**
 * Add testimonial options to theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function wen_biz_testimonial_options( $wp_customize ) {
    // Add note to Jetpack Testimonial Section
    wen_biz_register_option( $wp_customize, array(
            'name'              => 'wen_biz_jetpack_testimonial_cpt_note',
            'sanitize_callback' => 'sanitize_text_field',
            'custom_control'    => 'Wen_Biz_Note_Control',
            'label'             => sprintf( esc_html__( 'For Testimonial Options for WEN Biz Theme, go %1$shere%2$s', 'wen-biz-pro' ),
                '<a href="javascript:wp.customize.section( \'wen_biz_testimonials\' ).focus();">',
                 '</a>'
            ),
           'section'            => 'jetpack_testimonials',
            'type'              => 'description',
            'priority'          => 1,
        )
    );

    $wp_customize->add_section( 'wen_biz_testimonials', array(
            'panel'    => 'wen_biz_theme_options',
            'title'    => esc_html__( 'Testimonials', 'wen-biz-pro' ),
        )
    );

    wen_biz_register_option( $wp_customize, array(
            'name'              => 'wen_biz_testimonial_option',
            'default'           => 'disabled',
            'sanitize_callback' => 'wen_biz_sanitize_select',
            'choices'           => wen_biz_section_visibility_options(),
            'label'             => esc_html__( 'Enable on', 'wen-biz-pro' ),
            'section'           => 'wen_biz_testimonials',
            'type'              => 'select',
            'priority'          => 1,
        )
    );    

    wen_biz_register_option( $wp_customize, array(
            'name'              => 'wen_biz_testimonial_transition_in',
            'default'           => 'default',
            'sanitize_callback' => 'wen_biz_sanitize_select',
            'active_callback'   => 'wen_biz_is_testimonial_active',
            'choices'           => wen_biz_transition_effects(),
            'label'             => esc_html__( 'Transition In', 'wen-biz-pro' ),
            'section'           => 'wen_biz_testimonials',
            'type'              => 'select',
        )
    );

    wen_biz_register_option( $wp_customize, array(
            'name'              => 'wen_biz_testimonial_transition_out',
            'default'           => 'default',
            'sanitize_callback' => 'wen_biz_sanitize_select',
            'active_callback'   => 'wen_biz_is_testimonial_active',
            'choices'           => wen_biz_transition_effects(),
            'label'             => esc_html__( 'Transition Out', 'wen-biz-pro' ),
            'section'           => 'wen_biz_testimonials',
            'type'              => 'select',
        )
    );

    wen_biz_register_option( $wp_customize, array(
            'name'              => 'wen_biz_testimonial_nav_arrows',
            'default'           => 1,
            'sanitize_callback' => 'wen_biz_sanitize_checkbox',
            'active_callback'   => 'wen_biz_is_testimonial_active',
            'label'             => esc_html__( 'Display nav arrow', 'wen-biz-pro' ),
            'section'           => 'wen_biz_testimonials',
            'custom_control'    => 'Wen_Biz_Toggle_Control',
        )
    );

    wen_biz_register_option( $wp_customize, array(
            'name'              => 'wen_biz_testimonial_dots',
            'default'           => 0,
            'sanitize_callback' => 'wen_biz_sanitize_checkbox',
            'active_callback'   => 'wen_biz_is_testimonial_active',
            'label'             => esc_html__( 'Display nav dots', 'wen-biz-pro' ),
            'section'           => 'wen_biz_testimonials',
            'custom_control'    => 'Wen_Biz_Toggle_Control',
        )
    );

    wen_biz_register_option( $wp_customize, array(
            'name'              => 'wen_biz_testimonial_autoplay',
            'default'           => 0,
            'sanitize_callback' => 'wen_biz_sanitize_checkbox',
            'active_callback'   => 'wen_biz_is_testimonial_active',
            'label'             => esc_html__( 'Autoplay', 'wen-biz-pro' ),
            'section'           => 'wen_biz_testimonials',
            'custom_control'    => 'Wen_Biz_Toggle_Control',
        )
    );

    wen_biz_register_option( $wp_customize, array(
            'name'              => 'wen_biz_testimonial_loop',
            'default'           => 0,
            'sanitize_callback' => 'wen_biz_sanitize_checkbox',
            'active_callback'   => 'wen_biz_is_testimonial_active',
            'label'             => esc_html__( 'Loop (Last to first)', 'wen-biz-pro' ),
            'section'           => 'wen_biz_testimonials',
            'custom_control'    => 'Wen_Biz_Toggle_Control',
        )
    );

    wen_biz_register_option( $wp_customize, array(
            'name'              => 'wen_biz_testimonial_transition_timeout',
            'default'           => 4,
            'sanitize_callback' => 'wen_biz_sanitize_number_range',
            'active_callback'   => 'wen_biz_is_testimonial_active',
            'input_attrs'       => array(
                'style'       => 'width: 100px;',
                'min'         => 0,
            ),
            'label'             => esc_html__( 'Transition timeout', 'wen-biz-pro' ),
            'section'           => 'wen_biz_testimonials',
            'type'              => 'number',
        )
    );

    $type = wen_biz_section_type_options();

    $type['jetpack-testimonial'] = esc_html__( 'Custom Post Type', 'wen-biz-pro' );

    wen_biz_register_option( $wp_customize, array(
            'name'              => 'wen_biz_testimonial_type',
            'default'           => 'category',
            'sanitize_callback' => 'wen_biz_sanitize_select',
            'active_callback'   => 'wen_biz_is_testimonial_active',
            'choices'           => $type,
            'description'       => sprintf( esc_html__( 'For Custom Post Type Content, install %1$sEssential Content Types%2$s Plugin with Testimonial Content Type Enabled', 'wen-biz-pro' ),
                '<a target="_blank" href="https://wordpress.org/plugins/essential-content-types/">',
                '</a>'
            ),
            'label'             => esc_html__( 'Select Type', 'wen-biz-pro' ),
            'section'           => 'wen_biz_testimonials',
            'type'              => 'select',
        )
    );

    wen_biz_register_option( $wp_customize, array(
            'name'              => 'wen_biz_testimonial_tagline',
            'sanitize_callback' => 'wp_kses_post',
            'label'             => esc_html__( 'Section Tagline', 'wen-biz-pro' ),
            'active_callback'   => 'wen_biz_is_testimonial_active',
            'section'           => 'wen_biz_testimonials',
            'type'              => 'text',
        )
    );

    wen_biz_register_option( $wp_customize, array(
            'name'              => 'wen_biz_testimonial_title',
            'default'           => esc_html__( 'Testimonials', 'wen-biz-pro' ),
            'sanitize_callback' => 'wp_kses_post',
            'label'             => esc_html__( 'Section Title', 'wen-biz-pro' ),
            'active_callback'   => 'wen_biz_is_testimonial_active',
            'section'           => 'wen_biz_testimonials',
            'type'              => 'text',
        )
    );

    wen_biz_register_option( $wp_customize, array(
            'name'              => 'wen_biz_testimonial_number',
            'default'           => '5',
            'sanitize_callback' => 'wen_biz_sanitize_number_range',
            'active_callback'   => 'wen_biz_is_testimonial_active',
            'label'             => esc_html__( 'Number of items', 'wen-biz-pro' ),
            'section'           => 'wen_biz_testimonials',
            'type'              => 'number',
            'input_attrs'       => array(
                'style'             => 'width: 100px;',
                'min'               => 0,
            ),
        )
    );

    wen_biz_register_option( $wp_customize, array(
            'name'              => 'wen_biz_testimonial_show',
            'default'           => 'excerpt',
            'sanitize_callback' => 'wen_biz_sanitize_select',
            'active_callback'   => 'wen_biz_is_post_page_category_cpt_testimonial_active',
            'choices'           => wen_biz_content_show(),
            'label'             => esc_html__( 'Display Content', 'wen-biz-pro' ),
            'section'           => 'wen_biz_testimonials',
            'type'              => 'select',
        )
    );

    wen_biz_register_option( $wp_customize, array(
            'name'              => 'wen_biz_testimonial_select_category',
            'sanitize_callback' => 'wen_biz_sanitize_category_list',
            'active_callback'   => 'wen_biz_is_category_testimonial_active',
            'custom_control'    => 'Wen_Biz_Multi_Cat',
            'label'             => esc_html__( 'Select Categories', 'wen-biz-pro' ),
            'name'              => 'wen_biz_testimonial_select_category',
            'section'           => 'wen_biz_testimonials',
            'type'              => 'dropdown-categories',
        )
    );

    $number = get_theme_mod( 'wen_biz_testimonial_number', 5 );

    for ( $i = 1; $i <= $number ; $i++ ) {
        //for featured post content
        wen_biz_register_option( $wp_customize, array(
                'name'              => 'wen_biz_testimonial_post_' . $i,
                'sanitize_callback' => 'wen_biz_sanitize_post',
                'active_callback'   => 'wen_biz_is_post_testimonial_active',
                'input_attrs'       => array(
                'style'             => 'width: 100px;'
                ),
                'label'             => esc_html__( 'Post', 'wen-biz-pro' ) . ' ' . $i ,
                'section'           => 'wen_biz_testimonials',
                'choices'           => wen_biz_generate_post_array(),
                'type'              => 'select',
            )
        );

        //for CPT
        wen_biz_register_option( $wp_customize, array(
                'name'              => 'wen_biz_testimonial_cpt_' . $i,
                'sanitize_callback' => 'wen_biz_sanitize_post',
                'active_callback'   => 'wen_biz_is_jetpack_testimonial_active',
                'label'             => esc_html__( 'Testimonial', 'wen-biz-pro' ) . ' ' . $i ,
                'section'           => 'wen_biz_testimonials',
                'type'              => 'select',
                'choices'           => wen_biz_generate_post_array( 'jetpack-testimonial' ),
            )
        );

        wen_biz_register_option( $wp_customize, array(
                'name'              => 'wen_biz_testimonial_page_' . $i,
                'sanitize_callback' => 'wen_biz_sanitize_post',
                'active_callback'   => 'wen_biz_is_page_testimonial_active',
                'label'             => esc_html__( 'Page', 'wen-biz-pro' ) . ' ' . $i ,
                'section'           => 'wen_biz_testimonials',
                'type'              => 'dropdown-pages',
            )
        );

        wen_biz_register_option( $wp_customize, array(
                'name'              => 'wen_biz_testimonial_note_' . $i,
                'sanitize_callback' => 'sanitize_text_field',
                'custom_control'    => 'Wen_Biz_Note_Control',
                'active_callback'   => 'wen_biz_is_image_testimonial_active',
                'label'             => esc_html__( 'Testimonial #', 'wen-biz-pro' ) .  $i,
                'section'           => 'wen_biz_testimonials',
                'type'              => 'description',
            )
        );

        wen_biz_register_option( $wp_customize, array(
                'name'              => 'wen_biz_testimonial_image_' . $i,
                'custom_control'      => 'WP_Customize_Image_Control',
                'sanitize_callback' => 'wen_biz_sanitize_image',
                'active_callback'   => 'wen_biz_is_image_testimonial_active',
                'label'             => esc_html__( 'Image', 'wen-biz-pro' ),
                'section'           => 'wen_biz_testimonials',
            )
        );

        wen_biz_register_option( $wp_customize, array(
                'name'              => 'wen_biz_testimonial_link_' . $i,
                'sanitize_callback' => 'esc_url_raw',
                'active_callback'   => 'wen_biz_is_image_testimonial_active',
                'label'             => esc_html__( 'Link', 'wen-biz-pro' ),
                'section'           => 'wen_biz_testimonials',
            )
        );

        wen_biz_register_option( $wp_customize, array(
                'name'              => 'wen_biz_testimonial_target_' . $i,
                'sanitize_callback' => 'wen_biz_sanitize_checkbox',
                'active_callback'   => 'wen_biz_is_image_testimonial_active',
                'label'             => esc_html__( 'Open Link in New Window/Tab', 'wen-biz-pro' ),
                'section'           => 'wen_biz_testimonials',
                'custom_control'    => 'Wen_Biz_Toggle_Control',
            )
        );

        wen_biz_register_option( $wp_customize, array(
                'name'              => 'wen_biz_testimonial_content_' . $i,
                'sanitize_callback' => 'sanitize_text_field',
                'active_callback'   => 'wen_biz_is_image_testimonial_active',
                'label'             => esc_html__( 'Testimonial Text', 'wen-biz-pro' ),
                'section'           => 'wen_biz_testimonials',
                'type'              => 'textarea',
            )
        );

        wen_biz_register_option( $wp_customize, array(
                'name'              => 'wen_biz_testimonial_title_' . $i,
                'sanitize_callback' => 'sanitize_text_field',
                'active_callback'   => 'wen_biz_is_image_testimonial_active',
                'label'             => esc_html__( 'Name', 'wen-biz-pro' ),
                'section'           => 'wen_biz_testimonials',
                'type'              => 'text',
            )
        );

        wen_biz_register_option( $wp_customize, array(
                'name'              => 'wen_biz_testimonial_position_' . $i,
                'sanitize_callback' => 'sanitize_text_field',
                'active_callback'   => 'wen_biz_is_cpt_testimonial_inactive',
                'label'             => esc_html__( 'Position', 'wen-biz-pro' ),
                'section'           => 'wen_biz_testimonials',
                'type'              => 'text',
            )
        );
    } // End for().
}
add_action( 'customize_register', 'wen_biz_testimonial_options' );

/**
 * Active Callback Functions
 */
if ( ! function_exists( 'wen_biz_is_testimonial_active' ) ) :
    /**
    * Return true if testimonial is active
    *
    * @since 1.0.0
    */
    function wen_biz_is_testimonial_active( $control ) {
        $enable = $control->manager->get_setting( 'wen_biz_testimonial_option' )->value();

        //return true only if previwed page on customizer matches the type of content option selected
        return wen_biz_check_section( $enable );
    }
endif;

if ( ! function_exists( 'wen_biz_is_post_testimonial_active' ) ) :
    /**
    * Return true if page content is active
    *
    * @since 1.0.0
    */
    function wen_biz_is_post_testimonial_active( $control ) {
        $type = $control->manager->get_setting( 'wen_biz_testimonial_type' )->value();

        //return true only if previwed page on customizer matches the type of option selected
        return ( wen_biz_is_testimonial_active( $control ) && 'post' === $type );
    }
endif;

if ( ! function_exists( 'wen_biz_is_jetpack_testimonial_active' ) ) :
    /**
    * Return true if jetpack testimonial is active
    *
    * @since 1.0.0
    */
    function wen_biz_is_jetpack_testimonial_active( $control ) {
        $type = $control->manager->get_setting( 'wen_biz_testimonial_type' )->value();

        //return true only if previwed page on customizer matches the type of option selected
        return ( wen_biz_is_testimonial_active( $control ) && 'jetpack-testimonial' === $type );
    }
endif;

if ( ! function_exists( 'wen_biz_is_page_testimonial_active' ) ) :
    /**
    * Return true if page content is active
    *
    * @since 1.0.0
    */
    function wen_biz_is_page_testimonial_active( $control ) {
        $type = $control->manager->get_setting( 'wen_biz_testimonial_type' )->value();

        //return true only if previwed page on customizer matches the type of option selected
        return ( wen_biz_is_testimonial_active( $control ) && 'page' === $type );
    }
endif;

if ( ! function_exists( 'wen_biz_is_category_testimonial_active' ) ) :
    /**
    * Return true if page content is active
    *
    * @since 1.0.0
    */
    function wen_biz_is_category_testimonial_active( $control ) {
        $type = $control->manager->get_setting( 'wen_biz_testimonial_type' )->value();

        //return true only if previwed page on customizer matches the type of option selected
        return ( wen_biz_is_testimonial_active( $control ) && 'category' === $type );
    }
endif;

if ( ! function_exists( 'wen_biz_is_post_page_category_cpt_testimonial_active' ) ) :
    /**
    * Return true if custom option is not active
    *
    * @since 1.0.0
    */
    function wen_biz_is_post_page_category_cpt_testimonial_active( $control ) {
        $type = $control->manager->get_setting( 'wen_biz_testimonial_type' )->value();

        //return true only if previwed page on customizer matches the type of option selected
        return ( wen_biz_is_testimonial_active( $control ) && 'custom' !== $type );
    }
endif;

if ( ! function_exists( 'wen_biz_is_cpt_testimonial_inactive' ) ) :
    /**
    * Return true if cpt option is not active
    *
    * @since 1.0.0
    */
    function wen_biz_is_cpt_testimonial_inactive( $control ) {
        $type = $control->manager->get_setting( 'wen_biz_testimonial_type' )->value();

        //return true only if previwed page on customizer matches the type of option selected
        return ( wen_biz_is_testimonial_active( $control ) && 'jetpack-testimonial' !== $type );
    }
endif;

if ( ! function_exists( 'wen_biz_is_image_testimonial_active' ) ) :
    /**
    * Return true if page content is active
    *
    * @since 1.0.0
    */
    function wen_biz_is_image_testimonial_active( $control ) {
        $type = $control->manager->get_setting( 'wen_biz_testimonial_type' )->value();

        //return true only if previwed page on customizer matches the type of option selected
        return ( wen_biz_is_testimonial_active( $control ) && 'custom' === $type );
    }
endif;
