<?php
/**
 * Theme Options
 *
 * @package Wen_Biz
 */

/**
 * Add theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function wen_biz_theme_options( $wp_customize ) {
	$wp_customize->add_panel( 'wen_biz_theme_options', array(
		'title'    => esc_html__( 'Theme Options', 'wen-biz-pro' ),
		'priority' => 130,
	) );

	// Font Family Options.
	$wp_customize->add_section( 'wen_biz_font_family', array(
		'panel' => 'wen_biz_theme_options',
		'title' => esc_html__( 'Font Family Options', 'wen-biz-pro' ),
	) );

	$avaliable_fonts = wen_biz_avaliable_fonts();

	$choices = array();

	foreach ( $avaliable_fonts as $font ) {
		$choices[ $font['value'] ] = str_replace( '"', '', $font['label'] );
	}

	$font_family_options = wen_biz_font_family_options();

	foreach ( $font_family_options as $key => $value ) {
		wen_biz_register_option( $wp_customize, array(
				'name'              => $key,
				'default'           => $value['default'],
				'sanitize_callback' => 'wen_biz_sanitize_select',
				'choices'           => $choices,
				'label'             => $value['label'],
				'section'           => 'wen_biz_font_family',
				'type'              => 'select',
			)
		);
	}

	// Footer Options.
	$wp_customize->add_section( 'wen_biz_footer_options', array(
		'title'       => esc_html__( 'Footer Options', 'wen-biz-pro' ),
		'description' => esc_html__( 'You can either add html or plain text or custom shortcodes, which will be automatically inserted into your theme. Some shorcodes: [the-year], [site-link] and [privacy-policy-link] for current year, site link and privacy policy link respectively.', 'wen-biz-pro' ),
		'panel'       => 'wen_biz_theme_options',
	) );

	$theme_data = wp_get_theme();

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_footer_copyright_text',
			'default'           => sprintf( _x( 'Copyright &copy; %1$s %2$s %3$s', '1: Year, 2: Site Title with home URL, 3: Privacy Policy Link', 'wen-biz-pro' ), '[the-year]', '[site-link]', '[privacy-policy-link]' ) . '<span class="sep"> | </span>',
			'sanitize_callback' => 'wp_kses_post',
			'label'             => esc_html__( 'Copyright Text', 'wen-biz-pro' ),
			'section'           => 'wen_biz_footer_options',
			'type'              => 'textarea',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_footer_powered_by',
			'default'           => esc_html( $theme_data->get( 'Name' ) ) . '&nbsp;' . esc_html__( 'by', 'wen-biz-pro' ) . '&nbsp;<a target="_blank" href="' . esc_url( $theme_data->get( 'AuthorURI' ) ) . '">' . esc_html( $theme_data->get( 'Author' ) ) . '</a>',
			'sanitize_callback' => 'wp_kses_post',
			'label'             => esc_html__( 'Powered By Text', 'wen-biz-pro' ),
			'section'           => 'wen_biz_footer_options',
			'type'              => 'textarea',
		)
	);

	// Layout Options
	$wp_customize->add_section( 'wen_biz_layout_options', array(
		'title' => esc_html__( 'Layout Options', 'wen-biz-pro' ),
		'panel' => 'wen_biz_theme_options',
		)
	);

	/* Layout Type */
	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_layout_type',
			'default'           => 'fluid',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'label'             => esc_html__( 'Site Layout', 'wen-biz-pro' ),
			'section'           => 'wen_biz_layout_options',
			'type'              => 'select',
			'choices'           => array(
				'fluid' => esc_html__( 'Fluid', 'wen-biz-pro' ),
				'boxed' => esc_html__( 'Boxed', 'wen-biz-pro' ),
			),
		)
	);

	/* Default Layout */
	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_default_layout',
			'default'           => 'right-sidebar',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'label'             => esc_html__( 'Default Layout', 'wen-biz-pro' ),
			'section'           => 'wen_biz_layout_options',
			'type'              => 'select',
			'choices'           => array(
				'right-sidebar'         => esc_html__( 'Right Sidebar ( Content, Primary Sidebar )', 'wen-biz-pro' ),
				'left-sidebar'          => esc_html__( 'Left Sidebar ( Primary Sidebar, Content )', 'wen-biz-pro' ),
				'no-sidebar'            => esc_html__( 'No Sidebar', 'wen-biz-pro' ),
				'no-sidebar-full-width' => esc_html__( 'No Sidebar: Full Width', 'wen-biz-pro' ),
			),
		)
	);

	/* Homepage/Archive Layout */
	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_homepage_archive_layout',
			'default'           => 'right-sidebar',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'label'             => esc_html__( 'Homepage/Archive Layout', 'wen-biz-pro' ),
			'section'           => 'wen_biz_layout_options',
			'type'              => 'select',
			'choices'           => array(
				'right-sidebar'         => esc_html__( 'Right Sidebar ( Content, Primary Sidebar )', 'wen-biz-pro' ),
				'left-sidebar'          => esc_html__( 'Left Sidebar ( Primary Sidebar, Content )', 'wen-biz-pro' ),
				'no-sidebar'            => esc_html__( 'No Sidebar', 'wen-biz-pro' ),
				'no-sidebar-full-width' => esc_html__( 'No Sidebar: Full Width', 'wen-biz-pro' ),
			),
		)
	);

	/* Archive Content Layout */
	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_content_layout',
			'default'           => 'excerpt',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'label'             => esc_html__( 'Archive Content Layout', 'wen-biz-pro' ),
			'section'           => 'wen_biz_layout_options',
			'type'              => 'select',
			'choices'           => array(
				'excerpt'             => esc_html__( 'Excerpt with Featured Image', 'wen-biz-pro' ),
				'full-content-custom' => esc_html__( 'Show Full Content With Image', 'wen-biz-pro' ),
				'full-content'        => esc_html__( 'Show Full Content ( No Featured Image )', 'wen-biz-pro' ),
			),
		)
	);

	wen_biz_register_option( $wp_customize, array(
    		'name'              => 'wen_biz_blog_post_layout',
    		'default'           => 'layout-one',
    		'sanitize_callback' => 'wen_biz_sanitize_select',
    		'label'             => esc_html__( 'Blog/Archive Posts Column', 'wen-biz-pro' ),
    		'section'           => 'wen_biz_layout_options',
    		'type'              => 'select',
    		'choices'           => array(
				'layout-one'   => esc_html__( '1 Column', 'wen-biz-pro' ),
				'layout-two'   => esc_html__( '2 Columns', 'wen-biz-pro' ),
				'layout-three' => esc_html__( '3 Columns', 'wen-biz-pro' ),
    		),
    	)
	);

    wen_biz_register_option( $wp_customize, array(
    		'name'              => 'wen_biz_homepage_post_layout',
    		'default'           => 'layout-one',
    		'sanitize_callback' => 'wen_biz_sanitize_select',
    		'label'             => esc_html__( 'Homepage Posts Column', 'wen-biz-pro' ),
    		'section'           => 'wen_biz_layout_options',
    		'type'              => 'select',
    		'choices'           => array(
				'layout-one'   => esc_html__( '1 Column', 'wen-biz-pro' ),
				'layout-two'   => esc_html__( '2 Columns', 'wen-biz-pro' ),
				'layout-three' => esc_html__( '3 Columns', 'wen-biz-pro' ),
    		),
    	)
	);

	wen_biz_register_option( $wp_customize, array(
            'name'               => 'wen_biz_single_page_title',
            'default'			 => 1,
            'sanitize_callback'  => 'wen_biz_sanitize_checkbox',
            'label'              => esc_html__( 'Single Page title', 'wen-biz-pro' ),
            'section'            => 'wen_biz_layout_options',
            'custom_control'    => 'Wen_Biz_Toggle_Control',
        )
    );

	/* Single Page/Post Image */
	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_single_layout',
			'default'           => 'disabled',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'label'             => esc_html__( 'Single Page/Post Image', 'wen-biz-pro' ),
			'section'           => 'wen_biz_layout_options',
			'type'              => 'select',
			'choices'           => array(
				'disabled'        => esc_html__( 'Disabled', 'wen-biz-pro' ),
				'post-thumbnail'  => esc_html__( 'Post Thumbnail', 'wen-biz-pro' ),
				'wen-biz-slider' => esc_html__( 'Slider Image Size (1920x822)', 'wen-biz-pro' ),
				'full'            => esc_html__( 'Original Image Size', 'wen-biz-pro' ),
			),
		)
	);

	// Excerpt Options.
	$wp_customize->add_section( 'wen_biz_excerpt_options', array(
		'panel'     => 'wen_biz_theme_options',
		'title'     => esc_html__( 'Excerpt Options', 'wen-biz-pro' ),
	) );

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_excerpt_length',
			'default'           => '25',
			'sanitize_callback' => 'absint',
			'input_attrs' => array(
				'min'   => 10,
				'max'   => 200,
				'step'  => 5,
				'style' => 'width: 80px;',
			),
			'label'    => esc_html__( 'Excerpt Length (words)', 'wen-biz-pro' ),
			'section'  => 'wen_biz_excerpt_options',
			'type'     => 'number',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_excerpt_more_text',
			'default'           => esc_html__( 'Continue reading', 'wen-biz-pro' ),
			'sanitize_callback' => 'sanitize_text_field',
			'label'             => esc_html__( 'Read More Text', 'wen-biz-pro' ),
			'section'           => 'wen_biz_excerpt_options',
			'type'              => 'text',
		)
	);
	
	// Search Options.
	$wp_customize->add_section( 'wen_biz_search_options', array(
		'panel'     => 'wen_biz_theme_options',
		'title'     => esc_html__( 'Search Options', 'wen-biz-pro' ),
	) );

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_search_text',
			'default'           => esc_html__( 'Search a keyword', 'wen-biz-pro' ),
			'sanitize_callback' => 'sanitize_text_field',
			'label'             => esc_html__( 'Search Text', 'wen-biz-pro' ),
			'section'           => 'wen_biz_search_options',
			'type'              => 'text',
		)
	);

	// Comment Option.
	$wp_customize->add_section( 'wen_biz_comment_option', array(
		'description'   => esc_html__( 'Comments can also be disabled on a per post/page basis when creating/editing posts/pages.', 'wen-biz-pro' ),
		'panel'         => 'wen_biz_theme_options',
		'title'         => esc_html__( 'Comment Options', 'wen-biz-pro' ),
	) );

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_comment_option',
			'default'           => 'use-wordpress-setting',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'choices'           => array(
				'use-wordpress-setting' => esc_html__( 'Use WordPress Setting', 'wen-biz-pro' ),
				'disable-in-pages'      => esc_html__( 'Disable in Pages', 'wen-biz-pro' ),
				'disable-completely'    => esc_html__( 'Disable Completely', 'wen-biz-pro' ),
			),
			'label'             => __( 'Comment Option', 'wen-biz-pro' ),
			'section'           => 'wen_biz_comment_option',
			'type'              => 'select',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_website_field',
			'sanitize_callback' => 'wen_biz_sanitize_checkbox',
			'default'           => 1,
			'label'             => esc_html__( 'Display Website Field', 'wen-biz-pro' ),
			'section'           => 'wen_biz_comment_option',
			'custom_control'    => 'Wen_Biz_Toggle_Control',
		)
	);

	// Homepage / Frontpage Options.
	$wp_customize->add_section( 'wen_biz_homepage_options', array(
		'description' => esc_html__( 'Only posts that belong to the categories selected here will be displayed on the front page', 'wen-biz-pro' ),
		'panel'       => 'wen_biz_theme_options',
		'title'       => esc_html__( 'Homepage / Frontpage Options', 'wen-biz-pro' ),
	) );

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_display_homepage_posts',
			'default'			=> 1,
			'sanitize_callback' => 'wen_biz_sanitize_checkbox',
			'label'             => esc_html__( 'Recent Posts/Content on homepage', 'wen-biz-pro' ),
			'section'           => 'wen_biz_homepage_options',
			'custom_control'    => 'Wen_Biz_Toggle_Control',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_recent_posts_tagline',
			'default'              => 'Latest Updates & Posts',
			'sanitize_callback' => 'wp_kses_post',
			'label'             => esc_html__( 'Recent Posts Tagline', 'wen-biz-pro' ),
			'section'           => 'wen_biz_homepage_options',
			'type'              => 'text'
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_recent_posts_title',
			'sanitize_callback' => 'sanitize_text_field',
			'default'           => esc_html__( 'From Our Blog', 'wen-biz-pro' ),
			'label'             => esc_html__( 'Recent Posts Title', 'wen-biz-pro' ),
			'section'           => 'wen_biz_homepage_options',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_static_page_heading',
			'sanitize_callback' => 'sanitize_text_field',
			'active_callback'	=> 'wen_biz_is_static_page_enabled',
			'default'           => esc_html__( 'Archives', 'wen-biz-pro' ),
			'label'             => esc_html__( 'Posts Page Header Text', 'wen-biz-pro' ),
			'section'           => 'wen_biz_homepage_options',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_front_page_category',
			'sanitize_callback' => 'wen_biz_sanitize_category_list',
			'custom_control'    => 'Wen_Biz_Multi_Cat',
			'active_callback'   => 'wen_biz_is_homepage_posts_enabled',
			'label'             => esc_html__( 'Categories', 'wen-biz-pro' ),
			'section'           => 'wen_biz_homepage_options',
			'type'              => 'dropdown-categories',
		)
	);

	// Disable Recent post in static frontpage
    wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_enable_static_page_posts',
			'sanitize_callback' => 'wen_biz_sanitize_checkbox',
			'label'             => esc_html__( 'Recent Posts on Static Page', 'wen-biz-pro' ),
			'section'           => 'wen_biz_homepage_options',
			'custom_control'    => 'Wen_Biz_Toggle_Control',
	    )
	);

	//Menu Options
	$wp_customize->add_section( 'wen_biz_menu_options', array(
		'description' => esc_html__( 'Extra Menu Options specific to this theme', 'wen-biz-pro' ),
		'title'       => esc_html__( 'Menu Options', 'wen-biz-pro' ),
		'panel'       => 'wen_biz_theme_options',
	) );

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_primary_search_enable',
			'default'			=> 1,
			'sanitize_callback' => 'wen_biz_sanitize_checkbox',
			'label'             => esc_html__( 'Search in Primary Menu', 'wen-biz-pro' ),
			'section'           => 'wen_biz_menu_options',
			'custom_control'    => 'Wen_Biz_Toggle_Control',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_menu_type',
			'default'           => 'classic',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'label'             => esc_html__( 'Menu Type', 'wen-biz-pro' ),
			'section'           => 'wen_biz_menu_options',
			'type'              => 'radio',
			'choices'           => array(
				'modern'  => esc_html__( 'Modern', 'wen-biz-pro' ),
				'classic' => esc_html__( 'Classic', 'wen-biz-pro' ),
				'fullscreen' => esc_html__( 'Modern FullScreen', 'wen-biz-pro' ),
	        ),
	    )
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_mobile_fullscreen_enable',
			'sanitize_callback' => 'wen_biz_sanitize_checkbox',
			'active_callback' 	=> 'wen_biz_fullscreen_menu_active',
			'label'             => esc_html__( 'FullScreen on Mobile', 'wen-biz-pro' ),
			'section'           => 'wen_biz_menu_options',
			'custom_control'    => 'Wen_Biz_Toggle_Control',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_primary_button_label',
			'default'           => esc_html__( 'Free Consultation', 'wen-biz-pro' ),
			'sanitize_callback' => 'sanitize_text_field',
			'label'             => esc_html__( 'Primary Button Label', 'wen-biz-pro' ),
			'section'           => 'wen_biz_menu_options',
			'type'              => 'text',
		)
	);

	wen_biz_register_option( $wp_customize, array(
	        'name'              => 'wen_biz_primary_button_link',
	        'sanitize_callback' => 'esc_url_raw',
	        'label'             => esc_html__( 'Primary Button Link', 'wen-biz-pro' ),
	        'section'           => 'wen_biz_menu_options',
	    )
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_primary_button_target',
			'default'			=> 1,
			'sanitize_callback' => 'wen_biz_sanitize_checkbox',
			'label'             => esc_html__( 'Open in New Tab', 'wen-biz-pro' ),
			'section'           => 'wen_biz_menu_options',
			'custom_control'    => 'Wen_Biz_Toggle_Control',
		)
	);

	//Menu Options End

	// Pagination Options.
	$pagination_type = get_theme_mod( 'wen_biz_pagination_type', 'default' );

	$nav_desc = '';

	/**
	* Check if navigation type is Jetpack Infinite Scroll and if it is enabled
	*/
	$nav_desc = sprintf(
		wp_kses(
			__( 'For infinite scrolling, use %1$sCatch Infinite Scroll Plugin%2$s with Infinite Scroll module Enabled.', 'wen-biz-pro' ),
			array(
				'a' => array(
					'href' => array(),
					'target' => array(),
				),
				'br'=> array()
			)
		),
		'<a target="_blank" href="https://wordpress.org/plugins/catch-infinite-scroll/">',
		'</a>'
	);

	$wp_customize->add_section( 'wen_biz_pagination_options', array(
		'description'     => $nav_desc,
		'panel'           => 'wen_biz_theme_options',
		'title'           => esc_html__( 'Pagination Options', 'wen-biz-pro' ),
		'active_callback' => 'wen_biz_scroll_plugins_inactive'
	) );

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_pagination_type',
			'default'           => 'default',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'choices'           => wen_biz_get_pagination_types(),
			'label'             => esc_html__( 'Pagination type', 'wen-biz-pro' ),
			'section'           => 'wen_biz_pagination_options',
			'type'              => 'select',
		)
	);

	// For WooCommerce layout: wen_biz_woocommerce_layout, check woocommerce-options.php.
	/* Scrollup Options */
	$wp_customize->add_section( 'wen_biz_scrollup', array(
		'panel'    => 'wen_biz_theme_options',
		'title'    => esc_html__( 'Scrollup Options', 'wen-biz-pro' ),
	) );

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_disable_scrollup',
			'default'			=> 1,
			'sanitize_callback' => 'wen_biz_sanitize_checkbox',
			'label'             => esc_html__( 'Scroll Up', 'wen-biz-pro' ),
			'section'           => 'wen_biz_scrollup',
			'custom_control'    => 'Wen_Biz_Toggle_Control',
		)
	);

	// Section Sorter.
	$wp_customize->add_section( 'wen_biz_sections_sort', array(
		'title'       => esc_html__( 'Sections Sorter', 'wen-biz-pro' ),
		'description' => esc_html__( 'Drag and drop to sort your sections', 'wen-biz-pro' ),
		'panel'       => 'wen_biz_theme_options',
	) );

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_sections_sort',
			'default'           => wen_biz_get_default_sections_value(),
			'label'             => esc_html__( 'Sortable Sections', 'wen-biz-pro' ),
			'custom_control'    => 'Wen_Biz_Sortable_Custom_Control',
			'sanitize_callback' => 'sanitize_text_field',
			'section'           => 'wen_biz_sections_sort',
			'type'              => 'custom-sortable',
		)
	);
}
add_action( 'customize_register', 'wen_biz_theme_options' );


/**
 * Returns an array of avaliable fonts registered for WEN Biz
 *
 * @since 1.0.0
 */
function wen_biz_avaliable_fonts() {
	$avaliable_fonts = array(
		'arial-black' => array(
			'value' => 'arial-black',
			'label' => '"Arial Black", Gadget, sans-serif',
		),
		'allan' => array(
			'value' => 'allan',
			'label' => '"Allan", sans-serif',
		),
		'allerta' => array(
			'value' => 'allerta',
			'label' => '"Allerta", sans-serif',
		),
		'amaranth' => array(
			'value' => 'amaranth',
			'label' => '"Amaranth", sans-serif',
		),
		'amatic-sc' => array(
			'value' => 'amatic-sc',
			'label' => '"Amatic SC", cursive',
		),
		'arial' => array(
			'value' => 'arial',
			'label' => 'Arial, Helvetica, sans-serif',
		),
		'bitter' => array(
			'value' => 'bitter',
			'label' => '"Bitter", sans-serif',
		),
		'cabin' => array(
			'value' => 'cabin',
			'label' => '"Cabin", sans-serif',
		),
		'cantarell' => array(
			'value' => 'cantarell',
			'label' => '"Cantarell", sans-serif',
		),
		'century-gothic' => array(
			'value' => 'century-gothic',
			'label' => '"Century Gothic", sans-serif',
		),
		'courier-new' => array(
			'value' => 'courier-new',
			'label' => '"Courier New", Courier, monospace',
		),
		'crimson-text' => array(
			'value' => 'crimson-text',
			'label' => '"Crimson Text", sans-serif',
		),
		'cuprum' => array(
			'value' => 'cuprum',
			'label' => '"Cuprum", sans-serif',
		),
		'dancing-script' => array(
			'value' => 'dancing-script',
			'label' => '"Dancing Script", sans-serif',
		),
		'droid-sans' => array(
			'value' => 'droid-sans',
			'label' => '"Droid Sans", sans-serif',
		),
		'droid-serif' => array(
			'value' => 'droid-serif',
			'label' => '"Droid Serif", sans-serif',
		),
		'exo' => array(
			'value' => 'exo',
			'label' => '"Exo", sans-serif',
		),
		'exo-2' => array(
			'value' => 'exo-2',
			'label' => '"Exo 2", sans-serif',
		),
		'georgia' => array(
			'value' => 'georgia',
			'label' => 'Georgia, "Times New Roman", Times, serif',
		),
		'helvetica' => array(
			'value' => 'helvetica',
			'label' => 'Helvetica, "Helvetica Neue", Arial, sans-serif',
		),
		'helvetica-neue' => array(
			'value' => 'helvetica-neue',
			'label' => '"Helvetica Neue",Helvetica,Arial,sans-serif',
		),
		'istok-web' => array(
			'value' => 'istok-web',
			'label' => '"Istok Web", sans-serif',
		),
		'impact' => array(
			'value' => 'impact',
			'label' => 'Impact, Charcoal, sans-serif',
		),
		'josefin-sans' => array(
			'value' => 'josefin-sans',
			'label' => '"Josefin Sans", sans-serif',
		),
		'lato' => array(
			'value' => 'lato',
			'label' => '"Lato", sans-serif',
		),
		'lucida-sans-unicode' => array(
			'value' => 'lucida-sans-unicode',
			'label' => '"Lucida Sans Unicode", "Lucida Grande", sans-serif',
		),
		'lucida-grande' => array(
			'value' => 'lucida-grande',
			'label' => '"Lucida Grande", "Lucida Sans Unicode", sans-serif',
		),
		'lobster' => array(
			'value' => 'lobster',
			'label' => '"Lobster", sans-serif',
		),
		'lora' => array(
			'value' => 'lora',
			'label' => '"Lora", serif',
		),
		'monaco' => array(
			'value' => 'monaco',
			'label' => 'Monaco, Consolas, "Lucida Console", monospace, sans-serif',
		),
		'muli' => array(
			'value' => 'muli',
			'label' => 'Muli, sans-serif',
		),
		'mrs-saint-delafield' => array(
			'value' => 'mrs-saint-delafield',
			'label' => '"Mrs Saint Delafield", cursive',
		),
		'montserrat' => array(
			'value' => 'montserrat',
			'label' => '"Montserrat", sans-serif',
		),
		'nobile' => array(
			'value' => 'nobile',
			'label' => '"Nobile", sans-serif',
		),
		'noto-serif' => array(
			'value' => 'noto-serif',
			'label' => '"Noto Serif", serif',
		),
		'neuton' => array(
			'value' => 'neuton',
			'label' => '"Neuton", serif',
		),
		'open-sans' => array(
			'value' => 'open-sans',
			'label' => '"Open Sans", sans-serif',
		),
		'oswald' => array(
			'value' => 'oswald',
			'label' => '"Oswald", sans-serif',
		),
		'palatino' => array(
			'value' => 'palatino',
			'label' => 'Palatino, "Palatino Linotype", "Book Antiqua", serif',
		),
		'patua-one' => array(
			'value' => 'patua-one',
			'label' => '"Patua One", sans-serif',
		),
		'poppins' => array(
			'value' => 'poppins',
			'label' => '"Poppins", sans-serif',
		),
		'playfair-display' => array(
			'value' => 'playfair-display',
			'label' => '"Playfair Display", sans-serif',
		),
		'pt-sans' => array(
			'value' => 'pt-sans',
			'label' => '"PT Sans", sans-serif',
		),
		'pt-serif' => array(
			'value' => 'pt-serif',
			'label' => '"PT Serif", serif',
		),
		'quattrocento-sans' => array(
			'value' => 'quattrocento-sans',
			'label' => '"Quattrocento Sans", sans-serif',
		),
		'roboto' => array(
			'value' => 'roboto',
			'label' => '"Roboto", sans-serif',
		),
		'roboto-slab' => array(
			'value' => 'roboto-slab',
			'label' => '"Roboto Slab", serif',
		),
		'rubik' => array(
			'value' => 'rubik',
			'label' => '"Rubik", serif',
		),
		'sans-serif' => array(
			'value' => 'sans-serif',
			'label' => 'Sans Serif, Arial',
		),
		'source-sans-pro' => array(
			'value' => 'source-sans-pro',
			'label' => '"Source Sans Pro", sans-serif',
		),
		'tahoma' => array(
			'value' => 'tahoma',
			'label' => 'Tahoma, Geneva, sans-serif',
		),
		'trebuchet-ms' => array(
			'value' => 'trebuchet-ms',
			'label' => '"Trebuchet MS", "Helvetica", sans-serif',
		),
		'times-new-roman' => array(
			'value' => 'times-new-roman',
			'label' => '"Times New Roman", Times, serif',
		),
		'titillium-web' => array(
			'value' => 'titillium-web',
			'label' => '"Titillium Web", sans-serif',
		),
		'ubuntu' => array(
			'value' => 'ubuntu',
			'label' => '"Ubuntu", sans-serif',
		),
		'varela' => array(
			'value' => 'varela',
			'label' => '"Varela", sans-serif',
		),
		'verdana' => array(
			'value' => 'verdana',
			'label' => 'Verdana, Geneva, sans-serif',
		),
		'yanone-kaffeesatz' => array(
			'value' => 'yanone-kaffeesatz',
			'label' => '"Yanone Kaffeesatz", sans-serif',
		),
	);

	return apply_filters( 'wen_biz_avaliable_fonts', $avaliable_fonts );
}


/**
 * Returns an array of font family options
 *
 * @since 1.0.0
 */
function wen_biz_font_family_options() {
	$options = array(
		'wen_biz_body_font'         => array(
			'label'    => esc_html__( 'Default Font Family', 'wen-biz-pro' ),
			'default'  => 'open-sans',
			'selector' => 'body, input, select, textarea, .contact-details .section-description',
		),
		'wen_biz_title_font'        => array(
			'label'    => esc_html__( 'Site Title Font Family', 'wen-biz-pro' ),
			'default'  => 'titillium-web',
			'selector' => '.site-title',
		),
		'wen_biz_tagline_font'      => array(
			'label'    => esc_html__( 'Site Tagline Font Family', 'wen-biz-pro' ),
			'default'  => 'open-sans',
			'selector' => '.site-description',
		),
		'wen_biz_content_title_font' => array(
			'label'    => esc_html__( 'Content Title Font Family', 'wen-biz-pro' ),
			'default'  => 'titillium-web',
			'selector' => '.entry-title, .widget-title, .widgettitle, blockquote.wp-block-quote, .wp-block-pullquote, .widget-area li, .custom-header-media .breadcrumb, .custom-header-media .woocommerce-breadcrumb, .promotion-content-wrapper .post-thumbnail-stats-wrapper .promotion-stats, .featured-content-wrapper .more-link, .inner-contact, .wpcf7-form > p > label',
		),
		'wen_biz_headings_font'     => array(
			'label'    => esc_html__( 'Headings Tags from h1 to h6 Font Family', 'wen-biz-pro' ),
			'default'  => 'titillium-web',
			'selector' => 'h1, h2, h3, h4, h5, h6, .section-title, .section-tagline, .section-description, #feature-slider-section .entry-meta, .custom-header .entry-title, .feature-slider-section .entry-title, .app-section .entry-title, .gallery-section .entry-title, .hero-section .entry-title, .promotion-section .entry-title, .gallery-section .entry-title, .header-top-bar, .main-navigation, .custom-header-media .entry-meta, .page .site-main .entry-footer .entry-meta,
			.single .site-main .entry-footer .entry-meta, .entry-meta, .author-description .author-title, .post-navigation .nav-subtitle, .comments-title, .comment-reply-title, .hero-content-wrapper .entry-content .block-one-title, .hero-content-wrapper .entry-content .block-two-title, .contact-form-section .contact, .team-contact-details li',
		),
		'wen_biz_button_font'     => array(
			'label'    => esc_html__( 'Button Font Family', 'wen-biz-pro' ),
			'default'  => 'titillium-web',
			'selector' => '.author-link, button, .button, .posts-navigation a, input[type="submit"].submit, .filter-button-group .button, .woocommerce #respond input#submit, .woocommerce a.button, .woocommerce button.button, .woocommerce input.button, .comment-meta .author-name, #content #infinite-handle span button, .ui-tabs .ui-tabs-nav li a, input[type="button"], input[type="reset"], input[type="submit"], input[type="submit"].wpcf7-submit, .wp-block-file .wp-block-file__button, .wp-block-search .wp-block-search__button, .wp-block-button .wp-block-button__link, .single .site-main .entry-footer .entry-meta>span:not(.edit-link) a, .post-navigation .nav-title, .comment-reply-link, .pagination .page-numbers, .woocommerce .product-container .wc-forward, .more-button .more-link',
		),
	);

	return apply_filters( 'wen_biz_font_family_options', $options );
}

/** Active Callback Functions */

if ( ! function_exists( 'wen_biz_is_homepage_posts_enabled' ) ) :
	/**
	* Return true if hommepage posts/content is enabled
	*
	* @since 1.0.0
	*/
	function wen_biz_is_homepage_posts_enabled( $control ) {
		return ( $control->manager->get_setting( 'wen_biz_display_homepage_posts' )->value() ? true : false );
	}
endif;

if ( ! function_exists( 'wen_biz_scroll_plugins_inactive' ) ) :
	/**
	* Return true if infinite scroll functionality exists
	*
	* @since 1.0.0
	*/
	function wen_biz_scroll_plugins_inactive( $control ) {
		if ( ( class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'infinite-scroll' ) ) || class_exists( 'Catch_Infinite_Scroll' ) ) {
			// Support infinite scroll plugins.
			return false;
		}

		return true;
	}
endif;

if ( ! function_exists( 'wen_biz_is_static_page_enabled' ) ) :
	/**
	* Return true if A Static Page is enabled
	*
	* @since 1.0.0
	*/
	function wen_biz_is_static_page_enabled( $control ) {
		$enable = $control->manager->get_setting( 'show_on_front' )->value();
		if ( 'page' === $enable ) {
			return true;
		}
		return false;
	}
endif;

if ( ! function_exists( 'wen_biz_scroll_plugins_inactive' ) ) :
	/**
	* Return true if infinite scroll functionality exists
	*
	* @since 1.0.0
	*/
	function wen_biz_scroll_plugins_inactive( $control ) {
		if ( ( class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'infinite-scroll' ) ) || class_exists( 'Catch_Infinite_Scroll' ) ) {
			// Support infinite scroll plugins.
			return false;
		}

		return true;
	}
endif;

if ( ! function_exists( 'wen_biz_fullscreen_menu_active' ) ) :
	/**
	* Return true if FullScreen Menu is enabled
	*
	* @since 1.0.0
	*/
	function wen_biz_fullscreen_menu_active( $control ) {
		$enable = $control->manager->get_setting( 'wen_biz_menu_type' )->value();
		if ( 'fullscreen' === $enable ) {
			return true;
		}
		return false;
	}
endif;