<?php
/**
 * Adding support for WooCommerce Products Showcase Option
 */

/**
 * Add WooCommerce Product Showcase Options to customizer
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function wen_biz_woo_products_showcase( $wp_customize ) {
   $wp_customize->add_section( 'wen_biz_woo_products_showcase', array(
        'title' => esc_html__( 'WooCommerce Products Showcase', 'wen-biz-pro' ),
        'panel' => 'wen_biz_theme_options',
    ) );

    wen_biz_register_option( $wp_customize, array(
            'name'              => 'wen_biz_woo_products_showcase_option',
            'default'           => 'disabled',
            'sanitize_callback' => 'wen_biz_sanitize_select',
            'choices'           => wen_biz_section_visibility_options(),
            'label'             => esc_html__( 'Enable on', 'wen-biz-pro' ),
            'section'           => 'wen_biz_woo_products_showcase',
            'type'              => 'select',
        )
    );

    wen_biz_register_option( $wp_customize, array(
            'name'              => 'wen_biz_woo_products_showcase_tagline',
            'sanitize_callback' => 'wp_kses_post',
            'label'             => esc_html__( 'Section Tagline', 'wen-biz-pro' ),
            'active_callback'   => 'wen_biz_is_woo_products_showcase_active',
            'section'           => 'wen_biz_woo_products_showcase',
            'type'              => 'text',
        )
    );

    wen_biz_register_option( $wp_customize, array(
            'name'              => 'wen_biz_woo_products_showcase_title',
            'default'           => esc_html__( 'Exclusive Merch', 'wen-biz-pro' ),
            'sanitize_callback' => 'wp_kses_post',
            'label'             => esc_html__( 'Section Title', 'wen-biz-pro' ),
            'active_callback'   => 'wen_biz_is_woo_products_showcase_active',
            'section'           => 'wen_biz_woo_products_showcase',
            'type'              => 'text',
        )
    );

    wen_biz_register_option( $wp_customize, array(
            'name'              => 'wen_biz_woo_products_showcase_number',
            'default'           => 8,
            'sanitize_callback' => 'wen_biz_sanitize_number_range',
            'active_callback'   => 'wen_biz_is_woo_products_showcase_active',
            'description'       => esc_html__( 'Save and refresh the page if No. of Products is changed. Set -1 to display all', 'wen-biz-pro' ),
            'input_attrs'       => array(
                'style' => 'width: 50px;',
                'min'   => -1,
            ),
            'label'             => esc_html__( 'No of Products', 'wen-biz-pro' ),
            'section'           => 'wen_biz_woo_products_showcase',
            'type'              => 'number',
        )
    );

    wen_biz_register_option( $wp_customize, array(
            'name'               => 'wen_biz_woo_products_showcase_columns',
            'default'            => 4,
            'sanitize_callback'  => 'wen_biz_sanitize_number_range',
            'active_callback'    => 'wen_biz_is_woo_products_showcase_active',
            'description'        => esc_html__( 'Theme supports up to 6 columns', 'wen-biz-pro' ),
            'label'              => esc_html__( 'No of Columns', 'wen-biz-pro' ),
            'section'            => 'wen_biz_woo_products_showcase',
            'type'               => 'number',
            'input_attrs'       => array(
                'style' => 'width: 50px;',
                'min'   => 1,
                'max'   => 4,
            ),
        )
    );

    wen_biz_register_option( $wp_customize, array(
            'name'               => 'wen_biz_woo_products_showcase_paginate',
            'default'            => 'false',
            'sanitize_callback'  => 'wen_biz_sanitize_select',
            'active_callback'    => 'wen_biz_is_woo_products_showcase_active',
            'label'              => esc_html__( 'Paginate', 'wen-biz-pro' ),
            'section'            => 'wen_biz_woo_products_showcase',
            'type'               => 'radio',
            'choices'            => array(
                'false' => esc_html__( 'No', 'wen-biz-pro' ),
                'true' => esc_html__( 'Yes', 'wen-biz-pro' ),
            ),
        )
    );

    wen_biz_register_option( $wp_customize, array(
            'name'               => 'wen_biz_woo_products_showcase_orderby',
            'default'            => 'title',
            'sanitize_callback'  => 'wen_biz_sanitize_select',
            'active_callback'    => 'wen_biz_is_woo_products_showcase_active',
            'label'              => esc_html__( 'Order By', 'wen-biz-pro' ),
            'section'            => 'wen_biz_woo_products_showcase',
            'type'               => 'select',
            'choices'            => array(
                'date'       => esc_html__( 'Date - The date the product was published', 'wen-biz-pro' ),
                'id'         => esc_html__( 'ID - The post ID of the product', 'wen-biz-pro' ),
                'menu_order' => esc_html__( 'Menu Order - The Menu Order, if set (lower numbers display first)', 'wen-biz-pro' ),
                'popularity' => esc_html__( 'Popularity - The number of purchases', 'wen-biz-pro' ),
                'rand'       => esc_html__( 'Random', 'wen-biz-pro' ),
                'rating'     => esc_html__( 'Rating - The average product rating', 'wen-biz-pro' ),
                'title'      => esc_html__( 'Title - The product title', 'wen-biz-pro' ),
            ),
        )
    );

    wen_biz_register_option( $wp_customize, array(
            'name'               => 'wen_biz_woo_products_showcase_products_filter',
            'default'            => 'none',
            'sanitize_callback'  => 'wen_biz_sanitize_select',
            'active_callback'    => 'wen_biz_is_woo_products_showcase_active',
            'label'              => esc_html__( 'Products Filter', 'wen-biz-pro' ),
            'section'            => 'wen_biz_woo_products_showcase',
            'type'               => 'radio',
            'choices'            => array(
                'none'         => esc_html__( 'None', 'wen-biz-pro' ),
                'on_sale'      => esc_html__( 'Retrieve on sale products', 'wen-biz-pro' ),
                'best_selling' => esc_html__( 'Retrieve best selling products', 'wen-biz-pro' ),
                'top_rated'    => esc_html__( 'Retrieve top rated products', 'wen-biz-pro' ),
            ),
        )
    );

    wen_biz_register_option( $wp_customize, array(
            'name'              => 'wen_biz_woo_products_showcase_featured',
            'sanitize_callback' => 'wen_biz_sanitize_checkbox',
            'active_callback'   => 'wen_biz_is_woo_products_showcase_active',
            'label'             => esc_html__( 'Show only Products that are marked as Featured Products', 'wen-biz-pro' ),
            'section'           => 'wen_biz_woo_products_showcase',
            'custom_control'    => 'Wen_Biz_Toggle_Control',
        )
    );

    wen_biz_register_option( $wp_customize, array(
            'name'               => 'wen_biz_woo_products_showcase_order',
            'default'            => 'ASC',
            'sanitize_callback'  => 'wen_biz_sanitize_select',
            'active_callback'    => 'wen_biz_is_woo_products_showcase_active',
            'label'              => esc_html__( 'Order', 'wen-biz-pro' ),
            'section'            => 'wen_biz_woo_products_showcase',
            'type'               => 'radio',
            'choices'            => array(
                'ASC'  => esc_html__( 'Ascending', 'wen-biz-pro' ),
                'DESC' => esc_html__( 'Descending', 'wen-biz-pro' ),
            ),
        )
    );

    wen_biz_register_option( $wp_customize, array(
            'name'              => 'wen_biz_woo_products_showcase_skus',
            'description'       => esc_html__( 'Comma separated list of product SKUs', 'wen-biz-pro' ),
            'sanitize_callback' => 'sanitize_text_field',
            'active_callback'   => 'wen_biz_is_woo_products_showcase_active',
            'label'             => esc_html__( 'SKUs', 'wen-biz-pro' ),
            'section'           => 'wen_biz_woo_products_showcase',
            'type'              => 'text',
        )
    );

    wen_biz_register_option( $wp_customize, array(
            'name'              => 'wen_biz_woo_products_showcase_category',
            'description'       => esc_html__( 'Comma separated list of category slugs', 'wen-biz-pro' ),
            'sanitize_callback' => 'sanitize_text_field',
            'active_callback'   => 'wen_biz_is_woo_products_showcase_active',
            'label'             => esc_html__( 'Category', 'wen-biz-pro' ),
            'section'           => 'wen_biz_woo_products_showcase',
            'type'              => 'textarea',
        )
    );

    wen_biz_register_option( $wp_customize, array(
            'name'              => 'wen_biz_woo_products_showcase_text',
            'default'           => esc_html__( 'Go to Shop Page', 'wen-biz-pro' ),
            'sanitize_callback' => 'sanitize_text_field',
            'active_callback'   => 'wen_biz_is_woo_products_showcase_active',
            'label'             => esc_html__( 'Button Text', 'wen-biz-pro' ),
            'section'           => 'wen_biz_woo_products_showcase',
            'type'              => 'text',
        )
    );
    $shop_page_url = get_permalink( wc_get_page_id( 'shop' ) );
    wen_biz_register_option( $wp_customize, array(
            'name'              => 'wen_biz_woo_products_showcase_link',
            'default'           =>  esc_url( $shop_page_url ),
            'sanitize_callback' => 'esc_url_raw',
            'active_callback'   => 'wen_biz_is_woo_products_showcase_active',
            'label'             => esc_html__( 'Button Link', 'wen-biz-pro' ),
            'section'           => 'wen_biz_woo_products_showcase',
        )
    );

    wen_biz_register_option( $wp_customize, array(
            'name'              => 'wen_biz_woo_products_showcase_target',
            'sanitize_callback' => 'wen_biz_sanitize_checkbox',
            'active_callback'   => 'wen_biz_is_woo_products_showcase_active',
            'label'             => esc_html__( 'Open Link in New Window/Tab', 'wen-biz-pro' ),
            'section'           => 'wen_biz_woo_products_showcase',
            'custom_control'    => 'Wen_Biz_Toggle_Control',
        )
    );
}
add_action( 'customize_register', 'wen_biz_woo_products_showcase', 10 );

/** Active Callback Functions **/
if ( ! function_exists( 'wen_biz_is_woo_products_showcase_active' ) ) :
    /**
    * Return true if featured content is active
    *
    * @since 1.0.0
    */
    function wen_biz_is_woo_products_showcase_active( $control ) {
        $enable = $control->manager->get_setting( 'wen_biz_woo_products_showcase_option' )->value();

        return wen_biz_check_section( $enable );
    }
endif;
