<?php
/**
 * The template for displaying Contact Info
 *
 * @package Wen_Biz
 */

$enable_form = get_theme_mod( 'wen_biz_contact_form_option', 'disabled' );

if ( ! wen_biz_check_section( $enable_form ) ) {
	// Bail if featured content is disabled.
	return;
}

$map           = get_theme_mod( 'wen_biz_contact_map' );

$wen_biz_type        = get_theme_mod( 'wen_biz_contact_type', 'custom' ); 
$wen_biz_tagline     = get_theme_mod( 'wen_biz_contact_tagline' ); 
$wen_biz_title       = get_theme_mod( 'wen_biz_contact_title', esc_html__( 'Contact', 'wen-biz-pro' ) );
$wen_biz_description = get_theme_mod( 'wen_biz_contact_description' ); 

$inner_content = '';

if ('post' === $wen_biz_type && 'publish' === get_post_status( get_theme_mod( 'wen_biz_contact_post' ) ) ) {
	$post_object = get_post( get_theme_mod( 'wen_biz_contact_post' ) );

	$inner_content = apply_filters( 'the_content', $post_object->post_content );
} elseif ( 'page' === $wen_biz_type  && 'publish' === get_post_status( get_theme_mod( 'wen_biz_contact_page' ) ) ) {
	$post_object = get_post( get_theme_mod( 'wen_biz_contact_page' ) );

	$inner_content = apply_filters( 'the_content', $post_object->post_content );
} elseif ( 'custom' === $wen_biz_type ) {
	$inner_content = get_theme_mod( 'wen_biz_contact_custom' );
}	

$wen_biz_class = 'layout-two';

if ( ! $inner_content ) {
	$wen_biz_class = 'layout-one';
}

if ( $map ) {
	$wen_biz_class .= ' has-map';
}

?> 	
<div id="contact-form-section" class="section contact-form-section <?php echo esc_html( $wen_biz_class ); ?>">
	<?php 
	if ( $map ) : 
		$map_link   = get_theme_mod( 'wen_biz_contact_map_link' );
		$map_target = get_theme_mod( 'wen_biz_contact_map_target' ) ? '_blank' : '_self';
	?>
	<div class="post-thumbnail contact-map">
		<a href="<?php echo esc_url( $map_link ); ?>" target="<?php echo esc_url( $map_target ); ?>">
			<img src="<?php echo esc_url( $map )?>">
		</a>
	</div><!-- .contact-map -->
	<?php endif; ?>
		
	<div class="wrapper">
		<div class="section-content-wrapper contact-content-wrapper">
			<article class="hentry contact-details">
				<div class="entry-container">
					<?php wen_biz_section_heading( $wen_biz_tagline, $wen_biz_title, $wen_biz_description ); ?>
					<div class="contact">
						<?php $contact_image = get_theme_mod( 'wen_biz_contact_image' ); 
							  $contact_tagline = get_theme_mod( 'wen_biz_contact_number_tagline' );
							  $contact_number =  get_theme_mod( 'wen_biz_contact_phone' );
							  $contact_info_list = get_theme_mod( 'wen_biz_contact_info_list' );
							  $contact_text = get_theme_mod( 'wen_biz_contact_text' );
							  $contact_text_link = get_theme_mod( 'wen_biz_contact_text_link' );
							   ?>
						<?php if ( $contact_image ): ?>
							<img src="<?php echo esc_url( $contact_image )?>">
						<?php endif; ?>	
						<?php if ( $contact_tagline ): ?>	
							<span class="contact-tagline">
								<?php echo wp_kses_post( $contact_tagline); ?>
							</span>
						<?php endif; ?>	
						<?php if ( $contact_number ): ?>	
							<a target="_blank" title="<?php echo esc_attr( preg_replace( '/\s+/', '', $contact_number ) ); ?>"    href="tel:<?php echo esc_attr( preg_replace( '/\s+/', '', $contact_number ) ); ?>">
								<span class="contact-number-wrap">
									<span>
										<?php echo esc_html( $contact_number ); ?>
									</span>
								</span> 
							</a>
						<?php endif; ?>	
						<?php if ( $contact_info_list ): ?>
							<span class="contact-info-list">
								<?php echo wpautop( wp_kses_post( $contact_info_list ) ); ?>
							</span>
						<?php endif; ?>	
						<?php if ( $contact_text_link ):?>
							<span class="contact-info-text">
								<a class="contact-info-link" href="<?php echo esc_url( $contact_text_link ); ?>" target="_blank">
										<span><?php echo esc_html( $contact_text ); ?></span>
									</a>
							</span>
						<?php endif; ?>
					</div>
				</div>
			</article>
			<?php if ( $inner_content ): ?>
			<article class="hentry contact-us-form">
				<div class="entry-container">
					<div class="entry-content">												
						<?php echo do_shortcode( $inner_content );?> 
					</div>
				</div>
			</article><!-- .hentry -->
			<?php endif; ?>	
		</div>
	</div><!-- .wrapper -->
</div><!-- .section -->
