<?php
/**
 * The template for displaying featured content
 *
 * @package Wen_Biz
 */

$wen_biz_enable_content = get_theme_mod( 'wen_biz_featured_content_option', 'disabled' );

if ( ! wen_biz_check_section( $wen_biz_enable_content ) ) {
	// Bail if featured content is disabled.
	return;
}

$wen_biz_type = get_theme_mod( 'wen_biz_featured_content_type', 'category' );

if ( 'featured-content' === $wen_biz_type ) {
	$wen_biz_title   = get_option( 'featured_content_title', esc_html__( 'Contents', 'wen-biz-pro' ) );
	$wen_biz_tagline = get_option( 'featured_content_content' );
} else {
	$wen_biz_title   = get_theme_mod( 'wen_biz_featured_content_title' );
	$wen_biz_tagline = get_theme_mod( 'wen_biz_featured_content_tagline' );
}

$layout = get_theme_mod( 'wen_biz_featured_content_layout', 'layout-three' );

$wen_biz_classes[] = $layout;
$wen_biz_classes[] = $wen_biz_type;
$wen_biz_classes[] = 'section';

if( ! $wen_biz_title && ! $wen_biz_tagline ) {
	$wen_biz_classes[] = 'no-section-heading';
}
?>

<div id="featured-content-section" class="<?php echo esc_attr( implode( ' ', $wen_biz_classes ) ); ?>">
	<div class="wrapper">
		<?php wen_biz_section_heading( $wen_biz_tagline, $wen_biz_title ); ?>

		<div class="section-content-wrapper featured-content-wrapper <?php echo esc_attr( $layout ); ?>">
			<?php
				if ( 'custom' === $wen_biz_type ) {
					get_template_part( 'template-parts/featured-content/custom-featured' );
				} else {
					get_template_part( 'template-parts/featured-content/content-featured' );
				}
			?>
		</div><!-- .section-content-wrap -->

		<?php
			$wen_biz_target        = get_theme_mod( 'wen_biz_featured_content_target' ) ? '_blank': '_self';
			$wen_biz_link = get_theme_mod( 'wen_biz_featured_content_link', '#' );
			$wen_biz_text          = get_theme_mod( 'wen_biz_featured_content_text' );

			if ( $wen_biz_text ) :
			?>
			<p class="view-more">
				<a class="button" target="<?php echo $wen_biz_target; ?>" href="<?php echo esc_url( $wen_biz_link ); ?>"><?php echo esc_html( $wen_biz_text ); ?></a>
			</p>
		<?php endif; ?>
	</div><!-- .wrapper -->
</div><!-- #featured-content-section -->
