<?php
/**
 * The template used for displaying logo_slider
 *
 * @package Wen_Biz
 */
$wen_biz_quantity      = get_theme_mod( 'wen_biz_logo_slider_number', 6 );
$wen_biz_no_of_post    = 0; // for number of posts
$wen_biz_post_list     = array(); // list of valid post/page ids
$wen_biz_type = get_theme_mod( 'wen_biz_logo_slider_type', 'category' );
$show_content  = get_theme_mod( 'wen_biz_logo_slider_content_show', 'hide-content' );
$display_title = get_theme_mod( 'wen_biz_display_title', 0 );

$wen_biz_args = array(
	'post_type'           => 'any',
	'ignore_sticky_posts' => 1, // ignore sticky posts
);

//Get valid number of posts
if ( 'post' === $wen_biz_type || 'page' === $wen_biz_type ) {
	for ( $i = 1; $i <= $wen_biz_quantity; $i++ ) {
		$wen_biz_post_id = '';

		if ( 'post' === $wen_biz_type ) {
			$wen_biz_post_id = get_theme_mod( 'wen_biz_logo_slider_post_' . $i );
		} elseif ( 'page' === $wen_biz_type ) {
			$wen_biz_post_id = get_theme_mod( 'wen_biz_logo_slider_page_' . $i );
		}

		if ( $wen_biz_post_id && '' !== $wen_biz_post_id ) {
			$wen_biz_post_list = array_merge( $wen_biz_post_list, array( $wen_biz_post_id ) );

			$wen_biz_no_of_post++;
		}
	}

	$wen_biz_args['post__in'] = $wen_biz_post_list;
	$wen_biz_args['orderby'] = 'post__in';
} elseif ( 'category' === $wen_biz_type ) {
	$wen_biz_no_of_post = $wen_biz_quantity;

	$wen_biz_args['category__in'] = get_theme_mod( 'wen_biz_logo_slider_select_category' );

	$wen_biz_args['post_type'] = 'post';
} elseif ( 'tag' === $wen_biz_type ) {
	$wen_biz_no_of_post = $wen_biz_quantity;

	$wen_biz_args['tag__in'] = get_theme_mod( 'wen_biz_logo_slider_select_tag' );

	$wen_biz_args['post_type'] = 'post';
}

if ( ! $wen_biz_no_of_post ) {
	return;
}

$wen_biz_args['posts_per_page'] = $wen_biz_no_of_post;

$wen_biz_loop = new WP_Query( $wen_biz_args );

while ( $wen_biz_loop->have_posts() ) :
	$wen_biz_loop->the_post();

	$wen_biz_classes = 'post post-' . get_the_ID() . ' hentry slides';

	// Default value if there is no featurd image or first image.
	$image_url = trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/no-thumb-200x85.jpg';

	if ( has_post_thumbnail() ) {
		$image_url = get_the_post_thumbnail_url( get_the_ID(), array( 200, 85 ) ); // Ratio 21:9
	} else {
		// Get the first image in page, returns false if there is no image.
		$first_image_url = wen_biz_get_first_image( get_the_ID(), array( 200, 85 ), '', true );

		// Set value of image as first image if there is an image present in the page.
		if ( $first_image_url ) {
			$image_url = $first_image_url;
		}
	}
	?>
	<article class="<?php echo esc_attr( $wen_biz_classes ); ?>">
		<div class="hentry-inner">
			<div class="post-thumbnail">
				<a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>">
					<img src="<?php echo esc_url( $image_url ); ?>" class="wp-post-image" alt="<?php the_title_attribute(); ?>">
				</a>
			</div><!-- .logo_slider-image-wrapper -->

			<div class="entry-container">
				<?php if( $display_title ) : ?>
					<header class="entry-header">
						<h2 class="entry-title">
							<a title="<?php the_title_attribute(); ?>" href="<?php the_permalink(); ?>">
								<?php the_title( '<span>','</span>' ); ?>
							</a>
						</h2>
					</header>
				<?php endif;

				if ( 'excerpt' === $show_content ) {
					$excerpt = get_the_excerpt();

					echo '<div class="entry-summary"><p>' . $excerpt . '</p></div><!-- .entry-summary -->';
				} elseif ( 'full-content' === $show_content ) {
					$content = apply_filters( 'the_content', get_the_content() );
					$content = str_replace( ']]>', ']]&gt;', $content );
					echo '<div class="entry-content">' . wp_kses_post( $content ) . '</div><!-- .entry-content -->';
				}
				?>
			</div><!-- .entry-container -->
		</div><!-- .hentry-inner -->
	</article><!-- .slides -->
<?php
endwhile;

wp_reset_postdata();
