<?php
/**
 * The template for displaying portfolio items
 *
 * @package Wen_Biz
 */
?>

<?php
$enable = get_theme_mod( 'wen_biz_portfolio_option', 'disabled' );

if ( ! wen_biz_check_section( $enable ) ) {
	// Bail if portfolio section is disabled.
	return;
}

$wen_biz_type = get_theme_mod( 'wen_biz_portfolio_type', 'category' );

$wen_biz_tagline = get_theme_mod( 'wen_biz_portfolio_tagline' );
$wen_biz_title   = get_theme_mod( 'wen_biz_portfolio_title', esc_html__( 'Latest Release', 'wen-biz-pro' ) );

if ( 'jetpack-portfolio' === $wen_biz_type ) {
	$wen_biz_tagline = get_option( 'jetpack_portfolio_content' );
	$wen_biz_title   = get_option( 'jetpack_portfolio_title', esc_html__( 'Projects', 'wen-biz-pro' ) );
}

$layout = get_theme_mod( 'wen_biz_portfolio_layout', 'layout-four' );

$classes[] = $layout;
$classes[] = $wen_biz_type;
$classes[] = 'section';

$classes[] = get_theme_mod( 'wen_biz_filter_type', 'filter-type-classic' );

?>

<div id="portfolio-content-section" class="<?php echo esc_attr( implode( ' ', $classes ) ); ?>">
	<div class="wrapper">
		<?php wen_biz_section_heading( $wen_biz_tagline, $wen_biz_title ); ?>

		<div class="section-content-wrapper portfolio-content-wrapper <?php echo esc_attr( $layout ); ?>">
			<?php if ( 'category' === $wen_biz_type && ! empty( $cats = get_theme_mod( 'wen_biz_portfolio_select_category' ) ) ) : ?>
				<div class="filter-button-wrap">
					<div class="filter-button-group button-group js-radio-button-group">
						<button class="button is-checked" data-filter="*"><?php esc_html_e( 'Filter - All', 'wen-biz-pro' ) ?></button>
						<?php
						foreach ( $cats as $cat ) {
							if ( ! is_wp_error( $cat ) ) {
								$catinfo = get_category( $cat );
								?>
								<button class="button" data-filter=".<?php echo esc_attr( 'category-' . $catinfo->slug ); ?>"><?php echo esc_html( $catinfo->name ); ?></button>
								<?php
							}
						}
					    ?>
					</div>
				</div>

				<div class="filter-select-group">
					<div class="filters-select-wrap">
						<select class="filters-select">
							<option value="*"><?php esc_html_e( 'Filter - All', 'wen-biz-pro' ) ?></option>
							<?php
							foreach ( $cats as $cat ) {
								if ( ! is_wp_error( $cat ) ) {
									$catinfo = get_category( $cat );
									?>
									<option value=".<?php echo esc_attr( 'category-' . $catinfo->slug ); ?>"><?php echo esc_html( $catinfo->name ); ?></option>
									<?php
								}
							}
						    ?>
						</select>
					</div>
				</div>
			<?php endif;?>

			<?php if ( 'jetpack-portfolio-type' === $wen_biz_type && ! empty( $project_types = get_theme_mod( 'wen_biz_portfolio_select_project_type' ) ) ) : ?>
				<div class="filter-button-wrap">
					<div class="filter-button-group button-group js-radio-button-group">
						<button class="button is-checked" data-filter="*"><?php esc_html_e( 'All', 'wen-biz-pro' ) ?></button>
						<?php
						foreach ( $project_types as $project_type ) {
							if ( ! is_wp_error( $project_type ) ) {
								$project_type_info = get_term( $project_type );
								?>
								<button class="button" data-filter=".<?php echo esc_attr( 'jetpack-portfolio-type-' . $project_type_info->slug ); ?>"><?php echo esc_html( $project_type_info->name ); ?></button>
								<?php
							}
						}
					    ?>
					</div>
				</div>

				<div class="filter-select-group">
					<div class="filters-select-wrap">
						<select class="filters-select">
							<option value="*"><?php esc_html_e( 'Filter - All', 'wen-biz-pro' ) ?></option>
							<?php
							foreach ( $project_types as $project_type ) {
								if ( ! is_wp_error( $project_type ) ) {
									$project_type_info = get_term( $project_type );
									?>
									<option value=".<?php echo esc_attr( 'jetpack-portfolio-type-' . $project_type_info->slug ); ?>"><?php echo esc_html( $project_type_info->name ); ?></option>
									<?php
								}
							}
						    ?>
						</select>
					</div>
				</div>
			<?php endif;?>

			<div class="grid">
				<?php
				if ( 'post' === $wen_biz_type || 'jetpack-portfolio' === $wen_biz_type || 'page' === $wen_biz_type || 'category' === $wen_biz_type || 'jetpack-portfolio-type' === $wen_biz_type ) {
					get_template_part( 'template-parts/portfolio/post-types', 'portfolio' );
				} elseif ( 'custom' === $wen_biz_type ) {
					get_template_part( 'template-parts/portfolio/image', 'portfolio' );
				}
				?>
			</div>
		</div><!-- .section-content-wrap -->

		<?php
			$target = get_theme_mod( 'wen_biz_portfolio_target' ) ? '_blank': '_self';
			$wen_biz_link   = get_theme_mod( 'wen_biz_portfolio_link', '#' );
			$text   = get_theme_mod( 'wen_biz_portfolio_text', esc_html__( 'View More', 'wen-biz-pro' ) );

			if ( $text ) :
		?>

		<p class="view-more">
			<a class="button" target="<?php echo $target; ?>" href="<?php echo esc_url( $wen_biz_link ); ?>"><?php echo esc_html( $text ); ?></a>
		</p>
		<?php endif; ?>
	</div><!-- .wrapper -->
</div><!-- #portfolio-section -->
