<?php
/**
 * The template for displaying pricing content
 *
 * @package Wen_Biz
 */
?>

<?php
$enable_content = get_theme_mod( 'wen_biz_pricing_option', 'disabled' );

if ( ! wen_biz_check_section( $enable_content ) ) {
	// Bail if pricing content is disabled.
	return;
}

$wen_biz_type = get_theme_mod( 'wen_biz_pricing_type', 'category' );

if ( 'custom' !== $wen_biz_type ) {
	$pricing_posts = wen_biz_get_pricing_posts();

	if ( empty( $pricing_posts ) ) {
		return;
	}
}

$wen_biz_tagline  = get_theme_mod( 'wen_biz_pricing_section_tagline' );
$wen_biz_title    = get_theme_mod( 'wen_biz_pricing_section_title' );

$classes[] = 'pricing-section';
$classes[] = 'section';

if ( ! $wen_biz_title && ! $wen_biz_tagline ) {
	$classes[] = 'no-section-heading';
}
?>

<div id="pricing-section" class="<?php echo esc_attr( implode( ' ', $classes ) ); ?>">
	<div class="wrapper">
		<?php wen_biz_section_heading( $wen_biz_tagline, $wen_biz_title ); ?>

		<?php

		$wrapper_classes[] = 'section-content-wrapper pricing-content-wrapper';

		$wrapper_classes[] = get_theme_mod( 'wen_biz_pricing_layout', 'layout-three' );
		?>

		<div class="<?php echo esc_attr( implode( ' ', $wrapper_classes ) ); ?>">
			<?php
			if ( 'custom' === $wen_biz_type ) {
				get_template_part( 'template-parts/pricing/content', 'custom' );
			} else {
				$i = 1;
				$currency = get_theme_mod( 'wen_biz_pricing_currency' );

				foreach ( $pricing_posts as $post ) {
					setup_postdata( $post );

					$show_content    = get_theme_mod( 'wen_biz_pricing_show', 'full-content' );
					$highlight_class = get_theme_mod( 'wen_biz_pricing_highlight_' . $i ) ? 'highlight' : 'highlight-off';
					?>

					<article id="post-<?php the_ID(); ?>" <?php post_class( esc_attr( $highlight_class ) ); ?>>
						<div class="hentry-inner">
							<?php if( 'highlight' === $highlight_class && get_theme_mod( 'wen_biz_pricing_highlight_text_' . $i, esc_html__( 'Popular Choice', 'wen-biz-pro' ) ) ) : ?>
								<span class="popular-tag"><?php echo esc_html( get_theme_mod( 'wen_biz_pricing_highlight_text_' . $i, esc_html__( 'Popular Choice', 'wen-biz-pro' ) ) ); ?></span>
							<?php endif; ?>
							<div class="post-thumbnail">
								<a href="<?php the_permalink(); ?>">
									<?php

									// Default value if there is no first image
									$image = '';

									if ( has_post_thumbnail() ) {
										the_post_thumbnail( array( 110, 110 ) );
									} else {
										// Get the first image in page, returns false if there is no image.
										$first_image = wen_biz_get_first_image( get_the_ID(), 'post-thumbnail', '' );

										// Set value of image as first image if there is an image present in the page.
										if ( $first_image ) {
											$image = $first_image;
										}

										echo $image;
									}
									?>
								</a>
							</div>
							<?php 
							$amount         = get_theme_mod( 'wen_biz_pricing_amount_' . $i );
							$amount_remarks = get_theme_mod( 'wen_biz_pricing_amount_remarks_' . $i ); ?>
							<div class="entry-container">
							<?php if ( $amount || $amount_remarks ) : ?>
								<div class="entry-header-wrap has-package-price">
							<?php else: ?>
								<div class="entry-header-wrap">
							<?php endif; ?>		
									<header class="entry-header">
										<?php the_title( '<h2 class="entry-title"><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">','</a></h2>' ); ?>
									</header>

									<?php
									if ( $amount || $amount_remarks ) :
										?>
										<div class="package-price">
											<?php if ( $amount ) : ?>
											<span class="package-amount"><?php echo esc_html( $currency ); ?><?php echo esc_html( $amount ); ?></span>
											<?php endif; ?>

											<?php if ( $amount_remarks ) : ?>
											<span class="package-month"><?php echo esc_html( $amount_remarks ); ?></span>
											<?php endif; ?>
										 </div>
									<?php endif; ?>
								</div>
								<?php
								if ( 'excerpt' === $show_content ) {
									$excerpt = get_the_excerpt();

									echo '<div class="entry-summary"><p>' . $excerpt . '</p></div><!-- .entry-summary -->';
								} elseif ( 'full-content' === $show_content ) {
									$content = apply_filters( 'the_content', get_the_content() );
									$content = str_replace( ']]>', ']]&gt;', $content );
									echo '<div class="entry-content">' . wp_kses_post( $content ) . '</div><!-- .entry-content -->';
								} ?>
							</div><!-- .entry-container -->
						</div> <!-- .hentry-inner -->
					</article> <!-- .article -->
					<?php
					$i++;
				}

				wp_reset_postdata();
			}
			?>
		</div><!-- .pricing-wrapper -->
	</div><!-- .wrapper -->
</div><!-- #pricing-section -->
