<?php
/**
 * The template used for displaying promotion content
 *
 * @package Wen_Biz
 */

$wen_biz_type = get_theme_mod( 'wen_biz_promotion_content_type', 'page' );

if ( 'page' === $wen_biz_type && $wen_biz_id = get_theme_mod( 'wen_biz_promotion_content' ) ) {
	$wen_biz_args['page_id'] = absint( $wen_biz_id );
} elseif ( 'post' === $wen_biz_type && $wen_biz_id = get_theme_mod( 'wen_biz_promotion_content_post' ) ) {
	$wen_biz_args['p'] = absint( $wen_biz_id );
} elseif ( 'category' === $wen_biz_type && $wen_biz_cat = get_theme_mod( 'wen_biz_promotion_content_category' ) ) {
	$wen_biz_args['cat'] = absint( $wen_biz_cat );
	$wen_biz_args['posts_per_page'] = 1;
}

// If $wen_biz_args is empty return false
if ( empty( $wen_biz_args ) ) {
	return;
}

$wen_biz_classes[] = 'promotion-content-section';
$wen_biz_classes[] = 'section';
$wen_biz_classes[] = get_theme_mod( 'wen_biz_promotion_content_img_align', 'content-align-left' );
$wen_biz_classes[] = get_theme_mod( 'wen_biz_promotion_content_txt_align', 'text-align-left' );

// Create a new WP_Query using the argument previously created
$promotion_query = new WP_Query( $wen_biz_args );
if ( $promotion_query->have_posts() ) :
	while ( $promotion_query->have_posts() ) :
		$promotion_query->the_post();
		?>
		<div id="promotion-content-section" class="<?php echo esc_attr( implode( ' ', $wen_biz_classes ) ); ?>">
			<div class="wrapper">
				<div class="section-content-wrapper promotion-content-wrapper">
					<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
						<div class="hentry-inner">
							<div class="post-thumbnail-stats-wrapper">
								<?php $stats_text = get_theme_mod( 'wen_biz_promotion_content_stats' ); 
							 	$stats_count = get_theme_mod( 'wen_biz_promotion_content_stats_count' );
							 	if ( $stats_text || $stats_count  ) {
									$post_thumbnail = wen_biz_post_thumbnail( 'wen-biz-promotional-content', 'html-with-bg', false ); // wen_biz_post_thumbnail( $image_size, $wen_biz_type = 'html', $echo = true, $no_thumb = false ).
								} else {
								 	$post_thumbnail = wen_biz_post_thumbnail( 'wen-biz-promotional-content', 'html', false );
								}

								if ( has_post_thumbnail() ) :
									echo $post_thumbnail;
		
								if ( $stats_text || $stats_count  ) { ?>
									<div class="promotion-stats">
										<span class="stat-count">
											<?php echo wp_kses_post( $stats_count ); ?>
										</span>
										<?php echo wpautop( wp_kses_post( $stats_text ) ); ?>
									</div><!-- .promotion-stats -->
								<?php } ?>		
							</div><!-- .post-thumbnail-stats-wrapper -->	
							<div class="entry-container">
						<?php else : ?>
								<?php if ( $stats_text || $stats_count  ) { ?>
									<div class="promotion-stats">
										<span class="stat-count">
											<?php echo wp_kses_post( $stats_count ); ?>
										</span>
										<?php echo wpautop( wp_kses_post( $stats_text ) ); ?>
									</div><!-- .promotion-stats -->	
								<?php } ?>
							</div><!-- .post-thumbnail-stats-wrapper -->
							<div class="entry-container full-width">
						<?php endif; ?>
							<?php
							$wen_biz_title   = get_theme_mod( 'wen_biz_display_promotion_content_title', 1 );
							$wen_biz_tagline = get_theme_mod( 'wen_biz_promotion_content_tagline' );

							if ( $wen_biz_title || $wen_biz_tagline ) : ?>
								<header class="entry-header">
									<?php if ( $wen_biz_tagline ) : ?>
										<div class="section-tagline">
											<?php echo wp_kses_post( $wen_biz_tagline ); ?>
										</div><!-- .section-tagline -->
									<?php endif; ?>

									<?php if ( $wen_biz_title ) : ?>
									<h2 class="entry-title">
										<?php the_title(); ?>
									</h2>
									<?php endif; ?>
								</header><!-- .entry-header -->
							<?php endif; ?>

							<?php
							$show_content = get_theme_mod( 'wen_biz_promotion_content_show', 'excerpt' );

							if ( 'full-content' === $show_content ) {
								?>
								<div class="entry-content">
									<?php the_content(); ?>
								</div><!-- .entry-content -->
								<?php
							} elseif ( 'excerpt' === $show_content ) {
								?>
								<div class="entry-summary">
									<?php the_excerpt();  ?>
								</div><!-- .entry-summary -->
								<?php
							}
							?>

							<?php if ( get_edit_post_link() ) : ?>
								<footer class="entry-footer">
									<div class="entry-meta">
										<?php
											edit_post_link(
												sprintf(
													/* translators: %s: Name of current post */
													esc_html__( 'Edit %s', 'wen-biz-pro' ),
													the_title( '<span class="screen-reader-text">"', '"</span>', false )
												),
												'<span class="edit-link">',
												'</span>'
											);
										?>
									</div>	<!-- .entry-meta -->
								</footer><!-- .entry-footer -->
							<?php endif; ?>
						</div><!-- .hentry-inner -->
					</article>
				</div><!-- .section-content-wrapper -->
			</div><!-- .wrapper -->
		</div><!-- .section -->
	<?php
	endwhile;

	wp_reset_postdata();
endif;
