<?php
/**
 * The template for displaying service posts on the front page
 *
 * @package Wen_Biz
 */

$show_content  = get_theme_mod( 'wen_biz_service_show', 'excerpt' );
$show_meta     = get_theme_mod( 'wen_biz_service_meta_show', 'hide-meta' );
$wen_biz_type = get_theme_mod( 'wen_biz_service_type', 'category' );
$wen_biz_number        = get_theme_mod( 'wen_biz_service_number', 3 );

$wen_biz_post_list  = array();
$wen_biz_no_of_post = 0;

$wen_biz_args = array(
	'post_type'           => 'post',
	'ignore_sticky_posts' => 1, // ignore sticky posts.
);

// Get valid number of posts.
if ( 'post' === $wen_biz_type || 'page' === $wen_biz_type || 'ect-service' === $wen_biz_type ) {
	$wen_biz_args['post_type'] = $wen_biz_type;

	for ( $i = 1; $i <= $wen_biz_number; $i++ ) {
		$wen_biz_post_id = '';

		if ( 'post' === $wen_biz_type ) {
			$wen_biz_post_id = get_theme_mod( 'wen_biz_service_post_' . $i );
		} elseif ( 'page' === $wen_biz_type ) {
			$wen_biz_post_id = get_theme_mod( 'wen_biz_service_page_' . $i );
		} elseif ( 'ect-service' === $wen_biz_type ) {
			$wen_biz_post_id = get_theme_mod( 'wen_biz_service_cpt_' . $i );
		}

		if ( $wen_biz_post_id ) {
			$wen_biz_post_list = array_merge( $wen_biz_post_list, array( $wen_biz_post_id ) );

			$wen_biz_no_of_post++;
		}
	}

	$wen_biz_args['post__in'] = $wen_biz_post_list;
	$wen_biz_args['orderby']  = 'post__in';
} elseif ( 'category' === $wen_biz_type ) {
	if ( $wen_biz_cat = get_theme_mod( 'wen_biz_service_select_category' ) ) {
		$wen_biz_args['category__in'] = $wen_biz_cat;
	}

	$wen_biz_no_of_post = $wen_biz_number;
}

$wen_biz_args['posts_per_page'] = $wen_biz_no_of_post;

if ( ! $wen_biz_no_of_post ) {
	return;
}

$wen_biz_loop = new WP_Query( $wen_biz_args );

while ( $wen_biz_loop->have_posts() ) :
	
	$wen_biz_loop->the_post();
	?>
	<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
		<div class="hentry-inner">
			<?php wen_biz_post_thumbnail( array( 110, 110 ), 'html', true ); ?>

			<div class="entry-container">
				<header class="entry-header">

					<?php the_title( '<h2 class="entry-title"><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">','</a></h2>' ); ?>

					<?php if ( 'show-meta' === $show_meta  && 'custom' !== $wen_biz_type ) : ?>
					<div class="entry-meta">
						<?php wen_biz_posted_on(); ?>
					</div><!-- .entry-meta -->
					<?php endif; ?>

				</header>

				<?php
				if ( 'excerpt' === $show_content ) {
					$excerpt = get_the_excerpt();

					echo '<div class="entry-summary"><p>' . $excerpt . '</p></div><!-- .entry-summary -->';
				} elseif ( 'full-content' === $show_content ) {
					$content = apply_filters( 'the_content', get_the_content() );
					$content = str_replace( ']]>', ']]&gt;', $content );
					echo '<div class="entry-content">' . wp_kses_post( $content ) . '</div><!-- .entry-content -->';
				} ?>
			</div><!-- .entry-container -->
		</div> <!-- .hentry-inner -->
	</article> <!-- .article -->
	<?php
endwhile;

wp_reset_postdata();
