<?php
/**
 * The template for displaying service content
 *
 * @package Wen_Biz
 */

$wen_biz_enable_content = get_theme_mod( 'wen_biz_service_option', 'disabled' );

if ( ! wen_biz_check_section( $wen_biz_enable_content ) ) {
	// Bail if service content is disabled.
	return;
}

$wen_biz_type = get_theme_mod( 'wen_biz_service_type', 'category' );

if ( 'ect-service' === $wen_biz_type ) {
	$wen_biz_tagline = get_option( 'ect_service_content' );
	$wen_biz_title    = get_option( 'ect_service_title', esc_html__( 'Services', 'wen-biz-pro' ) );
} else {
	$wen_biz_tagline = get_theme_mod( 'wen_biz_service_tagline' );
	$wen_biz_title    = get_theme_mod( 'wen_biz_service_title' );
}

$wen_biz_classes[] = 'service-section';
$wen_biz_classes[] = 'section';

if ( ! $wen_biz_title && ! $wen_biz_tagline ) {
	$wen_biz_classes[] = 'no-section-heading';
}
?>

<div id="service-section" class="<?php echo esc_attr( implode( ' ', $wen_biz_classes ) ); ?>">
	<div class="wrapper">
		<?php wen_biz_section_heading( $wen_biz_tagline, $wen_biz_title ); ?>

		<?php

		$wrapper_classes[] = 'section-content-wrapper service-content-wrapper';

		$wrapper_classes[] = get_theme_mod( 'wen_biz_service_layout', 'layout-three' );
		?>

		<div class="<?php echo esc_attr( implode( ' ', $wrapper_classes ) ); ?>">
			<?php
			if ( 'custom' === $wen_biz_type ) {
				get_template_part( 'template-parts/service/content-custom' );
			} else {
				get_template_part( 'template-parts/service/content-service' );
			}
			?>

		</div><!-- .section-content-wrapper -->
		
		<?php
			$wen_biz_link = get_theme_mod( 'wen_biz_service_link', '' );
			$wen_biz_text          = get_theme_mod( 'wen_biz_service_text', esc_html__( 'View All', 'wen-biz-pro' ) );
			$wen_biz_target        = get_theme_mod( 'wen_biz_service_target' ) ? '_blank': '_self';

			if ( $wen_biz_text || $wen_biz_link ) :
		?>

		<p class="view-more">
			<a class="button" target="<?php echo $wen_biz_target; ?>" href="<?php echo esc_url( $wen_biz_link ); ?>"><?php echo esc_html( $wen_biz_text ); ?></a>
		</p>
		<?php endif; ?>
	</div><!-- .wrapper -->
</div><!-- #service-section -->
