<?php
/**
 * The template for displaying team items
 *
 * @package Focus_Stock
 */

$wen_biz_number = get_theme_mod( 'wen_biz_team_number', 3 );

if ( ! $wen_biz_number ) {
	// If number is 0, then this section is disabled
	return;
}

$wen_biz_args = array(
	'orderby'             => 'post__in',
	'ignore_sticky_posts' => 1 // ignore sticky posts
);

$wen_biz_post_list  = array();// list of valid post/page ids

$wen_biz_no_of_post = 0; // for number of posts

$wen_biz_type = get_theme_mod( 'wen_biz_team_type', 'category' );

if ( 'post' === $wen_biz_type || 'page' === $wen_biz_type  ) {
	$wen_biz_args['post_type'] = $wen_biz_type;

	for ( $i = 1; $i <= $wen_biz_number; $i++ ) {
		$wen_biz_post_id = '';

		if ( 'post' === $wen_biz_type ) {
			$wen_biz_post_id = get_theme_mod( 'wen_biz_team_post_' . $i );
		} elseif ( 'page' === $wen_biz_type ) {
			$wen_biz_post_id = get_theme_mod( 'wen_biz_team_page_' . $i );
		}

		if ( $wen_biz_post_id && '' !== $wen_biz_post_id ) {
			// Polylang Support.
			if ( class_exists( 'Polylang' ) ) {
				$wen_biz_post_id = pll_get_post( $wen_biz_post_id, pll_current_language() );
			}

			$wen_biz_post_list = array_merge( $wen_biz_post_list, array( $wen_biz_post_id ) );

			$wen_biz_no_of_post++;
		}
	}

	$wen_biz_args['post__in'] = $wen_biz_post_list;
} elseif ( 'category' === $wen_biz_type ) {
	$wen_biz_no_of_post = $wen_biz_number;

	if ( get_theme_mod( 'wen_biz_team_select_category' ) ) {
		$wen_biz_args['category__in'] = (array) get_theme_mod( 'wen_biz_team_select_category' );
	}

	$wen_biz_args['post_type'] = 'post';
}

if ( 0 === $wen_biz_no_of_post ) {
	return;
}

$wen_biz_args['posts_per_page'] = $wen_biz_no_of_post;
$show_content = get_theme_mod( 'wen_biz_team_show', 'hide-content' );
$wen_biz_loop     = new WP_Query( $wen_biz_args );

if ( $wen_biz_loop -> have_posts() ) :
	while ( $wen_biz_loop -> have_posts() ) :
		$wen_biz_loop -> the_post();
		$wen_biz_number   = get_theme_mod( 'wen_biz_team_number_' . ( absint( $wen_biz_loop ->current_post ) + 1 ) );
		$wen_biz_position = get_theme_mod( 'wen_biz_team_position_' . ( absint( $wen_biz_loop ->current_post ) + 1 ) );
		$wen_biz_phone = get_theme_mod( 'wen_biz_team_phone_' . ( absint( $wen_biz_loop ->current_post ) + 1 ) );
		$wen_biz_email = get_theme_mod( 'wen_biz_team_email_' . ( absint( $wen_biz_loop ->current_post ) + 1 ) );
		$no_thumb = trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/no-thumb-508x338.jpg';
		?>
		<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
			<div class="hentry-inner">
				<?php if( has_post_thumbnail() ) : ?>
					<div class="post-thumbnail">
						<a class="cover-link" href="<?php the_permalink(); ?>" title="<?php the_title(); ?>">
							<img src="<?php the_post_thumbnail_url( 'wen-biz-featured-content' ); ?>" class="attachment-wen-biz-featured-content size-wen-biz-featured-content wp-post-image" loading="lazy"></a>
						<?php wen_biz_team_social_links( absint( $wen_biz_loop->current_post ) +1 ); ?>	
					</div>
				<?php else : ?>
					<div class="post-thumbnail">
						<a class="cover-link" href="<?php the_permalink(); ?>" title="<?php the_title(); ?>">
							<img src="<?php echo esc_url( $no_thumb ); ?>"></a>
						<?php wen_biz_team_social_links( absint( $wen_biz_loop->current_post ) +1 ); ?>	
					</div>
				<?php endif; ?>
				<?php //wen_biz_post_thumbnail( 'wen-biz-featured-content', 'html', true, true ); ?>
				<div class="entry-container">
					<header class="entry-header">
						<?php the_title( '<h2 class="entry-title"><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">','</a></h2>' ); ?>
						
						<?php if ( $wen_biz_position ) : ?>
						<div class="entry-meta">
							<span class="entry-job">
	                        	<span class="job-label"><?php echo esc_html( $wen_biz_position ); ?></span>
		                    </span>
		                </div> <!-- .entry-meta -->
		           		<?php endif; ?>
					</header>
					<?php if ( $wen_biz_phone || $wen_biz_email ) : ?>
						<ul class="team-contact-details">
							<?php if ( $wen_biz_phone ) : ?>
								<li>
									<a href="tel:<?php echo esc_attr( preg_replace( '/\s+/', '', $wen_biz_phone ) ); ?>"><?php echo wen_biz_get_svg( array( 'icon' => 'phone' ) ); echo esc_html( preg_replace( '/\s+/', '', $wen_biz_phone ) ); ?></a>
								</li>
							<?php endif; ?>
							<?php if ( $wen_biz_email ) : ?>
								<li>
									<a href="mailto:<?php echo esc_attr(antispambot($wen_biz_email)); ?>">
									<?php echo wen_biz_get_svg(array('icon' => 'envelope'));
									echo esc_html(antispambot($wen_biz_email)) ?></a>
								</li>
							<?php endif; ?>
						</ul>
					<?php endif; ?>
					<?php
					if ( 'excerpt' === $show_content ) {
						$excerpt = get_the_excerpt();

						echo '<div class="entry-summary"><p>' . $excerpt . '</p></div><!-- .entry-summary -->';
					} elseif ( 'full-content' === $show_content ) {
						$content = apply_filters( 'the_content', get_the_content() );
						$content = str_replace( ']]>', ']]&gt;', $content );
						echo '<div class="entry-content">' . wp_kses_post( $content ) . '</div><!-- .entry-content -->';
					} ?>
				</div><!-- .entry-container -->
			</div> <!-- .hentry-inner -->
		</article> <!-- .article -->
	<?php
	endwhile;
	wp_reset_postdata();
endif;
