<?php
/**
 * The template for displaying Woo Products Showcase
 *
 * @package Wen_Biz
 */

if ( ! class_exists( 'WooCommerce' ) ) {
    // Bail if WooCommerce is not installed
    return;
}

$wen_biz_enable_content = get_theme_mod( 'wen_biz_woo_products_showcase_option', 'disabled' );

if ( ! wen_biz_check_section( $wen_biz_enable_content ) ) {
	// Bail if featured content is disabled.
	return;
}

$wen_biz_number           = get_theme_mod( 'wen_biz_woo_products_showcase_number', 8 );
$wen_biz_columns          = get_theme_mod( 'wen_biz_woo_products_showcase_columns', 4 );
$wen_biz_paginate         = get_theme_mod( 'wen_biz_woo_products_showcase_paginate' );
$wen_biz_orderby          = isset( $_GET['orderby'] ) ? $_GET['orderby'] : get_theme_mod( 'wen_biz_woo_products_showcase_orderby' );
$wen_biz_product_filter   = get_theme_mod( 'wen_biz_woo_products_showcase_products_filter' );
$wen_biz_product_featured = get_theme_mod( 'wen_biz_woo_products_showcase_featured' );
$wen_biz_order            = get_theme_mod( 'wen_biz_woo_products_showcase_order' );
$wen_biz_skus             = get_theme_mod( 'wen_biz_woo_products_showcase_skus' );
$wen_biz_category         = get_theme_mod( 'wen_biz_woo_products_showcase_category' );

$wen_biz_shortcode = '[products';

if ( $wen_biz_number ) {
	$wen_biz_shortcode .= ' limit="' . esc_attr( $wen_biz_number ) . '"';
}

if ( $wen_biz_columns ) {
	$wen_biz_shortcode .= ' columns="' . absint( $wen_biz_columns ) . '"';
}

if ( $wen_biz_paginate ) {
	$wen_biz_shortcode .= ' paginate="' . esc_attr( $wen_biz_paginate ) . '"';
}

if ( $wen_biz_orderby ) {
	$wen_biz_shortcode .= ' orderby="' . esc_attr( $wen_biz_orderby ) . '"';
}

if ( $wen_biz_order ) {
	$wen_biz_shortcode .= ' order="' . esc_attr( $wen_biz_order ) . '"';
}

if ( $wen_biz_product_filter && 'none' !== $wen_biz_product_filter ) {
	$wen_biz_shortcode .= ' ' . esc_attr( $wen_biz_product_filter ) . '="true"';
}

if ( $wen_biz_skus ) {
	$wen_biz_shortcode .= ' skus="' . esc_attr( $wen_biz_skus ) . '"';
}

if ( $wen_biz_category  ) {
	$wen_biz_shortcode .= ' category="' . esc_attr( $wen_biz_category  ) . '"';
}

if ( $wen_biz_product_featured ) {
	$wen_biz_shortcode .= ' visibility="featured"';
}

$wen_biz_shortcode .= ']';

$wen_biz_tagline = get_theme_mod( 'wen_biz_woo_products_showcase_tagline');
$wen_biz_title   = get_theme_mod( 'wen_biz_woo_products_showcase_title', esc_html__( 'Exclusive Merch', 'wen-biz-pro' ) );

$wen_biz_classes[] = 'section';

if ( ! $wen_biz_title && ! $wen_biz_tagline ) {
	$wen_biz_classes[] = 'no-section-heading';
}
?>

<div id="product-content-section" class="<?php echo esc_attr( implode( ' ', $wen_biz_classes ) ); ?>">
	<div class="wrapper">
		<?php wen_biz_section_heading( $wen_biz_tagline, $wen_biz_title ); ?>

		<div class="section-content-wrapper product-content-wrapper">
			<?php echo do_shortcode( $wen_biz_shortcode ); ?>
		</div><!-- .section-content-wrapper -->

		<?php
			$wen_biz_target = get_theme_mod( 'wen_biz_woo_products_showcase_target' ) ? '_blank': '_self';
			$wen_biz_link   = get_theme_mod( 'wen_biz_woo_products_showcase_link', get_permalink( wc_get_page_id( 'shop' ) ) );
			$wen_biz_text   = get_theme_mod( 'wen_biz_woo_products_showcase_text', esc_html__( 'Go to Shop Page', 'wen-biz-pro' ) );

			if ( $wen_biz_text ) :
		?>
			<p class="view-more">
				<a class="button" target="<?php echo $wen_biz_target; ?>" href="<?php echo esc_url( $wen_biz_link ); ?>"><?php echo esc_html( $wen_biz_text ); ?></a>
			</p>
		<?php endif; ?>
	</div><!-- .wrapper -->
</div><!-- .sectionr -->
